@@ -20,13 +20,14 @@ extern FXMainWindow *mainWindow;
 
 
 // Message map
-FXDEFMAP(Bookmarks) BookmarksMap[] = {
-                                         FXMAPFUNC(SEL_UPDATE,Bookmarks::ID_ANYBOOKMARKS,Bookmarks::onUpdAnyBookmarks),
-                                         FXMAPFUNC(SEL_UPDATE,Bookmarks::ID_CLEAR,Bookmarks::onUpdAnyBookmarks),
-                                         FXMAPFUNC(SEL_COMMAND,Bookmarks::ID_CLEAR,Bookmarks::onCmdClear),
-                                         FXMAPFUNCS(SEL_COMMAND,Bookmarks::ID_BOOKMARK_1,Bookmarks::ID_BOOKMARK_20,Bookmarks::onCmdBookmark),
-                                         FXMAPFUNCS(SEL_UPDATE,Bookmarks::ID_BOOKMARK_1,Bookmarks::ID_BOOKMARK_20,Bookmarks::onUpdBookmark),
-                                     };
+FXDEFMAP(Bookmarks) BookmarksMap[]=
+{
+	FXMAPFUNC(SEL_UPDATE,Bookmarks::ID_ANYBOOKMARKS,Bookmarks::onUpdAnyBookmarks),
+	FXMAPFUNC(SEL_UPDATE,Bookmarks::ID_CLEAR,Bookmarks::onUpdAnyBookmarks),
+	FXMAPFUNC(SEL_COMMAND,Bookmarks::ID_CLEAR,Bookmarks::onCmdClear),
+	FXMAPFUNCS(SEL_COMMAND,Bookmarks::ID_BOOKMARK_1,Bookmarks::ID_BOOKMARK_20,Bookmarks::onCmdBookmark),
+	FXMAPFUNCS(SEL_UPDATE,Bookmarks::ID_BOOKMARK_1,Bookmarks::ID_BOOKMARK_20,Bookmarks::onUpdBookmark),
+};
 
 // Class implementation
 FXIMPLEMENT(Bookmarks,FXObject,BookmarksMap,ARRAYNUMBER(BookmarksMap))
