@@ -25,13 +25,14 @@
 
 
 // Map
-FXDEFMAP(CommandWindow) CommandWindowMap[]={
-            FXMAPFUNC(SEL_COMMAND,CommandWindow::ID_CLOSE,CommandWindow::onCmdClose),
-            FXMAPFUNC(SEL_COMMAND,CommandWindow::ID_KILLPROCESS,CommandWindow::onCmdKillProcess),
-            FXMAPFUNC(SEL_UPDATE,CommandWindow::ID_KILLPROCESS,CommandWindow::onUpdKillProcess),
-            FXMAPFUNC(SEL_UPDATE,CommandWindow::ID_CLOSE,CommandWindow::onUpdClose),
-            FXMAPFUNC(SEL_CHORE,CommandWindow::ID_WATCHPROCESS,CommandWindow::onWatchProcess),
-        };
+FXDEFMAP(CommandWindow) CommandWindowMap[]=
+{
+	FXMAPFUNC(SEL_COMMAND,CommandWindow::ID_CLOSE,CommandWindow::onCmdClose),
+	FXMAPFUNC(SEL_COMMAND,CommandWindow::ID_KILLPROCESS,CommandWindow::onCmdKillProcess),
+	FXMAPFUNC(SEL_UPDATE,CommandWindow::ID_KILLPROCESS,CommandWindow::onUpdKillProcess),
+	FXMAPFUNC(SEL_UPDATE,CommandWindow::ID_CLOSE,CommandWindow::onUpdClose),
+	FXMAPFUNC(SEL_CHORE,CommandWindow::ID_WATCHPROCESS,CommandWindow::onWatchProcess),
+};
 
 
 // Object implementation
