@@ -1,8 +1,10 @@
 #ifndef COMMANDWINDOW_H
 #define COMMANDWINDOW_H
 
+#include "DialogBox.h"
 
-class CommandWindow : public FXDialogBox
+
+class CommandWindow : public DialogBox
 {
     FXDECLARE(CommandWindow)
 protected:
@@ -22,7 +24,7 @@ private:
     CommandWindow(const CommandWindow&);
 public:
     enum{
-        ID_CLOSE=FXDialogBox::ID_LAST,
+        ID_CLOSE=DialogBox::ID_LAST,
         ID_WATCHPROCESS,
         ID_KILLPROCESS,
         ID_LAST
