@@ -10,13 +10,14 @@
 
 
 // Map
-FXDEFMAP(DialogBox) DialogBoxMap[]={
-            FXMAPFUNC(SEL_KEYPRESS,0,DialogBox::onKeyPress),
-            FXMAPFUNC(SEL_CLOSE,0,DialogBox::onClose),
-            FXMAPFUNC(SEL_COMMAND,DialogBox::ID_CANCEL,DialogBox::onCmdCancel),
-            FXMAPFUNC(SEL_COMMAND,DialogBox::ID_ACCEPT,DialogBox::onCmdAccept),
-            FXMAPFUNC(SEL_COMMAND,DialogBox::ID_TOGGLE_OPTION,DialogBox::onCmdToggleOption)
-        };
+FXDEFMAP(DialogBox) DialogBoxMap[]=
+{
+	FXMAPFUNC(SEL_KEYPRESS,0,DialogBox::onKeyPress),
+	FXMAPFUNC(SEL_CLOSE,0,DialogBox::onClose),
+	FXMAPFUNC(SEL_COMMAND,DialogBox::ID_CANCEL,DialogBox::onCmdCancel),
+	FXMAPFUNC(SEL_COMMAND,DialogBox::ID_ACCEPT,DialogBox::onCmdAccept),
+	FXMAPFUNC(SEL_COMMAND,DialogBox::ID_TOGGLE_OPTION,DialogBox::onCmdToggleOption)
+};
 
 
 // Object implementation
