@@ -16,13 +16,14 @@
 
 
 // Map
-FXDEFMAP(DirHistBox) DirHistBoxMap[]={
-												FXMAPFUNC(SEL_KEYPRESS,0,DirHistBox::onKeyPress),
-												FXMAPFUNC(SEL_KEYRELEASE,0,DirHistBox::onKeyRelease),
-												FXMAPFUNC(SEL_FOCUSOUT,0,DirHistBox::onCmdClose),
-												FXMAPFUNC(SEL_COMMAND,DirHistBox::ID_CLOSE,DirHistBox::onCmdClose),
-												FXMAPFUNC(SEL_CLICKED,DirHistBox::ID_CLICKED,DirHistBox::onCmdClicked),
-											};
+FXDEFMAP(DirHistBox) DirHistBoxMap[]=
+{
+	FXMAPFUNC(SEL_KEYPRESS,0,DirHistBox::onKeyPress),
+	FXMAPFUNC(SEL_KEYRELEASE,0,DirHistBox::onKeyRelease),
+	FXMAPFUNC(SEL_FOCUSOUT,0,DirHistBox::onCmdClose),
+	FXMAPFUNC(SEL_COMMAND,DirHistBox::ID_CLOSE,DirHistBox::onCmdClose),
+	FXMAPFUNC(SEL_CLICKED,DirHistBox::ID_CLICKED,DirHistBox::onCmdClicked),
+};
 
 
 // Object implementation
