@@ -15,6 +15,7 @@
 #include "BrowseInputDialog.h"
 #include "File.h"
 #include "FileDict.h"
+#include "InputDialog.h"
 #include "MessageBox.h"
 
 
@@ -49,47 +50,48 @@ FXIMPLEMENT(DirItem,FXTreeItem,NULL,0)
 
 
 // Map
-FXDEFMAP(DirList) DirListMap[]={
-                                   FXMAPFUNC(SEL_DRAGGED,0,DirList::onDragged),
-                                   FXMAPFUNC(SEL_TIMEOUT,DirList::ID_REFRESH_TIMER,DirList::onCmdRefreshTimer),
+FXDEFMAP(DirList) DirListMap[]=
+{
+	FXMAPFUNC(SEL_DRAGGED,0,DirList::onDragged),
+	FXMAPFUNC(SEL_TIMEOUT,DirList::ID_REFRESH_TIMER,DirList::onCmdRefreshTimer),
 #if defined(linux)
-                                   FXMAPFUNC(SEL_TIMEOUT,DirList::ID_MTDEVICES_REFRESH,DirList::onMtdevicesRefresh),
-                                   FXMAPFUNC(SEL_TIMEOUT,DirList::ID_UPDEVICES_REFRESH,DirList::onUpdevicesRefresh),
+	FXMAPFUNC(SEL_TIMEOUT,DirList::ID_MTDEVICES_REFRESH,DirList::onMtdevicesRefresh),
+	FXMAPFUNC(SEL_TIMEOUT,DirList::ID_UPDEVICES_REFRESH,DirList::onUpdevicesRefresh),
 #endif
-                                   FXMAPFUNC(SEL_TIMEOUT,DirList::ID_EXPAND_TIMER,DirList::onExpandTimer),
-                                   FXMAPFUNC(SEL_DND_ENTER,0,DirList::onDNDEnter),
-                                   FXMAPFUNC(SEL_DND_LEAVE,0,DirList::onDNDLeave),
-                                   FXMAPFUNC(SEL_DND_DROP,0,DirList::onDNDDrop),
-                                   FXMAPFUNC(SEL_DND_MOTION,0,DirList::onDNDMotion),
-                                   FXMAPFUNC(SEL_DND_REQUEST,0,DirList::onDNDRequest),
-                                   FXMAPFUNC(SEL_BEGINDRAG,0,DirList::onBeginDrag),
-                                   FXMAPFUNC(SEL_ENDDRAG,0,DirList::onEndDrag),
-                                   FXMAPFUNC(SEL_OPENED,0,DirList::onOpened),
-                                   FXMAPFUNC(SEL_CLOSED,0,DirList::onClosed),
-                                   FXMAPFUNC(SEL_EXPANDED,0,DirList::onExpanded),
-                                   FXMAPFUNC(SEL_COLLAPSED,0,DirList::onCollapsed),
-                                   FXMAPFUNC(SEL_UPDATE,DirList::ID_SHOW_HIDDEN,DirList::onUpdShowHidden),
-                                   FXMAPFUNC(SEL_UPDATE,DirList::ID_HIDE_HIDDEN,DirList::onUpdHideHidden),
-                                   FXMAPFUNC(SEL_UPDATE,DirList::ID_TOGGLE_HIDDEN,DirList::onUpdToggleHidden),
-                                   FXMAPFUNC(SEL_UPDATE,DirList::ID_SHOW_FILES,DirList::onUpdShowFiles),
-                                   FXMAPFUNC(SEL_UPDATE,DirList::ID_HIDE_FILES,DirList::onUpdHideFiles),
-                                   FXMAPFUNC(SEL_UPDATE,DirList::ID_TOGGLE_FILES,DirList::onUpdToggleFiles),
-                                   FXMAPFUNC(SEL_UPDATE,DirList::ID_SET_PATTERN,DirList::onUpdSetPattern),
-                                   FXMAPFUNC(SEL_UPDATE,DirList::ID_SORT_REVERSE,DirList::onUpdSortReverse),
-                                   FXMAPFUNC(SEL_COMMAND,DirList::ID_SHOW_HIDDEN,DirList::onCmdShowHidden),
-								   FXMAPFUNC(SEL_COMMAND,DirList::ID_DRAG_COPY,DirList::onCmdDragCopy),
-								   FXMAPFUNC(SEL_COMMAND,DirList::ID_DRAG_MOVE,DirList::onCmdDragMove),
-								   FXMAPFUNC(SEL_COMMAND,DirList::ID_DRAG_LINK,DirList::onCmdDragLink),
-								   FXMAPFUNC(SEL_COMMAND,DirList::ID_DRAG_REJECT,DirList::onCmdDragReject),
-                                   FXMAPFUNC(SEL_COMMAND,DirList::ID_HIDE_HIDDEN,DirList::onCmdHideHidden),
-                                   FXMAPFUNC(SEL_COMMAND,DirList::ID_TOGGLE_HIDDEN,DirList::onCmdToggleHidden),
-                                   FXMAPFUNC(SEL_COMMAND,DirList::ID_SHOW_FILES,DirList::onCmdShowFiles),
-                                   FXMAPFUNC(SEL_COMMAND,DirList::ID_HIDE_FILES,DirList::onCmdHideFiles),
-                                   FXMAPFUNC(SEL_COMMAND,DirList::ID_TOGGLE_FILES,DirList::onCmdToggleFiles),
-                                   FXMAPFUNC(SEL_COMMAND,DirList::ID_SET_PATTERN,DirList::onCmdSetPattern),
-                                   FXMAPFUNC(SEL_COMMAND,DirList::ID_SORT_REVERSE,DirList::onCmdSortReverse),
-								   FXMAPFUNC(SEL_COMMAND,DirList::ID_REFRESH,DirList::onCmdRefresh),
-                               };
+	FXMAPFUNC(SEL_TIMEOUT,DirList::ID_EXPAND_TIMER,DirList::onExpandTimer),
+	FXMAPFUNC(SEL_DND_ENTER,0,DirList::onDNDEnter),
+	FXMAPFUNC(SEL_DND_LEAVE,0,DirList::onDNDLeave),
+	FXMAPFUNC(SEL_DND_DROP,0,DirList::onDNDDrop),
+	FXMAPFUNC(SEL_DND_MOTION,0,DirList::onDNDMotion),
+	FXMAPFUNC(SEL_DND_REQUEST,0,DirList::onDNDRequest),
+	FXMAPFUNC(SEL_BEGINDRAG,0,DirList::onBeginDrag),
+	FXMAPFUNC(SEL_ENDDRAG,0,DirList::onEndDrag),
+	FXMAPFUNC(SEL_OPENED,0,DirList::onOpened),
+	FXMAPFUNC(SEL_CLOSED,0,DirList::onClosed),
+	FXMAPFUNC(SEL_EXPANDED,0,DirList::onExpanded),
+	FXMAPFUNC(SEL_COLLAPSED,0,DirList::onCollapsed),
+	FXMAPFUNC(SEL_UPDATE,DirList::ID_SHOW_HIDDEN,DirList::onUpdShowHidden),
+	FXMAPFUNC(SEL_UPDATE,DirList::ID_HIDE_HIDDEN,DirList::onUpdHideHidden),
+	FXMAPFUNC(SEL_UPDATE,DirList::ID_TOGGLE_HIDDEN,DirList::onUpdToggleHidden),
+	FXMAPFUNC(SEL_UPDATE,DirList::ID_SHOW_FILES,DirList::onUpdShowFiles),
+	FXMAPFUNC(SEL_UPDATE,DirList::ID_HIDE_FILES,DirList::onUpdHideFiles),
+	FXMAPFUNC(SEL_UPDATE,DirList::ID_TOGGLE_FILES,DirList::onUpdToggleFiles),
+	FXMAPFUNC(SEL_UPDATE,DirList::ID_SET_PATTERN,DirList::onUpdSetPattern),
+	FXMAPFUNC(SEL_UPDATE,DirList::ID_SORT_REVERSE,DirList::onUpdSortReverse),
+	FXMAPFUNC(SEL_COMMAND,DirList::ID_SHOW_HIDDEN,DirList::onCmdShowHidden),
+	FXMAPFUNC(SEL_COMMAND,DirList::ID_DRAG_COPY,DirList::onCmdDragCopy),
+	FXMAPFUNC(SEL_COMMAND,DirList::ID_DRAG_MOVE,DirList::onCmdDragMove),
+	FXMAPFUNC(SEL_COMMAND,DirList::ID_DRAG_LINK,DirList::onCmdDragLink),
+	FXMAPFUNC(SEL_COMMAND,DirList::ID_DRAG_REJECT,DirList::onCmdDragReject),
+	FXMAPFUNC(SEL_COMMAND,DirList::ID_HIDE_HIDDEN,DirList::onCmdHideHidden),
+	FXMAPFUNC(SEL_COMMAND,DirList::ID_TOGGLE_HIDDEN,DirList::onCmdToggleHidden),
+	FXMAPFUNC(SEL_COMMAND,DirList::ID_SHOW_FILES,DirList::onCmdShowFiles),
+	FXMAPFUNC(SEL_COMMAND,DirList::ID_HIDE_FILES,DirList::onCmdHideFiles),
+	FXMAPFUNC(SEL_COMMAND,DirList::ID_TOGGLE_FILES,DirList::onCmdToggleFiles),
+	FXMAPFUNC(SEL_COMMAND,DirList::ID_SET_PATTERN,DirList::onCmdSetPattern),
+	FXMAPFUNC(SEL_COMMAND,DirList::ID_SORT_REVERSE,DirList::onCmdSortReverse),
+	FXMAPFUNC(SEL_COMMAND,DirList::ID_REFRESH,DirList::onCmdRefresh),
+};
 
 
 // Object implementation
@@ -186,6 +188,12 @@ DirList::DirList(FXComposite *p,FXObject* tgt,FXSelector sel,FXuint opts,FXint x
         }
     }
 #endif
+
+	// Trahscan location (without trailing slash)
+	FXString homelocation=getenv("HOME");
+    if(homelocation=="")
+        homelocation=ROOTDIR;
+	trashlocation=homelocation+PATHSEPSTRING+TRASHPATH;
 }
 
 
@@ -344,7 +352,10 @@ long DirList::onDNDMotion(FXObject* sender,FXSelector sel,void* ptr)
             // Set open up timer
             getApp()->addTimeout(this,ID_EXPAND_TIMER,EXPAND_INTERVAL);
 
-            // See if this is writable
+            // Set icon to open folder icon
+			setItemOpenIcon(item,minifolderopenicon);
+
+			// See if this is writable
             if(::isWritable(dropdirectory))
             {
                 acceptDrop(DRAG_ACCEPT);
@@ -407,21 +418,17 @@ long DirList::onCmdDragReject(FXObject* sender,FXSelector sel,void* ptr)
 // Handle drag-and-drop drop
 long DirList::onDNDDrop(FXObject* sender,FXSelector sel,void* ptr)
 {
-    FXuchar *data;
+     FXEvent *event=(FXEvent*)ptr;
+
+	FXuchar *data;
     FXuint len;
     FXbool showdialog=TRUE;
 	FXbool ret;
     File *f=NULL;
 
     FXbool ask_before_copy=getApp()->reg().readUnsignedEntry("OPTIONS","ask_before_copy",TRUE);
+    FXbool confirm_dnd=getApp()->reg().readUnsignedEntry("OPTIONS","confirm_drag_and_drop",TRUE);
 	
-	if(prevSelItem)
-    {
-        if(!isItemCurrent(prevSelItem))
-            closeItem(prevSelItem);
-        prevSelItem = NULL;
-    }
-
     // Cancel open up timer
     getApp()->removeTimeout(this,ID_EXPAND_TIMER);
 
@@ -431,24 +438,47 @@ long DirList::onDNDDrop(FXObject* sender,FXSelector sel,void* ptr)
     // Perhaps target wants to deal with it
     if(FXTreeList::onDNDDrop(sender,sel,ptr))
         return 1;
-
-	// Display a popup to select the drag type
-	dropaction=DRAG_REJECT;
-	FXMenuPane menu(this);
-    FXint x,y;
-    FXuint state;
-    getRoot()->getCursorPosition(x,y,state);
-   	new FXMenuCommand(&menu,_("Copy here"),copy_clpicon,this,DirList::ID_DRAG_COPY);
-   	new FXMenuCommand(&menu,_("Move here"),moveiticon,this,DirList::ID_DRAG_MOVE);
-   	new FXMenuCommand(&menu,_("Link here"),minilinkicon,this,DirList::ID_DRAG_LINK);
-	new FXMenuSeparator(&menu);
-   	new FXMenuCommand(&menu,_("Cancel"),NULL,this,DirList::ID_DRAG_REJECT);
-    menu.create();
-    allowPopupScroll=TRUE;  // Allow keyboard scrolling
-	menu.popup(NULL,x,y);
-	getApp()->runModalWhileShown(&menu);
-    allowPopupScroll=FALSE;
 	
+	// Check if control key or shift key were pressed
+	FXbool ctrlshiftkey=FALSE;
+	if (ptr!=NULL)
+	{
+		FXEvent* event=(FXEvent*)ptr;
+		if (event->state&CONTROLMASK)
+			ctrlshiftkey=TRUE;
+		if (event->state&SHIFTMASK)
+			ctrlshiftkey=TRUE;
+	}
+
+	// Display the dnd dialog if the control or shift key were not pressed
+	if (confirm_dnd & !ctrlshiftkey)
+	{
+		// Display a popup to select the drag type
+		dropaction=DRAG_REJECT;
+		FXMenuPane menu(this);
+		FXint x,y;
+		FXuint state;
+		getRoot()->getCursorPosition(x,y,state);
+		new FXMenuCommand(&menu,_("Copy here"),copy_clpicon,this,DirList::ID_DRAG_COPY);
+		new FXMenuCommand(&menu,_("Move here"),moveiticon,this,DirList::ID_DRAG_MOVE);
+		new FXMenuCommand(&menu,_("Link here"),minilinkicon,this,DirList::ID_DRAG_LINK);
+		new FXMenuSeparator(&menu);
+		new FXMenuCommand(&menu,_("Cancel"),NULL,this,DirList::ID_DRAG_REJECT);
+		menu.create();
+		allowPopupScroll=TRUE;  // Allow keyboard scrolling
+		menu.popup(NULL,x,y);
+		getApp()->runModalWhileShown(&menu);
+		allowPopupScroll=FALSE;
+	}
+
+	// Close item
+	if(prevSelItem)
+    {
+        if(!isItemCurrent(prevSelItem))
+            closeItem(prevSelItem);
+        prevSelItem = NULL;
+    }
+
     // Get uri-list of files being dropped
     if(getDNDData(FROM_DRAGNDROP,urilistType,data,len))
     {
@@ -489,9 +519,8 @@ long DirList::onDNDDrop(FXObject* sender,FXSelector sel,void* ptr)
             FXString target(targetdir+PATHSEPSTRING+FXPath::name(source));
             FXString sourcedir=FXPath::directory(source);
 
-            /*
-			// File operation dialog, if needed
-            if(ask_before_copy & showdialog)
+            // File operation dialog, if needed
+            if ((!confirm_dnd | ctrlshiftkey) & ask_before_copy & showdialog)
             {
                 FXIcon *icon=NULL;
                 FXString title,message;
@@ -513,30 +542,25 @@ long DirList::onDNDDrop(FXObject* sender,FXSelector sel,void* ptr)
                     else
                         message=_("Move ")+FXStringVal(num)+_(" files/folders.\nFrom: ")+sourcedir;
                 }
-                else if (dropaction==DRAG_LINK)
+                else if ((dropaction==DRAG_LINK) && (num==1))
                 {
                     title=_("Symlink ");
                     icon=link_bigicon;
-                    if (num==1)
-                        message=title+source;
-                    else
-                        message=_("Symlink ")+FXStringVal(num)+_(" files/folders.\nFrom: ")+sourcedir;
-				}
+					message=title+source;
+                }
 
-                // The target directory can be modified here
-                BrowseInputDialog* dialog = new BrowseInputDialog(this,targetdir,message,title,_("To:"),icon);
+                InputDialog* dialog = new InputDialog(this,targetdir,message,title,_("To:"),icon);
                 dialog->CursorEnd();
                 int rc=1;
                 rc=dialog->execute();
                 target=dialog->getText();
-                targetdir=::filePath(target);
+                target=::filePath(target);
                 if (num>1)
                     showdialog=FALSE;
                 delete dialog;
                 if (!rc)
                     return 0;
             }
-			*/
 
             // Move the source file
             if(dropaction==DRAG_MOVE)
@@ -1224,6 +1248,8 @@ void DirList::listChildItems(DirItem *par)
     FXString       directory;
     FXString       name;
     FXint          islink;
+	FXString type, mod, usrid, grpid, atts, del;
+	long deldate;
 
     // Path to parent node
     directory=getItemPathname((TreeItem*)par);
@@ -1253,7 +1279,7 @@ void DirList::listChildItems(DirItem *par)
 #endif
             // Get name of entry
             name=dp->d_name;
-
+			
             // A dot special file?
             if(name[0]=='.' && (name[1]==0 || (name[1]=='.' && name[2]==0)))
                 continue;
@@ -1416,12 +1442,43 @@ fnd:
             item->size=(unsigned long)info.st_size;
             item->assoc=fileassoc;
             item->date=info.st_mtime;
-            //item->date=filetime;
+
+			// Default folder type
+			type=_("Folder");
+
+			// Obtain user name
+			FXString usrid=FXSystem::userName(info.st_uid);
+
+			// Obtain group name
+			FXString grpid=FXSystem::groupName(info.st_gid);
+
+			// Permissions (caution : we don't use the FXSystem::modeString() function because
+			// it seems to be incompatible with the info.st_mode format)
+			FXString atts=::permissions(info.st_mode);
+			
+			// Modification time
+			mod=FXSystem::time("%x %X",item->date);
+
+			// If we are in trash can, obtain the deletion time
+			deldate=0;
+			del="";
+			if (FXPath::directory(pathname)==trashlocation)
+			{
+				char *endptr;
+				FXString str;
+				str=pathname.rafter('_');
+				str=str.rbefore('-');
+				deldate=strtol(str.text(),&endptr,10);
+				if (deldate!=0)
+					del=FXSystem::time("%x %X",deldate);
+			}
 
 #if defined(linux)
             // Devices have a specific icon
             if(fsdevices->find(pathname.text()))
             {
+				type=_("Mount point");
+				
                 if(::streq(fsdevices->find(pathname.text()),"harddisk"))
                 {
                     item->closedIcon=harddiskicon;
@@ -1458,10 +1515,16 @@ fnd:
             // Symbolic links have a specific icon
             if(islink)
             {
-                item->closedIcon=minilinkicon;
+                type=_("Link to Folder");
+				item->closedIcon=minilinkicon;
                 item->openIcon=minilinkicon;
             }
 
+			// Data passed to the item->data pointer and used to update the tooltip
+			FXString strdata=item->label+"\t"+type+"\t"+mod+"\t"+usrid+"\t"+grpid+"\t"+atts+"\t"+del+"\t"+pathname;
+			FXMALLOC(&item->data,FXchar,strdata.length()+1);
+			memcpy(item->data,strdata.text(),strdata.length()+1);	
+
             // Create item
             if(id())
                 item->create();
@@ -1476,6 +1539,7 @@ fnd:
     {
         link=item->link;
         removeItem(item,TRUE);
+		FXFREE(&item->data);
     }
 
     // Now we know for sure whether we really have subitems or not
