@@ -39,52 +39,297 @@ extern FXbool single_click_diropen;
 extern FXbool single_click_fileopen;
 
 
+
+// Dirty hack to change the KEY_up and KEY_down behaviour
+// These keys are no more associated with the mouse click action
+#define SELECT_MASK (TREELIST_SINGLESELECT|TREELIST_BROWSESELECT)
+FXbool fromKeyPress=FALSE;
+long FXTreeList::onKeyPress(FXObject*,FXSelector,void* ptr)
+{
+    FXEvent* event=(FXEvent*)ptr;
+    FXTreeItem *item=currentitem;
+    FXTreeItem *succ;
+    FXint page;
+    flags&=~FLAG_TIP;
+    if (!isEnabled())
+		return 0;
+    if (target && target->tryHandle(this,FXSEL(SEL_KEYPRESS,message),ptr))
+		return 1;
+    if (item==NULL) item=firstitem;
+    switch (event->code)
+    {
+    case KEY_Control_L:
+    case KEY_Control_R:
+    case KEY_Shift_L:
+    case KEY_Shift_R:
+    case KEY_Alt_L:
+    case KEY_Alt_R:
+        if (flags&FLAG_DODRAG)
+            handle(this,FXSEL(SEL_DRAGGED,0),ptr);
+        return 1;
+    case KEY_Page_Up:
+    case KEY_KP_Page_Up:
+        for (succ=item,page=verticalScrollBar()->getPage(); succ && 0<page; )
+        {
+            item=succ;
+            page-=succ->getHeight(this);
+            if (succ->prev)
+            {
+                succ=succ->prev;
+                while (succ->last && ((options&TREELIST_AUTOSELECT) || succ->isExpanded())) succ=succ->last;
+            }
+            else if (succ->parent)
+                succ=succ->parent;
+        }
+        goto hop;
+    case KEY_Page_Down:
+    case KEY_KP_Page_Down:
+        for (succ=item,page=verticalScrollBar()->getPage(); succ && 0<page; )
+        {
+            item=succ;
+            page-=succ->getHeight(this);
+            if (succ->first && ((options&TREELIST_AUTOSELECT) || succ->isExpanded()))
+                succ=succ->first;
+            else
+            {
+                while (!succ->next && succ->parent) succ=succ->parent;
+                succ=succ->next;
+            }
+        }
+        goto hop;
+    case KEY_Up:                          // Move up
+    case KEY_KP_Up:
+        if (item)
+        {
+            if (item->prev)
+            {
+                item=item->prev;
+                while (item->last && ((options&TREELIST_AUTOSELECT) || item->isExpanded())) item=item->last;
+            }
+            else if (item->parent)
+                item=item->parent;
+        }
+        goto hop;
+    case KEY_Down:                        // Move down
+    case KEY_KP_Down:
+        if (item)
+        {
+            if (item->first && ((options&TREELIST_AUTOSELECT) || item->isExpanded()))
+                item=item->first;
+            else
+            {
+                while (!item->next && item->parent) item=item->parent;
+                item=item->next;
+            }
+        }
+        goto hop;
+    case KEY_Right:                       // Move right/down and open subtree
+    case KEY_KP_Right:
+        if (item)
+        {
+            if (!(options&TREELIST_AUTOSELECT) && !item->isExpanded() && (item->hasItems() || item->getFirst()))
+                expandTree(item,TRUE);
+            else if (item->first)
+                item=item->first;
+            else
+            {
+                while (!item->next && item->parent) item=item->parent;
+                item=item->next;
+            }
+        }
+        goto hop;
+    case KEY_Left:                        // Move left/up and close subtree
+    case KEY_KP_Left:
+        if (item)
+        {
+            if (!(options&TREELIST_AUTOSELECT) && item->isExpanded() && (item->hasItems() || item->getFirst()))
+                collapseTree(item,TRUE);
+            else if (item->parent)
+                item=item->parent;
+            else if (item->prev)
+                item=item->prev;
+        }
+        goto hop;
+    case KEY_Home:                        // Move to first
+    case KEY_KP_Home:
+        item=firstitem;
+        goto hop;
+    case KEY_End:                         // Move to last
+    case KEY_KP_End:
+        item=lastitem;
+        while (item)
+        {
+            if (item->last && ((options&TREELIST_AUTOSELECT) || item->isExpanded()))
+                item=item->last;
+            else if (item->next)
+                item=item->next;
+            else
+                break;
+        }
+hop:
+        lookup=FXString::null;
+        if (item)
+        {
+            setCurrentItem(item,TRUE);
+            makeItemVisible(item);
+            if ((options&SELECT_MASK)==TREELIST_EXTENDEDSELECT)
+            {
+                if (item->isEnabled())
+                {
+                    if (event->state&SHIFTMASK)
+                    {
+                        if (anchoritem)
+                        {
+                            selectItem(anchoritem,TRUE);
+                            extendSelection(item,TRUE);
+                        }
+                        else
+                        {
+                            selectItem(item,TRUE);
+                            setAnchorItem(item);
+                        }
+                    }
+                    else if (!(event->state&CONTROLMASK))
+                    {
+                        killSelection(TRUE);
+                        selectItem(item,TRUE);
+                        setAnchorItem(item);
+                    }
+                }
+            }
+        }
+
+        //!!!! Hack to change the KEY_up and KEY_down behaviour !!!
+		fromKeyPress=TRUE;
+		// !!!! End of hack !!!
+		handle(this,FXSEL(SEL_CLICKED,0),(void*)currentitem);
+		
+        if (currentitem && currentitem->isEnabled())
+            handle(this,FXSEL(SEL_COMMAND,0),(void*)currentitem);
+        return 1;
+    case KEY_space:
+    case KEY_KP_Space:
+        lookup=FXString::null;
+        if (item && item->isEnabled())
+        {
+            switch (options&SELECT_MASK)
+            {
+            case TREELIST_EXTENDEDSELECT:
+                if (event->state&SHIFTMASK)
+                {
+                    if (anchoritem)
+                    {
+                        selectItem(anchoritem,TRUE);
+                        extendSelection(item,TRUE);
+                    }
+                    else
+                        selectItem(item,TRUE);
+                }
+                else if (event->state&CONTROLMASK)
+                    toggleItem(item,TRUE);
+                else
+                {
+                    killSelection(TRUE);
+                    selectItem(item,TRUE);
+                }
+                break;
+            case TREELIST_MULTIPLESELECT:
+            case TREELIST_SINGLESELECT:
+                toggleItem(item,TRUE);
+                break;
+            }
+            setAnchorItem(item);
+        }
+        handle(this,FXSEL(SEL_CLICKED,0),(void*)currentitem);
+        if (currentitem && currentitem->isEnabled())
+            handle(this,FXSEL(SEL_COMMAND,0),(void*)currentitem);
+        return 1;
+    case KEY_Return:
+    case KEY_KP_Enter:
+        lookup=FXString::null;
+        handle(this,FXSEL(SEL_DOUBLECLICKED,0),(void*)currentitem);
+        if (currentitem && currentitem->isEnabled())
+            handle(this,FXSEL(SEL_COMMAND,0),(void*)currentitem);
+        return 1;
+    default:
+        if ((FXuchar)event->text[0]<' ')
+			return 0;
+        if (event->state&(CONTROLMASK|ALTMASK))
+			return 0;
+        if (!Ascii::isPrint(event->text[0]))
+			return 0;
+        lookup.append(event->text);
+        getApp()->addTimeout(this,ID_LOOKUPTIMER,getApp()->getTypingSpeed());
+        item=findItem(lookup,currentitem,SEARCH_FORWARD|SEARCH_WRAP|SEARCH_PREFIX);
+        if (item)
+        {
+            setCurrentItem(item,TRUE);
+            makeItemVisible(item);
+            if ((options&SELECT_MASK)==TREELIST_EXTENDEDSELECT)
+            {
+                if (item->isEnabled())
+                {
+                    killSelection(TRUE);
+                    selectItem(item,TRUE);
+                }
+            }
+            setAnchorItem(item);
+        }
+        handle(this,FXSEL(SEL_CLICKED,0),(void*)currentitem);
+        if (currentitem && currentitem->isEnabled())
+            handle(this,FXSEL(SEL_COMMAND,0),(void*)currentitem);
+        return 1;
+    }
+    return 0;
+}
+
+
 // Map
 FXDEFMAP(DirPanel) DirPanelMap[]={
-								   FXMAPFUNC(SEL_CLIPBOARD_LOST,0,DirPanel::onClipboardLost),
-								   FXMAPFUNC(SEL_CLIPBOARD_GAINED,0,DirPanel::onClipboardGained),
-								   FXMAPFUNC(SEL_CLIPBOARD_REQUEST,0,DirPanel::onClipboardRequest),
-                                   FXMAPFUNC(SEL_COMMAND,DirPanel::ID_EXPANDTREE,DirPanel::onExpandTree),
-                                   FXMAPFUNC(SEL_COMMAND,DirPanel::ID_COLLAPSETREE,DirPanel::onCollapseTree),
-                                   FXMAPFUNC(SEL_COMMAND,DirPanel::ID_PROPERTIES,DirPanel::onCmdProperties),
-                                   FXMAPFUNC(SEL_COMMAND,DirPanel::ID_ARCHIVE,DirPanel::onCmdAddToArch),
-                                   FXMAPFUNC(SEL_RIGHTBUTTONRELEASE,DirPanel::ID_FILELIST,DirPanel::onPopupMenu),
-                               	   FXMAPFUNC(SEL_CLICKED,DirPanel::ID_FILELIST,DirPanel::onCmdDirectory),
-                               	   FXMAPFUNC(SEL_EXPANDED,DirPanel::ID_FILELIST,DirPanel::onExpand),
-                                   FXMAPFUNC(SEL_COMMAND,DirPanel::ID_COPY_CLIPBOARD,DirPanel::onCmdCopyCut),
-                                   FXMAPFUNC(SEL_COMMAND,DirPanel::ID_CUT_CLIPBOARD,DirPanel::onCmdCopyCut),
-                                   FXMAPFUNC(SEL_COMMAND,DirPanel::ID_PASTE_CLIPBOARD,DirPanel::onCmdPaste),
-                               	   FXMAPFUNC(SEL_COMMAND,DirPanel::ID_DIR_COPY,DirPanel::onCmdDirMan),
-                               	   FXMAPFUNC(SEL_COMMAND,DirPanel::ID_DIR_CUT,DirPanel::onCmdDirMan),
-                                   FXMAPFUNC(SEL_COMMAND,DirPanel::ID_DIR_COPYTO,DirPanel::onCmdDirMan),
-                                   FXMAPFUNC(SEL_COMMAND,DirPanel::ID_DIR_MOVE,DirPanel::onCmdDirMan),
-                                   FXMAPFUNC(SEL_COMMAND,DirPanel::ID_DIR_RENAME,DirPanel::onCmdDirMan),
-                                   FXMAPFUNC(SEL_COMMAND,DirPanel::ID_DIR_SYMLINK,DirPanel::onCmdDirMan),
-                                   FXMAPFUNC(SEL_COMMAND,DirPanel::ID_DIR_DELETE,DirPanel::onCmdDirDelete),
-                                   FXMAPFUNC(SEL_COMMAND,DirPanel::ID_DIR_TRASH,DirPanel::onCmdDirTrash),
-                                   FXMAPFUNC(SEL_COMMAND,DirPanel::ID_NEW_DIR,DirPanel::onCmdNewDir),
-                                   FXMAPFUNC(SEL_COMMAND,DirPanel::ID_XTERM,DirPanel::onCmdXTerm),
-                                   FXMAPFUNC(SEL_COMMAND,DirPanel::ID_TOGGLE_HIDDEN,DirPanel::onCmdToggleHidden),
-                                   FXMAPFUNC(SEL_COMMAND,DirPanel::ID_TOGGLE_TREE,DirPanel::onCmdToggleTree),
-                                   FXMAPFUNC(SEL_TIMEOUT,DirPanel::ID_DIRSIZE_REFRESH,DirPanel::onCmdDirsizeRefresh),
+	FXMAPFUNC(SEL_CLIPBOARD_LOST,0,DirPanel::onClipboardLost),
+	FXMAPFUNC(SEL_CLIPBOARD_GAINED,0,DirPanel::onClipboardGained),
+	FXMAPFUNC(SEL_CLIPBOARD_REQUEST,0,DirPanel::onClipboardRequest),
+	FXMAPFUNC(SEL_COMMAND,DirPanel::ID_EXPANDTREE,DirPanel::onExpandTree),
+	FXMAPFUNC(SEL_COMMAND,DirPanel::ID_COLLAPSETREE,DirPanel::onCollapseTree),
+	FXMAPFUNC(SEL_COMMAND,DirPanel::ID_PROPERTIES,DirPanel::onCmdProperties),
+	FXMAPFUNC(SEL_COMMAND,DirPanel::ID_ARCHIVE,DirPanel::onCmdAddToArch),
+	FXMAPFUNC(SEL_RIGHTBUTTONRELEASE,DirPanel::ID_FILELIST,DirPanel::onPopupMenu),
+	FXMAPFUNC(SEL_CLICKED,DirPanel::ID_FILELIST,DirPanel::onCmdDirectory),
+	FXMAPFUNC(SEL_EXPANDED,DirPanel::ID_FILELIST,DirPanel::onExpand),
+	FXMAPFUNC(SEL_COMMAND,DirPanel::ID_COPY_CLIPBOARD,DirPanel::onCmdCopyCut),
+	FXMAPFUNC(SEL_COMMAND,DirPanel::ID_CUT_CLIPBOARD,DirPanel::onCmdCopyCut),
+	FXMAPFUNC(SEL_COMMAND,DirPanel::ID_PASTE_CLIPBOARD,DirPanel::onCmdPaste),
+	FXMAPFUNC(SEL_COMMAND,DirPanel::ID_DIR_COPY,DirPanel::onCmdDirMan),
+	FXMAPFUNC(SEL_COMMAND,DirPanel::ID_DIR_CUT,DirPanel::onCmdDirMan),
+	FXMAPFUNC(SEL_COMMAND,DirPanel::ID_DIR_COPYTO,DirPanel::onCmdDirMan),
+	FXMAPFUNC(SEL_COMMAND,DirPanel::ID_DIR_MOVE,DirPanel::onCmdDirMan),
+	FXMAPFUNC(SEL_COMMAND,DirPanel::ID_DIR_RENAME,DirPanel::onCmdDirMan),
+	FXMAPFUNC(SEL_COMMAND,DirPanel::ID_DIR_SYMLINK,DirPanel::onCmdDirMan),
+	FXMAPFUNC(SEL_COMMAND,DirPanel::ID_DIR_DELETE,DirPanel::onCmdDirDelete),
+	FXMAPFUNC(SEL_COMMAND,DirPanel::ID_DIR_TRASH,DirPanel::onCmdDirTrash),
+	FXMAPFUNC(SEL_COMMAND,DirPanel::ID_NEW_DIR,DirPanel::onCmdNewDir),
+	FXMAPFUNC(SEL_COMMAND,DirPanel::ID_XTERM,DirPanel::onCmdXTerm),
+	FXMAPFUNC(SEL_COMMAND,DirPanel::ID_TOGGLE_HIDDEN,DirPanel::onCmdToggleHidden),
+	FXMAPFUNC(SEL_COMMAND,DirPanel::ID_TOGGLE_TREE,DirPanel::onCmdToggleTree),
+	FXMAPFUNC(SEL_TIMEOUT,DirPanel::ID_DIRSIZE_REFRESH,DirPanel::onCmdDirsizeRefresh),
 #if defined(linux)
-                                   FXMAPFUNC(SEL_COMMAND,DirPanel::ID_MOUNT,DirPanel::onCmdMount),
-                                   FXMAPFUNC(SEL_COMMAND,DirPanel::ID_UMOUNT,DirPanel::onCmdMount),
-                               	   FXMAPFUNC(SEL_UPDATE,DirPanel::ID_MOUNT,DirPanel::onUpdMount),
-                                   FXMAPFUNC(SEL_UPDATE,DirPanel::ID_UMOUNT,DirPanel::onUpdUnmount),
+	FXMAPFUNC(SEL_COMMAND,DirPanel::ID_MOUNT,DirPanel::onCmdMount),
+	FXMAPFUNC(SEL_COMMAND,DirPanel::ID_UMOUNT,DirPanel::onCmdMount),
+	FXMAPFUNC(SEL_UPDATE,DirPanel::ID_MOUNT,DirPanel::onUpdMount),
+	FXMAPFUNC(SEL_UPDATE,DirPanel::ID_UMOUNT,DirPanel::onUpdUnmount),
 #endif
-                               	   FXMAPFUNC(SEL_UPDATE,DirPanel::ID_PASTE_CLIPBOARD,DirPanel::onUpdPaste),
-                                   FXMAPFUNC(SEL_UPDATE,DirPanel::ID_TOGGLE_HIDDEN,DirPanel::onUpdToggleHidden),
-                                   FXMAPFUNC(SEL_UPDATE,DirPanel::ID_TOGGLE_TREE,DirPanel::onUpdToggleTree),
-                                   FXMAPFUNC(SEL_UPDATE,DirPanel::ID_CUT_CLIPBOARD,DirPanel::onUpdMenu),
-                                   FXMAPFUNC(SEL_UPDATE,DirPanel::ID_ARCHIVE,DirPanel::onUpdMenu),
-                                   FXMAPFUNC(SEL_UPDATE,DirPanel::ID_DIR_MOVE,DirPanel::onUpdMenu),
-                                   FXMAPFUNC(SEL_UPDATE,DirPanel::ID_DIR_RENAME,DirPanel::onUpdMenu),
-                                   FXMAPFUNC(SEL_UPDATE,DirPanel::ID_DIR_TRASH,DirPanel::onUpdDirTrash),
-                                   FXMAPFUNC(SEL_UPDATE,DirPanel::ID_DIR_DELETE,DirPanel::onUpdDirDelete),
-                                   FXMAPFUNC(SEL_UPDATE,DirPanel::ID_NEW_DIR,DirPanel::onUpdMenu),
-                                   FXMAPFUNC(SEL_UPDATE,DirPanel::ID_TITLE,DirPanel::onUpdTitle),
-                          		};
+	FXMAPFUNC(SEL_UPDATE,DirPanel::ID_PASTE_CLIPBOARD,DirPanel::onUpdPaste),
+	FXMAPFUNC(SEL_UPDATE,DirPanel::ID_TOGGLE_HIDDEN,DirPanel::onUpdToggleHidden),
+	FXMAPFUNC(SEL_UPDATE,DirPanel::ID_TOGGLE_TREE,DirPanel::onUpdToggleTree),
+	FXMAPFUNC(SEL_UPDATE,DirPanel::ID_CUT_CLIPBOARD,DirPanel::onUpdMenu),
+	FXMAPFUNC(SEL_UPDATE,DirPanel::ID_ARCHIVE,DirPanel::onUpdMenu),
+	FXMAPFUNC(SEL_UPDATE,DirPanel::ID_DIR_MOVE,DirPanel::onUpdMenu),
+	FXMAPFUNC(SEL_UPDATE,DirPanel::ID_DIR_RENAME,DirPanel::onUpdMenu),
+	FXMAPFUNC(SEL_UPDATE,DirPanel::ID_DIR_TRASH,DirPanel::onUpdDirTrash),
+	FXMAPFUNC(SEL_UPDATE,DirPanel::ID_DIR_DELETE,DirPanel::onUpdDirDelete),
+	FXMAPFUNC(SEL_UPDATE,DirPanel::ID_NEW_DIR,DirPanel::onUpdMenu),
+	FXMAPFUNC(SEL_UPDATE,DirPanel::ID_TITLE,DirPanel::onUpdTitle),
+};
 
 // Object implementation 
 FXIMPLEMENT(DirPanel,FXVerticalFrame,DirPanelMap,ARRAYNUMBER(DirPanelMap))
@@ -213,17 +458,19 @@ long DirPanel::onCmdDirectory(FXObject*,FXSelector,void* ptr)
     }
 
 	// Manage single click navigation
-	if (item && single_click_diropen)
+	if (item && single_click_diropen && !fromKeyPress)
 	{
 		//if (item->isExpanded())
 			//list->handle(this,FXSEL(SEL_COLLAPSED,0),(void*)ptr);
 		//else
 			list->handle(this,FXSEL(SEL_EXPANDED,0),(void*)ptr);
 	}
+	fromKeyPress=FALSE;
 		
     return 1;
 }
 
+
 // Toggle hidden files
 long DirPanel::onCmdToggleHidden(FXObject*,FXSelector,void*)
 {
@@ -1244,6 +1491,8 @@ long DirPanel::onCmdDirDelete(FXObject*,FXSelector,void*)
     }
 
     FXbool confirm_del=getApp()->reg().readUnsignedEntry("OPTIONS","confirm_delete",TRUE);
+    FXbool confirm_del_emptydir=getApp()->reg().readUnsignedEntry("OPTIONS","confirm_delete_emptydir",TRUE);
+
 	if(confirm_del)
     {
 		FXString message=_("Definitively delete folder ") + pathname + " ?";
@@ -1256,11 +1505,27 @@ long DirPanel::onCmdDirDelete(FXObject*,FXSelector,void*)
    	File* f=new File(this,_("File delete"),DELETE);
    	f->create();
 
+	// Confirm empty directory deletion
+	if (confirm_del & confirm_del_emptydir)
+	{
+		if (::isEmptyDir(pathname)==0)
+		{
+			// Dialog to confirm file deletion
+			f->allowProgressDialog=FALSE;
+			f->hide();
+
+			FXString message=_("Folder ") + pathname + _(" is not empty, delete it anyway?");
+			MessageBox box(this,_("Confirm Delete"),message,delete_big_permicon,BOX_YES_NO|DECOR_TITLE|DECOR_BORDER);
+			if(box.execute(PLACEMENT_CURSOR) == BOX_CLICKED_NO)
+				goto end;
+		}
+	}
+
     // If we don't have permission to write to the directory
  	if (!::isWritable(pathname))
     {
 		// Dialog to confirm directory deletion
-		f->allowPdialog=FALSE;
+		f->allowProgressDialog=FALSE;
 		f->hide();
 		FXString str=_("Folder ") + pathname + _(" is write-protected, definitively delete it anyway?");
 		MessageBox box(this,_("Confirm Delete"),str,errorbigicon,BOX_OK_CANCEL|DECOR_TITLE|DECOR_BORDER);        	
@@ -1297,6 +1562,7 @@ long DirPanel::onCmdDirDelete(FXObject*,FXSelector,void*)
 		((XFileExplorer*) mainWindow)->lpanel->current->updatePathLinker();
 	}
 
+end:
 	delete f;
 
 	// Force DirPanel and FilePanel refresh
@@ -1324,6 +1590,8 @@ long DirPanel::onCmdDirTrash(FXObject*,FXSelector,void*)
     }
 
     FXbool confirm_del=getApp()->reg().readUnsignedEntry("OPTIONS","confirm_delete",TRUE);
+    FXbool confirm_del_emptydir=getApp()->reg().readUnsignedEntry("OPTIONS","confirm_delete_emptydir",TRUE);
+
 	if(confirm_del)
     {
 		FXString message=_("Move folder ") + pathname + " to trash can?";
@@ -1336,11 +1604,27 @@ long DirPanel::onCmdDirTrash(FXObject*,FXSelector,void*)
    	File* f=new File(this,_("Move to trash"),DELETE);
    	f->create();
 
+	// Confirm empty directory deletion
+	if (confirm_del & confirm_del_emptydir)
+	{
+		if (::isEmptyDir(pathname)==0)
+		{
+			// Dialog to confirm file deletion
+			f->allowProgressDialog=FALSE;
+			f->hide();
+
+			FXString message=_("Folder ") + pathname + _(" is not empty, move it anyway to trash can?");
+			MessageBox box(this,_("Confirm Trash"),message,delete_bigicon,BOX_YES_NO|DECOR_TITLE|DECOR_BORDER);
+			if(box.execute(PLACEMENT_CURSOR) == BOX_CLICKED_NO)
+				goto end;
+		}
+	}
+
     // If we don't have permission to write to the directory
  	if (!::isWritable(pathname))
     {
 		// Dialog to confirm directory deletion
-		f->allowPdialog=FALSE;
+		f->allowProgressDialog=FALSE;
 		f->hide();
 		FXString str=_("Folder ") + pathname + _(" is write-protected, move it to trash can anyway?");
 		MessageBox box(this,_("Confirm Trash"),str,errorbigicon,BOX_OK_CANCEL|DECOR_TITLE|DECOR_BORDER);        	
@@ -1355,7 +1639,7 @@ long DirPanel::onCmdDirTrash(FXObject*,FXSelector,void*)
 				MessageBox box(this,_("Delete from trash can"),message,delete_big_permicon,BOX_OK_CANCEL|DECOR_TITLE|DECOR_BORDER);
 				if(box.execute(PLACEMENT_CURSOR) == BOX_CLICKED_OK)
 					f->remove(pathname);
-				f->allowPdialog=TRUE;
+				f->allowProgressDialog=TRUE;
 			}
 			else
 			{
@@ -1391,13 +1675,13 @@ long DirPanel::onCmdDirTrash(FXObject*,FXSelector,void*)
 		// Folder is in the trash can
 		if (pathname.find(trashlocation.text())==0)
 		{
-			f->allowPdialog=FALSE;
+			f->allowProgressDialog=FALSE;
 			f->hide();
 			FXString message=_("Folder is already in the trash can! Definitively delete folder ") + pathname + " ?";
        		MessageBox box(this,_("Delete from trash can"),message,delete_big_permicon,BOX_OK_CANCEL|DECOR_TITLE|DECOR_BORDER);
 			if(box.execute(PLACEMENT_CURSOR) == BOX_CLICKED_OK)
 				f->remove(pathname);
-			f->allowPdialog=TRUE;
+			f->allowProgressDialog=TRUE;
 		}
 		else
 		{
@@ -1426,6 +1710,7 @@ long DirPanel::onCmdDirTrash(FXObject*,FXSelector,void*)
 		((XFileExplorer*) mainWindow)->lpanel->current->updatePathLinker();
 	}
 
+end:
 	delete f;
 
 	// Force DirPanel and FilePanel refresh
@@ -1703,8 +1988,8 @@ long DirPanel::onUpdDirTrash(FXObject* o,FXSelector,void*)
 // Refresh the directory size in the status bar
 long DirPanel::onCmdDirsizeRefresh(FXObject* sender,FXSelector,void*)
 {
-	unsigned long long dsize;
-	char size[64];
+	unsigned long long dnsize;
+	char dsize[64];
 	FXString hsize;
 	
 	// Name of the current selected item
@@ -1722,11 +2007,11 @@ long DirPanel::onCmdDirsizeRefresh(FXObject* sender,FXSelector,void*)
 
 	// Size of the files present in the directory
 	//strlcpy(buf,path.text(),path.length()+1);
-	dsize=::dirsize(path.text());
+	dnsize=::dirsize(path.text());
 
 	// Size in human readable form
-	snprintf(size,sizeof(size)-1,"%llu",dsize);
-	hsize=::hSize(size);
+	snprintf(dsize,sizeof(dsize)-1,"%llu",dnsize);
+	hsize=::hSize(dsize);
 
 	// Refresh the status label
 	FXString string = hsize +  _(" in root");
