@@ -99,8 +99,9 @@ public:
 	long onUpdTitle(FXObject*,FXSelector,void*);
 	long onUpdStatus(FXObject*,FXSelector,void*);
 	long onExpand(FXObject*,FXSelector,void*);
+	long onKeyPress(FXObject*,FXSelector,void*);
 #if defined(linux)
-	long onCmdMount(FXObject*,FXSelector sel,void*);
+	long onCmdMount(FXObject*,FXSelector,void*);
 #endif
 };
 #endif
