@@ -128,13 +128,52 @@ void FXTextReplace::redo()
 
 // Preferences class
 
+// Map
+FXDEFMAP(Preferences) PreferencesMap[]=
+{
+	FXMAPFUNC(SEL_COMMAND,Preferences::ID_ACCEPT,Preferences::onCmdAccept),
+	FXMAPFUNC(SEL_COMMAND,Preferences::ID_CANCEL,Preferences::onCmdCancel),
+	FXMAPFUNC(SEL_COMMAND,Preferences::ID_WHEELADJUST,Preferences::onCmdWheelAdjust),
+	FXMAPFUNC(SEL_UPDATE,Preferences::ID_WHEELADJUST,Preferences::onUpdWheelAdjust),
+	FXMAPFUNC(SEL_COMMAND,Preferences::ID_TEXT_BACK,Preferences::onCmdTextBackColor),
+	FXMAPFUNC(SEL_CHANGED,Preferences::ID_TEXT_BACK,Preferences::onCmdTextBackColor),
+	FXMAPFUNC(SEL_UPDATE,Preferences::ID_TEXT_BACK,Preferences::onUpdTextBackColor),
+	FXMAPFUNC(SEL_COMMAND,Preferences::ID_TEXT_FORE,Preferences::onCmdTextForeColor),
+	FXMAPFUNC(SEL_CHANGED,Preferences::ID_TEXT_FORE,Preferences::onCmdTextForeColor),
+	FXMAPFUNC(SEL_UPDATE,Preferences::ID_TEXT_FORE,Preferences::onUpdTextForeColor),
+	FXMAPFUNC(SEL_COMMAND,Preferences::ID_TEXT_SELBACK,Preferences::onCmdTextSelBackColor),
+	FXMAPFUNC(SEL_CHANGED,Preferences::ID_TEXT_SELBACK,Preferences::onCmdTextSelBackColor),
+	FXMAPFUNC(SEL_UPDATE,Preferences::ID_TEXT_SELBACK,Preferences::onUpdTextSelBackColor),
+	FXMAPFUNC(SEL_COMMAND,Preferences::ID_TEXT_SELFORE,Preferences::onCmdTextSelForeColor),
+	FXMAPFUNC(SEL_CHANGED,Preferences::ID_TEXT_SELFORE,Preferences::onCmdTextSelForeColor),
+	FXMAPFUNC(SEL_UPDATE,Preferences::ID_TEXT_SELFORE,Preferences::onUpdTextSelForeColor),
+	FXMAPFUNC(SEL_COMMAND,Preferences::ID_TEXT_HILITEBACK,Preferences::onCmdTextHiliteBackColor),
+	FXMAPFUNC(SEL_CHANGED,Preferences::ID_TEXT_HILITEBACK,Preferences::onCmdTextHiliteBackColor),
+	FXMAPFUNC(SEL_UPDATE,Preferences::ID_TEXT_HILITEBACK,Preferences::onUpdTextHiliteBackColor),
+	FXMAPFUNC(SEL_COMMAND,Preferences::ID_TEXT_HILITEFORE,Preferences::onCmdTextHiliteForeColor),
+	FXMAPFUNC(SEL_CHANGED,Preferences::ID_TEXT_HILITEFORE,Preferences::onCmdTextHiliteForeColor),
+	FXMAPFUNC(SEL_UPDATE,Preferences::ID_TEXT_HILITEFORE,Preferences::onUpdTextHiliteForeColor),
+	FXMAPFUNC(SEL_COMMAND,Preferences::ID_TEXT_CURSOR,Preferences::onCmdTextCursorColor),
+	FXMAPFUNC(SEL_CHANGED,Preferences::ID_TEXT_CURSOR,Preferences::onCmdTextCursorColor),
+	FXMAPFUNC(SEL_UPDATE,Preferences::ID_TEXT_CURSOR,Preferences::onUpdTextCursorColor),
+	FXMAPFUNC(SEL_COMMAND,Preferences::ID_TEXT_NUMBACK,Preferences::onCmdTextBarColor),
+	FXMAPFUNC(SEL_CHANGED,Preferences::ID_TEXT_NUMBACK,Preferences::onCmdTextBarColor),
+	FXMAPFUNC(SEL_UPDATE,Preferences::ID_TEXT_NUMBACK,Preferences::onUpdTextBarColor),
+	FXMAPFUNC(SEL_COMMAND,Preferences::ID_TEXT_NUMFORE,Preferences::onCmdTextNumberColor),
+	FXMAPFUNC(SEL_CHANGED,Preferences::ID_TEXT_NUMFORE,Preferences::onCmdTextNumberColor),
+	FXMAPFUNC(SEL_UPDATE,Preferences::ID_TEXT_NUMFORE,Preferences::onUpdTextNumberColor),
+};
+
 // Object implementation
-FXIMPLEMENT(Preferences,DialogBox,NULL,0)
+FXIMPLEMENT(Preferences,DialogBox,PreferencesMap,ARRAYNUMBER(PreferencesMap))
 
 // Construct
 Preferences::Preferences(EditWindow *owner):DialogBox(owner,_("XFileWrite Preferences"),DECOR_TITLE|DECOR_BORDER)
 {
-
+	// Get the editor text widget from the owner
+	editwin=owner;
+	editor=owner->getEditor();
+	
     // Set title
     setTitle(_("XFileWrite Preferences"));
 
@@ -145,11 +184,11 @@ Preferences::Preferences(EditWindow *owner):DialogBox(owner,_("XFileWrite Prefer
     FXHorizontalFrame *contents=new FXHorizontalFrame(this,LAYOUT_SIDE_TOP|FRAME_NONE|LAYOUT_FILL_X|LAYOUT_FILL_Y|PACK_UNIFORM_WIDTH);
 
     // Accept
-    FXButton *ok = new FXButton(buttons,_("&Accept"),NULL,this,DialogBox::ID_ACCEPT,FRAME_RAISED|FRAME_THICK|LAYOUT_RIGHT|LAYOUT_CENTER_Y,0,0,0,0,20,20);
+    FXButton *ok = new FXButton(buttons,_("&Accept"),NULL,this,Preferences::ID_ACCEPT,FRAME_RAISED|FRAME_THICK|LAYOUT_RIGHT|LAYOUT_CENTER_Y,0,0,0,0,20,20);
     ok->addHotKey(KEY_Return);
 
     // Cancel
-    new FXButton(buttons,_("&Cancel"),NULL,this,DialogBox::ID_CANCEL,FRAME_RAISED|FRAME_THICK|LAYOUT_RIGHT|LAYOUT_CENTER_Y,0,0,0,0,20,20);
+    new FXButton(buttons,_("&Cancel"),NULL,this,Preferences::ID_CANCEL,FRAME_RAISED|FRAME_THICK|LAYOUT_RIGHT|LAYOUT_CENTER_Y,0,0,0,0,20,20);
 
     // Switcher
     FXTabBook *tabbook = new FXTabBook(contents,NULL,0,LAYOUT_FILL_X|LAYOUT_FILL_Y|LAYOUT_RIGHT);
@@ -161,18 +200,24 @@ Preferences::Preferences(EditWindow *owner):DialogBox(owner,_("XFileWrite Prefer
     FXMatrix *matrix = new FXMatrix(group,2,MATRIX_BY_COLUMNS|LAYOUT_SIDE_TOP|LAYOUT_FILL_X|LAYOUT_FILL_Y);
     group=new FXGroupBox(editor,_("Mouse"),GROUPBOX_TITLE_LEFT|FRAME_GROOVE|LAYOUT_FILL_X|LAYOUT_FILL_Y);
     FXMatrix *matrix3 = new FXMatrix(group,2,MATRIX_BY_COLUMNS|LAYOUT_SIDE_TOP|LAYOUT_FILL_X|LAYOUT_FILL_Y);
-
-    new FXLabel(matrix,_("Wrap margin:"),NULL,JUSTIFY_LEFT|LAYOUT_FILL_COLUMN|LAYOUT_FILL_ROW);
-    new FXTextField(matrix,10,owner,EditWindow::ID_WRAPCOLUMNS,JUSTIFY_RIGHT|FRAME_SUNKEN|FRAME_THICK|LAYOUT_CENTER_Y|LAYOUT_FILL_X|LAYOUT_FILL_ROW,0,0,0,0, 2,2,1,1);
-
-    new FXLabel(matrix,_("Tabulation size:"),NULL,JUSTIFY_LEFT|LAYOUT_FILL_COLUMN|LAYOUT_FILL_ROW);
-    new FXTextField(matrix,10,owner,EditWindow::ID_TABCOLUMNS,JUSTIFY_RIGHT|FRAME_SUNKEN|FRAME_THICK|LAYOUT_CENTER_Y|LAYOUT_FILL_X|LAYOUT_FILL_ROW,0,0,0,0, 2,2,1,1);
+    
+	new FXLabel(matrix,_("Wrap margin:"),NULL,JUSTIFY_LEFT|LAYOUT_FILL_COLUMN|LAYOUT_FILL_ROW);
+    wrapmargin = new FXTextField(matrix,10,NULL,0,TEXTFIELD_INTEGER|JUSTIFY_RIGHT|FRAME_SUNKEN|FRAME_THICK|LAYOUT_CENTER_Y|LAYOUT_FILL_X|LAYOUT_FILL_ROW,0,0,0,0, 2,2,1,1);
+    FXint wrapcols=getApp()->reg().readIntEntry("SETTINGS","wrapcols",80);
+	wrapmargin->setText(FXStringVal(wrapcols));
+	
+	new FXLabel(matrix,_("Tabulation size:"),NULL,JUSTIFY_LEFT|LAYOUT_FILL_COLUMN|LAYOUT_FILL_ROW);
+    tabsize = new FXTextField(matrix,10,NULL,0,TEXTFIELD_INTEGER|JUSTIFY_RIGHT|FRAME_SUNKEN|FRAME_THICK|LAYOUT_CENTER_Y|LAYOUT_FILL_X|LAYOUT_FILL_ROW,0,0,0,0, 2,2,1,1);
+    FXint tabcols=getApp()->reg().readIntEntry("SETTINGS","tabcols",80);
+	tabsize->setText(FXStringVal(tabcols));
 
     new FXLabel(matrix,_("Strip carriage returns:               "),NULL,JUSTIFY_LEFT|LAYOUT_FILL_COLUMN|LAYOUT_FILL_ROW);
-    new FXCheckButton(matrix,FXString::null,owner,EditWindow::ID_STRIP_CR,LAYOUT_LEFT|LAYOUT_CENTER_Y|LAYOUT_FILL_ROW,0,0,0,0, 0,0,0,0);
+    stripcr = new FXCheckButton(matrix,FXString::null,NULL,0,LAYOUT_LEFT|LAYOUT_CENTER_Y|LAYOUT_FILL_ROW,0,0,0,0, 0,0,0,0);
+    FXint stripreturn=getApp()->reg().readIntEntry("SETTINGS","stripreturn",FALSE);
+	stripcr->setCheck(stripreturn);
 
     new FXLabel(matrix3,_("Mouse scrolling speed:"),NULL,JUSTIFY_LEFT|LAYOUT_FILL_COLUMN|LAYOUT_FILL_ROW);
-    FXSpinner* spinner=new FXSpinner(matrix3,3,owner,EditWindow::ID_WHEELADJUST,JUSTIFY_RIGHT|FRAME_SUNKEN|FRAME_THICK|LAYOUT_FILL_X|LAYOUT_FILL_ROW,0,0,0,0, 2,2,1,1);
+    FXSpinner* spinner=new FXSpinner(matrix3,3,this,Preferences::ID_WHEELADJUST,JUSTIFY_RIGHT|FRAME_SUNKEN|FRAME_THICK|LAYOUT_FILL_X|LAYOUT_FILL_ROW,0,0,0,0, 2,2,1,1);
     spinner->setRange(1,100);
 
     // Second tab - Colors
@@ -184,108 +229,321 @@ Preferences::Preferences(EditWindow *owner):DialogBox(owner,_("XFileWrite Prefer
     FXMatrix *matrix2 = new FXMatrix(group,2,MATRIX_BY_COLUMNS|LAYOUT_SIDE_TOP|LAYOUT_FILL_X|LAYOUT_FILL_Y);
 
     new FXLabel(matrix1,_("Background:"),NULL,JUSTIFY_LEFT|LAYOUT_FILL_COLUMN|LAYOUT_FILL_ROW);
-    new FXColorWell(matrix1,FXRGB(0,0,0),owner,EditWindow::ID_TEXT_BACK,FRAME_SUNKEN|FRAME_THICK|LAYOUT_LEFT|LAYOUT_CENTER_Y|LAYOUT_FIX_WIDTH|LAYOUT_FIX_HEIGHT|LAYOUT_FILL_ROW,0,0,40,24);
+    new FXColorWell(matrix1,FXRGB(0,0,0),this,Preferences::ID_TEXT_BACK,FRAME_SUNKEN|FRAME_THICK|LAYOUT_LEFT|LAYOUT_CENTER_Y|LAYOUT_FIX_WIDTH|LAYOUT_FIX_HEIGHT|LAYOUT_FILL_ROW,0,0,40,24);
 
     new FXLabel(matrix1,_("Text:"),NULL,JUSTIFY_LEFT|LAYOUT_FILL_COLUMN|LAYOUT_FILL_ROW);
-    new FXColorWell(matrix1,FXRGB(0,0,0),owner,EditWindow::ID_TEXT_FORE,FRAME_SUNKEN|FRAME_THICK|LAYOUT_LEFT|LAYOUT_CENTER_Y|LAYOUT_FIX_WIDTH|LAYOUT_FIX_HEIGHT|LAYOUT_FILL_ROW,0,0,40,24);
+    new FXColorWell(matrix1,FXRGB(0,0,0),this,Preferences::ID_TEXT_FORE,FRAME_SUNKEN|FRAME_THICK|LAYOUT_LEFT|LAYOUT_CENTER_Y|LAYOUT_FIX_WIDTH|LAYOUT_FIX_HEIGHT|LAYOUT_FILL_ROW,0,0,40,24);
 
     new FXLabel(matrix1,_("Selected text background:"),NULL,JUSTIFY_LEFT|LAYOUT_FILL_COLUMN|LAYOUT_FILL_ROW);
-    new FXColorWell(matrix1,FXRGB(0,0,0),owner,EditWindow::ID_TEXT_SELBACK,FRAME_SUNKEN|FRAME_THICK|LAYOUT_LEFT|LAYOUT_CENTER_Y|LAYOUT_FIX_WIDTH|LAYOUT_FIX_HEIGHT|LAYOUT_FILL_ROW,0,0,40,24);
+    new FXColorWell(matrix1,FXRGB(0,0,0),this,Preferences::ID_TEXT_SELBACK,FRAME_SUNKEN|FRAME_THICK|LAYOUT_LEFT|LAYOUT_CENTER_Y|LAYOUT_FIX_WIDTH|LAYOUT_FIX_HEIGHT|LAYOUT_FILL_ROW,0,0,40,24);
 
     new FXLabel(matrix1,_("Selected text:"),NULL,JUSTIFY_LEFT|LAYOUT_FILL_COLUMN|LAYOUT_FILL_ROW);
-    new FXColorWell(matrix1,FXRGB(0,0,0),owner,EditWindow::ID_TEXT_SELFORE,FRAME_SUNKEN|FRAME_THICK|LAYOUT_LEFT|LAYOUT_CENTER_Y|LAYOUT_FIX_WIDTH|LAYOUT_FIX_HEIGHT|LAYOUT_FILL_ROW,0,0,40,24);
+    new FXColorWell(matrix1,FXRGB(0,0,0),this,Preferences::ID_TEXT_SELFORE,FRAME_SUNKEN|FRAME_THICK|LAYOUT_LEFT|LAYOUT_CENTER_Y|LAYOUT_FIX_WIDTH|LAYOUT_FIX_HEIGHT|LAYOUT_FILL_ROW,0,0,40,24);
 
     new FXLabel(matrix1,_("Highlighted text background:"),NULL,JUSTIFY_LEFT|LAYOUT_FILL_COLUMN|LAYOUT_FILL_ROW);
-    new FXColorWell(matrix1,FXRGB(0,0,0),owner,EditWindow::ID_TEXT_HILITEBACK,FRAME_SUNKEN|FRAME_THICK|LAYOUT_LEFT|LAYOUT_CENTER_Y|LAYOUT_FIX_WIDTH|LAYOUT_FIX_HEIGHT|LAYOUT_FILL_ROW,0,0,40,24);
+    new FXColorWell(matrix1,FXRGB(0,0,0),this,Preferences::ID_TEXT_HILITEBACK,FRAME_SUNKEN|FRAME_THICK|LAYOUT_LEFT|LAYOUT_CENTER_Y|LAYOUT_FIX_WIDTH|LAYOUT_FIX_HEIGHT|LAYOUT_FILL_ROW,0,0,40,24);
 
     new FXLabel(matrix1,_("Highlighted text:"),NULL,JUSTIFY_LEFT|LAYOUT_FILL_COLUMN|LAYOUT_FILL_ROW);
-    new FXColorWell(matrix1,FXRGB(0,0,0),owner,EditWindow::ID_TEXT_HILITEFORE,FRAME_SUNKEN|FRAME_THICK|LAYOUT_LEFT|LAYOUT_CENTER_Y|LAYOUT_FIX_WIDTH|LAYOUT_FIX_HEIGHT|LAYOUT_FILL_ROW,0,0,40,24);
+    new FXColorWell(matrix1,FXRGB(0,0,0),this,Preferences::ID_TEXT_HILITEFORE,FRAME_SUNKEN|FRAME_THICK|LAYOUT_LEFT|LAYOUT_CENTER_Y|LAYOUT_FIX_WIDTH|LAYOUT_FIX_HEIGHT|LAYOUT_FILL_ROW,0,0,40,24);
 
     new FXLabel(matrix1,_("Cursor:"),NULL,JUSTIFY_LEFT|LAYOUT_FILL_COLUMN|LAYOUT_FILL_ROW);
-    new FXColorWell(matrix1,FXRGB(0,0,0),owner,EditWindow::ID_TEXT_CURSOR,FRAME_SUNKEN|FRAME_THICK|LAYOUT_LEFT|LAYOUT_CENTER_Y|LAYOUT_FIX_WIDTH|LAYOUT_FIX_HEIGHT|LAYOUT_FILL_ROW,0,0,40,24);
+    new FXColorWell(matrix1,FXRGB(0,0,0),this,Preferences::ID_TEXT_CURSOR,FRAME_SUNKEN|FRAME_THICK|LAYOUT_LEFT|LAYOUT_CENTER_Y|LAYOUT_FIX_WIDTH|LAYOUT_FIX_HEIGHT|LAYOUT_FILL_ROW,0,0,40,24);
 
     new FXLabel(matrix2,_("Line numbers background:"),NULL,JUSTIFY_LEFT|LAYOUT_FILL_COLUMN|LAYOUT_FILL_ROW);
-    new FXColorWell(matrix2,FXRGB(0,0,0),owner,EditWindow::ID_TEXT_NUMBACK,FRAME_SUNKEN|FRAME_THICK|LAYOUT_LEFT|LAYOUT_CENTER_Y|LAYOUT_FIX_WIDTH|LAYOUT_FIX_HEIGHT|LAYOUT_FILL_ROW,0,0,40,24);
+    new FXColorWell(matrix2,FXRGB(0,0,0),this,Preferences::ID_TEXT_NUMBACK,FRAME_SUNKEN|FRAME_THICK|LAYOUT_LEFT|LAYOUT_CENTER_Y|LAYOUT_FIX_WIDTH|LAYOUT_FIX_HEIGHT|LAYOUT_FILL_ROW,0,0,40,24);
 
     new FXLabel(matrix2,_("Line numbers foreground:"),NULL,JUSTIFY_LEFT|LAYOUT_FILL_COLUMN|LAYOUT_FILL_ROW);
-    new FXColorWell(matrix2,FXRGB(0,0,0),owner,EditWindow::ID_TEXT_NUMFORE,FRAME_SUNKEN|FRAME_THICK|LAYOUT_LEFT|LAYOUT_CENTER_Y|LAYOUT_FIX_WIDTH|LAYOUT_FIX_HEIGHT|LAYOUT_FILL_ROW,0,0,40,24);
+    new FXColorWell(matrix2,FXRGB(0,0,0),this,Preferences::ID_TEXT_NUMFORE,FRAME_SUNKEN|FRAME_THICK|LAYOUT_LEFT|LAYOUT_CENTER_Y|LAYOUT_FIX_WIDTH|LAYOUT_FIX_HEIGHT|LAYOUT_FILL_ROW,0,0,40,24);
 
 }
 
+long Preferences::onCmdAccept(FXObject* o,FXSelector s,void* p)
+{
+	// Update preferences to their new values
+	
+	editor->setWrapColumns(FXIntVal(wrapmargin->getText()));	
+	getApp()->reg().writeIntEntry("SETTINGS","wrapcols",FXIntVal(wrapmargin->getText()));
+	
+	editor->setTabColumns(FXIntVal(tabsize->getText()));	
+	getApp()->reg().writeIntEntry("SETTINGS","tabcols",FXIntVal(tabsize->getText()));
+
+	editor->setTabColumns(FXIntVal(tabsize->getText()));	
+	getApp()->reg().writeIntEntry("SETTINGS","tabcols",FXIntVal(tabsize->getText()));
+
+    editwin->setStripcr(stripcr->getCheck());
+	getApp()->reg().writeIntEntry("SETTINGS","stripreturn",stripcr->getCheck());
+
+
+	// Finally, update the registry
+	getApp()->reg().write();
+	
+    DialogBox::onCmdAccept(o,s,p);
+	
+	return 1;
+}
+
+
+long Preferences::onCmdCancel(FXObject* o,FXSelector s,void* p)
+{
+	// Reset preferences to their previous values
+	
+	// First tab - Editor
+	wrapmargin->setText(wrapmargin_prev);
+	tabsize->setText(tabsize_prev);
+	stripcr->setCheck(stripcr_prev);
+	getApp()->setWheelLines(value_prev);	
+
+	// Second tab - Colors
+	editor->setTextColor(textcolor_prev);
+	editor->setBackColor(backcolor_prev);	
+	editor->setSelTextColor(seltextcolor_prev);
+	editor->setSelBackColor(selbackcolor_prev);
+	editor->setHiliteTextColor(hilitetextcolor_prev);	
+	editor->setHiliteBackColor(hilitebackcolor_prev);	
+	editor->setCursorColor(cursorcolor_prev);
+	editor->setBarColor(barcolor_prev);
+	editor->setNumberColor(numbercolor_prev);	
+
+    DialogBox::onCmdCancel(o,s,p);
+    return 1;
+}
+
+
+// Execute dialog box modally
+FXuint Preferences::execute(FXuint placement)
+{
+	// Save current preferences to restore them if cancel is pressed
+	
+	// First tab - Editor
+	wrapmargin_prev=wrapmargin->getText();
+	tabsize_prev=tabsize->getText();
+	stripcr_prev=stripcr->getCheck();
+	value_prev=getApp()->getWheelLines();
+	
+	// Second tab - Colors
+	textcolor_prev=editor->getTextColor();	
+	backcolor_prev=editor->getBackColor();	
+	seltextcolor_prev=editor->getSelTextColor();
+	selbackcolor_prev=editor->getSelBackColor();
+	hilitetextcolor_prev=editor->getHiliteTextColor();	
+	hilitebackcolor_prev=editor->getHiliteBackColor();	
+	cursorcolor_prev=editor->getCursorColor();
+	barcolor_prev=editor->getBarColor();
+	numbercolor_prev=editor->getNumberColor();	
+	
+	// Display dialog
+	create();
+    show(placement);
+	getApp()->refresh();
+    return getApp()->runModalFor(this);
+}
+
+// Set scroll wheel lines (Mathew Robertson <mathew@optushome.com.au>)
+long Preferences::onCmdWheelAdjust(FXObject* sender,FXSelector,void*)
+{
+    FXuint value;
+    sender->handle(this,FXSEL(SEL_COMMAND,ID_GETINTVALUE),(void*)&value);
+    getApp()->setWheelLines(value);
+	getApp()->reg().write();
+    return 1;
+}
+
+
+// Update the wheel lines button
+long Preferences::onUpdWheelAdjust(FXObject* sender,FXSelector,void*)
+{
+    FXuint value=getApp()->getWheelLines();
+	sender->handle(this,FXSEL(SEL_COMMAND,ID_SETINTVALUE),(void*)&value);
+    return 1;
+}
+
+// Change text color
+long Preferences::onCmdTextForeColor(FXObject*,FXSelector,void* ptr)
+{
+    editor->setTextColor((FXColor)(FXuval)ptr);
+    return 1;
+}
+
+// Update text color
+long Preferences::onUpdTextForeColor(FXObject* sender,FXSelector,void*)
+{
+    FXColor color=editor->getTextColor();
+    sender->handle(this,FXSEL(SEL_COMMAND,ID_SETINTVALUE),(void*)&color);
+    return 1;
+}
+
+
+// Change text background color
+long Preferences::onCmdTextBackColor(FXObject*,FXSelector,void* ptr)
+{
+    editor->setBackColor((FXColor)(FXuval)ptr);
+    return 1;
+}
+
+// Update background color
+long Preferences::onUpdTextBackColor(FXObject* sender,FXSelector,void*)
+{
+    FXColor color=editor->getBackColor();
+    sender->handle(this,FXSEL(SEL_COMMAND,ID_SETINTVALUE),(void*)&color);
+    return 1;
+}
+
+
+// Change selected text foreground color
+long Preferences::onCmdTextSelForeColor(FXObject*,FXSelector,void* ptr)
+{
+    editor->setSelTextColor((FXColor)(FXuval)ptr);
+    return 1;
+}
+
+
+// Update selected text foregoround color
+long Preferences::onUpdTextSelForeColor(FXObject* sender,FXSelector,void*)
+{
+    FXColor color=editor->getSelTextColor();
+    sender->handle(this,FXSEL(SEL_COMMAND,ID_SETINTVALUE),(void*)&color);
+    return 1;
+}
+
+
+// Change selected text background color
+long Preferences::onCmdTextSelBackColor(FXObject*,FXSelector,void* ptr)
+{
+    editor->setSelBackColor((FXColor)(FXuval)ptr);
+    return 1;
+}
+
+// Update selected text background color
+long Preferences::onUpdTextSelBackColor(FXObject* sender,FXSelector,void*)
+{
+    FXColor color=editor->getSelBackColor();
+    sender->handle(this,FXSEL(SEL_COMMAND,ID_SETINTVALUE),(void*)&color);
+    return 1;
+}
+
+
+// Change hilight text color
+long Preferences::onCmdTextHiliteForeColor(FXObject*,FXSelector,void* ptr)
+{
+    editor->setHiliteTextColor((FXColor)(FXuval)ptr);
+    return 1;
+}
+
+// Update hilight text color
+long Preferences::onUpdTextHiliteForeColor(FXObject* sender,FXSelector,void*)
+{
+    FXColor color=editor->getHiliteTextColor();
+    sender->handle(this,FXSEL(SEL_COMMAND,ID_SETINTVALUE),(void*)&color);
+    return 1;
+}
+
+
+// Change hilight text background color
+long Preferences::onCmdTextHiliteBackColor(FXObject*,FXSelector,void* ptr)
+{
+    editor->setHiliteBackColor((FXColor)(FXuval)ptr);
+    return 1;
+}
+
+// Update hilight text background color
+long Preferences::onUpdTextHiliteBackColor(FXObject* sender,FXSelector,void*)
+{
+    FXColor color=editor->getHiliteBackColor();
+    sender->handle(this,FXSEL(SEL_COMMAND,ID_SETINTVALUE),(void*)&color);
+    return 1;
+}
+
+
+// Change cursor color
+long Preferences::onCmdTextCursorColor(FXObject*,FXSelector,void* ptr)
+{
+    editor->setCursorColor((FXColor)(FXuval)ptr);
+    return 1;
+}
+
+// Update cursor color
+long Preferences::onUpdTextCursorColor(FXObject* sender,FXSelector,void*)
+{
+    FXColor color=editor->getCursorColor();
+    sender->handle(sender,FXSEL(SEL_COMMAND,FXWindow::ID_SETINTVALUE),(void*)&color);
+    return 1;
+}
+
+
+// Change line numbers background color
+long Preferences::onCmdTextBarColor(FXObject*,FXSelector,void* ptr)
+{
+    editor->setBarColor((FXColor)(FXuval)ptr);
+    return 1;
+}
+
+
+// Update line numbers background color
+long Preferences::onUpdTextBarColor(FXObject* sender,FXSelector,void*)
+{
+    FXColor color=editor->getBarColor();
+    sender->handle(this,FXSEL(SEL_COMMAND,ID_SETINTVALUE),(void*)&color);
+    return 1;
+}
+
+
+// Change line numbers color
+long Preferences::onCmdTextNumberColor(FXObject*,FXSelector,void* ptr)
+{
+    editor->setNumberColor((FXColor)(FXuval)ptr);
+    return 1;
+}
+
+
+// Update line numbers color
+long Preferences::onUpdTextNumberColor(FXObject* sender,FXSelector,void*)
+{
+    FXColor color=editor->getNumberColor();
+    sender->handle(this,FXSEL(SEL_COMMAND,ID_SETINTVALUE),(void*)&color);
+    return 1;
+}
+
+
+
 
 // EditWindow class
 
 
 // Map
-FXDEFMAP(EditWindow) EditWindowMap[]={
-                                         FXMAPFUNC(SEL_UPDATE,0,EditWindow::onUpdateTitle),
-                                         FXMAPFUNC(SEL_FOCUSIN,0,EditWindow::onFocusIn),
-                                         FXMAPFUNC(SEL_COMMAND,EditWindow::ID_ABOUT,EditWindow::onCmdAbout),
-                                         FXMAPFUNC(SEL_COMMAND,EditWindow::ID_NEW,EditWindow::onCmdNew),
-                                         FXMAPFUNC(SEL_COMMAND,EditWindow::ID_OPEN,EditWindow::onCmdOpen),
-                                         FXMAPFUNC(SEL_COMMAND,EditWindow::ID_OPEN_RECENT,EditWindow::onCmdOpenRecent),
-                                         FXMAPFUNC(SEL_COMMAND,EditWindow::ID_SAVE,EditWindow::onCmdSave),
-                                         FXMAPFUNC(SEL_UPDATE,EditWindow::ID_SAVE,EditWindow::onUpdSave),
-                                         FXMAPFUNC(SEL_COMMAND,EditWindow::ID_SAVEAS,EditWindow::onCmdSaveAs),
-                                         FXMAPFUNC(SEL_COMMAND,EditWindow::ID_FONT,EditWindow::onCmdFont),
-                                         FXMAPFUNC(SEL_COMMAND,EditWindow::ID_PRINT,EditWindow::onCmdPrint),
-                                         FXMAPFUNC(SEL_COMMAND,EditWindow::ID_TEXT_BACK,EditWindow::onCmdTextBackColor),
-                                         FXMAPFUNC(SEL_CHANGED,EditWindow::ID_TEXT_BACK,EditWindow::onCmdTextBackColor),
-                                         FXMAPFUNC(SEL_UPDATE,EditWindow::ID_TEXT_BACK,EditWindow::onUpdTextBackColor),
-                                         FXMAPFUNC(SEL_COMMAND,EditWindow::ID_TEXT_FORE,EditWindow::onCmdTextForeColor),
-                                         FXMAPFUNC(SEL_CHANGED,EditWindow::ID_TEXT_FORE,EditWindow::onCmdTextForeColor),
-                                         FXMAPFUNC(SEL_UPDATE,EditWindow::ID_TEXT_FORE,EditWindow::onUpdTextForeColor),
-                                         FXMAPFUNC(SEL_COMMAND,EditWindow::ID_TEXT_SELBACK,EditWindow::onCmdTextSelBackColor),
-                                         FXMAPFUNC(SEL_CHANGED,EditWindow::ID_TEXT_SELBACK,EditWindow::onCmdTextSelBackColor),
-                                         FXMAPFUNC(SEL_UPDATE,EditWindow::ID_TEXT_SELBACK,EditWindow::onUpdTextSelBackColor),
-                                         FXMAPFUNC(SEL_COMMAND,EditWindow::ID_TEXT_SELFORE,EditWindow::onCmdTextSelForeColor),
-                                         FXMAPFUNC(SEL_CHANGED,EditWindow::ID_TEXT_SELFORE,EditWindow::onCmdTextSelForeColor),
-                                         FXMAPFUNC(SEL_UPDATE,EditWindow::ID_TEXT_SELFORE,EditWindow::onUpdTextSelForeColor),
-                                         FXMAPFUNC(SEL_COMMAND,EditWindow::ID_TEXT_HILITEBACK,EditWindow::onCmdTextHiliteBackColor),
-                                         FXMAPFUNC(SEL_CHANGED,EditWindow::ID_TEXT_HILITEBACK,EditWindow::onCmdTextHiliteBackColor),
-                                         FXMAPFUNC(SEL_UPDATE,EditWindow::ID_TEXT_HILITEBACK,EditWindow::onUpdTextHiliteBackColor),
-                                         FXMAPFUNC(SEL_COMMAND,EditWindow::ID_TEXT_HILITEFORE,EditWindow::onCmdTextHiliteForeColor),
-                                         FXMAPFUNC(SEL_CHANGED,EditWindow::ID_TEXT_HILITEFORE,EditWindow::onCmdTextHiliteForeColor),
-                                         FXMAPFUNC(SEL_UPDATE,EditWindow::ID_TEXT_HILITEFORE,EditWindow::onUpdTextHiliteForeColor),
-                                         FXMAPFUNC(SEL_COMMAND,EditWindow::ID_TEXT_CURSOR,EditWindow::onCmdTextCursorColor),
-                                         FXMAPFUNC(SEL_CHANGED,EditWindow::ID_TEXT_CURSOR,EditWindow::onCmdTextCursorColor),
-                                         FXMAPFUNC(SEL_UPDATE,EditWindow::ID_TEXT_CURSOR,EditWindow::onUpdTextCursorColor),
-                                         FXMAPFUNC(SEL_COMMAND,EditWindow::ID_TEXT_NUMBACK,EditWindow::onCmdTextBarColor),
-                                         FXMAPFUNC(SEL_CHANGED,EditWindow::ID_TEXT_NUMBACK,EditWindow::onCmdTextBarColor),
-                                         FXMAPFUNC(SEL_UPDATE,EditWindow::ID_TEXT_NUMBACK,EditWindow::onUpdTextBarColor),
-                                         FXMAPFUNC(SEL_COMMAND,EditWindow::ID_TEXT_NUMFORE,EditWindow::onCmdTextNumberColor),
-                                         FXMAPFUNC(SEL_CHANGED,EditWindow::ID_TEXT_NUMFORE,EditWindow::onCmdTextNumberColor),
-                                         FXMAPFUNC(SEL_UPDATE,EditWindow::ID_TEXT_NUMFORE,EditWindow::onUpdTextNumberColor),
-                                         FXMAPFUNC(SEL_UPDATE,EditWindow::ID_TOGGLE_WRAP,EditWindow::onUpdWrap),
-                                         FXMAPFUNC(SEL_COMMAND,EditWindow::ID_TOGGLE_WRAP,EditWindow::onCmdWrap),
-                                         FXMAPFUNC(SEL_COMMAND,EditWindow::ID_TOGGLE_LINES_NUM,EditWindow::onCmdLinesNum),
-                                         FXMAPFUNC(SEL_UPDATE,EditWindow::ID_TOGGLE_LINES_NUM,EditWindow::onUpdLinesNum),
-                                         FXMAPFUNC(SEL_COMMAND,EditWindow::ID_SAVE_SETTINGS,EditWindow::onCmdSaveSettings),
-                                         FXMAPFUNC(SEL_INSERTED,EditWindow::ID_TEXT,EditWindow::onTextInserted),
-                                         FXMAPFUNC(SEL_REPLACED,EditWindow::ID_TEXT,EditWindow::onTextReplaced),
-                                         FXMAPFUNC(SEL_DELETED,EditWindow::ID_TEXT,EditWindow::onTextDeleted),
-                                         FXMAPFUNC(SEL_RIGHTBUTTONRELEASE,EditWindow::ID_TEXT,EditWindow::onTextRightMouse),
-                                         FXMAPFUNC(SEL_DND_MOTION,EditWindow::ID_TEXT,EditWindow::onEditDNDMotion),
-                                         FXMAPFUNC(SEL_DND_DROP,EditWindow::ID_TEXT,EditWindow::onEditDNDDrop),
-                                         FXMAPFUNC(SEL_UPDATE,EditWindow::ID_STRIP_CR,EditWindow::onUpdStripReturns),
-                                         FXMAPFUNC(SEL_COMMAND,EditWindow::ID_STRIP_CR,EditWindow::onCmdStripReturns),
-                                         FXMAPFUNC(SEL_UPDATE,EditWindow::ID_OVERSTRIKE,EditWindow::onUpdOverstrike),
-                                         FXMAPFUNC(SEL_UPDATE,EditWindow::ID_NUM_ROWS,EditWindow::onUpdNumRows),
-                                         FXMAPFUNC(SEL_COMMAND,EditWindow::ID_PREFERENCES,EditWindow::onCmdMorePrefs),
-                                         FXMAPFUNC(SEL_COMMAND,EditWindow::ID_TABCOLUMNS,EditWindow::onCmdTabColumns),
-                                         FXMAPFUNC(SEL_UPDATE,EditWindow::ID_TABCOLUMNS,EditWindow::onUpdTabColumns),
-                                         FXMAPFUNC(SEL_COMMAND,EditWindow::ID_WRAPCOLUMNS,EditWindow::onCmdWrapColumns),
-                                         FXMAPFUNC(SEL_UPDATE,EditWindow::ID_WRAPCOLUMNS,EditWindow::onUpdWrapColumns),
-                                         FXMAPFUNC(SEL_UPDATE,EditWindow::ID_WHEELADJUST,EditWindow::onUpdWheelAdjust),
-                                         FXMAPFUNC(SEL_COMMAND,EditWindow::ID_WHEELADJUST,EditWindow::onCmdWheelAdjust),
-                                         FXMAPFUNC(SEL_COMMAND,EditWindow::ID_SEARCH,EditWindow::onCmdSearch),
-                                         FXMAPFUNC(SEL_COMMAND,EditWindow::ID_REPLACE,EditWindow::onCmdReplace),
-										 FXMAPFUNC(SEL_COMMAND,EditWindow::ID_SEARCH_FORW_SEL,EditWindow::onCmdSearchSel),
-										 FXMAPFUNC(SEL_COMMAND,EditWindow::ID_SEARCH_BACK_SEL,EditWindow::onCmdSearchSel),
-										 FXMAPFUNC(SEL_COMMAND,EditWindow::ID_GOTO_LINE,EditWindow::onCmdGotoLine),
-                                         FXMAPFUNCS(SEL_UPDATE, EditWindow::ID_WINDOW_1,EditWindow::ID_WINDOW_50,EditWindow::onUpdWindow),
-                                         FXMAPFUNCS(SEL_COMMAND,EditWindow::ID_WINDOW_1,EditWindow::ID_WINDOW_50,EditWindow::onCmdWindow),
-                                     };
+FXDEFMAP(EditWindow) EditWindowMap[]=
+{
+	FXMAPFUNC(SEL_UPDATE,0,EditWindow::onUpdateTitle),
+	FXMAPFUNC(SEL_FOCUSIN,0,EditWindow::onFocusIn),
+	FXMAPFUNC(SEL_COMMAND,EditWindow::ID_ABOUT,EditWindow::onCmdAbout),
+	FXMAPFUNC(SEL_COMMAND,EditWindow::ID_NEW,EditWindow::onCmdNew),
+	FXMAPFUNC(SEL_COMMAND,EditWindow::ID_OPEN,EditWindow::onCmdOpen),
+	FXMAPFUNC(SEL_COMMAND,EditWindow::ID_OPEN_RECENT,EditWindow::onCmdOpenRecent),
+	FXMAPFUNC(SEL_COMMAND,EditWindow::ID_SAVE,EditWindow::onCmdSave),
+	FXMAPFUNC(SEL_UPDATE,EditWindow::ID_SAVE,EditWindow::onUpdSave),
+	FXMAPFUNC(SEL_COMMAND,EditWindow::ID_SAVEAS,EditWindow::onCmdSaveAs),
+	FXMAPFUNC(SEL_COMMAND,EditWindow::ID_FONT,EditWindow::onCmdFont),
+	FXMAPFUNC(SEL_COMMAND,EditWindow::ID_PRINT,EditWindow::onCmdPrint),
+	FXMAPFUNC(SEL_UPDATE,EditWindow::ID_TOGGLE_WRAP,EditWindow::onUpdWrap),
+	FXMAPFUNC(SEL_COMMAND,EditWindow::ID_TOGGLE_WRAP,EditWindow::onCmdWrap),
+	FXMAPFUNC(SEL_COMMAND,EditWindow::ID_TOGGLE_LINES_NUM,EditWindow::onCmdLinesNum),
+	FXMAPFUNC(SEL_UPDATE,EditWindow::ID_TOGGLE_LINES_NUM,EditWindow::onUpdLinesNum),
+	FXMAPFUNC(SEL_INSERTED,EditWindow::ID_TEXT,EditWindow::onTextInserted),
+	FXMAPFUNC(SEL_REPLACED,EditWindow::ID_TEXT,EditWindow::onTextReplaced),
+	FXMAPFUNC(SEL_DELETED,EditWindow::ID_TEXT,EditWindow::onTextDeleted),
+	FXMAPFUNC(SEL_RIGHTBUTTONRELEASE,EditWindow::ID_TEXT,EditWindow::onTextRightMouse),
+	FXMAPFUNC(SEL_DND_MOTION,EditWindow::ID_TEXT,EditWindow::onEditDNDMotion),
+	FXMAPFUNC(SEL_DND_DROP,EditWindow::ID_TEXT,EditWindow::onEditDNDDrop),
+	FXMAPFUNC(SEL_UPDATE,EditWindow::ID_OVERSTRIKE,EditWindow::onUpdOverstrike),
+	FXMAPFUNC(SEL_UPDATE,EditWindow::ID_NUM_ROWS,EditWindow::onUpdNumRows),
+	FXMAPFUNC(SEL_COMMAND,EditWindow::ID_PREFERENCES,EditWindow::onCmdMorePrefs),
+	FXMAPFUNC(SEL_COMMAND,EditWindow::ID_SEARCH,EditWindow::onCmdSearch),
+	FXMAPFUNC(SEL_COMMAND,EditWindow::ID_REPLACE,EditWindow::onCmdReplace),
+	FXMAPFUNC(SEL_COMMAND,EditWindow::ID_SEARCH_FORW_SEL,EditWindow::onCmdSearchSel),
+	FXMAPFUNC(SEL_COMMAND,EditWindow::ID_SEARCH_BACK_SEL,EditWindow::onCmdSearchSel),
+	FXMAPFUNC(SEL_COMMAND,EditWindow::ID_GOTO_LINE,EditWindow::onCmdGotoLine),
+	FXMAPFUNCS(SEL_UPDATE, EditWindow::ID_WINDOW_1,EditWindow::ID_WINDOW_50,EditWindow::onUpdWindow),
+	FXMAPFUNCS(SEL_COMMAND,EditWindow::ID_WINDOW_1,EditWindow::ID_WINDOW_50,EditWindow::onCmdWindow),
+};
 
 
 // Object implementation
@@ -510,8 +768,8 @@ EditWindow::EditWindow(XFileWrite* a,const FXString& file):FXMainWindow(a,"XFile
     new FXMenuSeparator(prefsmenu);
     new FXMenuCommand(prefsmenu,_("&Font...\t\tChange text font."),fontsicon,this,ID_FONT);
     new FXMenuCommand(prefsmenu,_("&More preferences...\t\tChange other options."),prefsicon,this,ID_PREFERENCES);
-    new FXMenuSeparator(prefsmenu);
-    new FXMenuCommand(prefsmenu,_("&Save Settings\t\tSave settings now."),NULL,this,ID_SAVE_SETTINGS);
+    //new FXMenuSeparator(prefsmenu);
+    //new FXMenuCommand(prefsmenu,_("&Save Settings\t\tSave settings now."),NULL,this,ID_SAVE_SETTINGS);
 
     // View Menu entries
     new FXMenuCheck(viewmenu,_("&Toolbar\t\tDisplay toolbar."),toolbar,FXWindow::ID_TOGGLESHOWN);
@@ -931,7 +1189,7 @@ void EditWindow::loadConfig()
         editor->setTextStyle(editor->getTextStyle()&~TEXT_WORDWRAP);
 
     // Wrap and tab columns
-    editor->setWrapColumns(wrapcols);
+	editor->setWrapColumns(wrapcols);
     editor->setTabColumns(tabcols);
 
     // Highlight match time
@@ -976,7 +1234,7 @@ void EditWindow::saveConfig()
 
     // Wrap mode
     getApp()->reg().writeIntEntry("SETTINGS","wordwrap",(editor->getTextStyle()&TEXT_WORDWRAP)!=0);
-    getApp()->reg().writeIntEntry("SETTINGS","wrapcols",editor->getWrapColumns());
+	getApp()->reg().writeIntEntry("SETTINGS","wrapcols",editor->getWrapColumns());
 
     // Tab settings
     getApp()->reg().writeIntEntry("SETTINGS","tabcols",editor->getTabColumns());
@@ -1009,7 +1267,7 @@ long EditWindow::onCmdMorePrefs(FXObject*,FXSelector,void*)
 {
     if (prefsdialog==NULL)
         prefsdialog=new Preferences(this);
-    prefsdialog->execute();
+    prefsdialog->execute(PLACEMENT_OWNER);
     return 1;
 }
 
@@ -1319,16 +1577,6 @@ long EditWindow::onCmdPrint(FXObject*,FXSelector,void*)
 }
 
 
-
-// Save settings
-long EditWindow::onCmdSaveSettings(FXObject*,FXSelector,void*)
-{
-    saveConfig();
-    getApp()->reg().write();
-    return 1;
-}
-
-
 // Toggle wrap mode
 long EditWindow::onCmdWrap(FXObject*,FXSelector,void*)
 {
@@ -1375,64 +1623,6 @@ long EditWindow::onUpdLinesNum(FXObject* sender,FXSelector,void*)
 }
 
 
-// Toggle strip returns mode
-long EditWindow::onCmdStripReturns(FXObject*,FXSelector,void* ptr)
-{
-    stripcr=(FXbool)(FXuval)ptr;
-    return 1;
-}
-
-
-// Update toggle strip returns mode
-long EditWindow::onUpdStripReturns(FXObject* sender,FXSelector,void*)
-{
-    if(stripcr)
-        sender->handle(this,FXSEL(SEL_COMMAND,ID_CHECK),NULL);
-    else
-        sender->handle(this,FXSEL(SEL_COMMAND,ID_UNCHECK),NULL);
-    return 1;
-}
-
-
-
-// Change tab columns
-long EditWindow::onCmdTabColumns(FXObject* sender,FXSelector,void*)
-{
-    FXint tabs;
-    sender->handle(this,FXSEL(SEL_COMMAND,ID_GETINTVALUE),(void*)&tabs);
-    editor->setTabColumns(tabs);
-    return 1;
-}
-
-
-// Update tab columns
-long EditWindow::onUpdTabColumns(FXObject* sender,FXSelector,void*)
-{
-    FXint tabs=editor->getTabColumns();
-    sender->handle(this,FXSEL(SEL_COMMAND,ID_SETINTVALUE),(void*)&tabs);
-    return 1;
-}
-
-
-// Change wrap columns
-long EditWindow::onCmdWrapColumns(FXObject* sender,FXSelector,void*)
-{
-    FXint wrap;
-    sender->handle(this,FXSEL(SEL_COMMAND,ID_GETINTVALUE),(void*)&wrap);
-    editor->setWrapColumns(wrap);
-    return 1;
-}
-
-
-// Update wrap columns
-long EditWindow::onUpdWrapColumns(FXObject* sender,FXSelector,void*)
-{
-    FXint wrap=editor->getWrapColumns();
-    sender->handle(this,FXSEL(SEL_COMMAND,ID_SETINTVALUE),(void*)&wrap);
-    return 1;
-}
-
-
 // Update box for overstrike mode display
 long EditWindow::onUpdOverstrike(FXObject* sender,FXSelector,void*)
 {
@@ -1442,7 +1632,6 @@ long EditWindow::onUpdOverstrike(FXObject* sender,FXSelector,void*)
 }
 
 
-
 // Update box for size display
 long EditWindow::onUpdNumRows(FXObject* sender,FXSelector,void*)
 {
@@ -1452,170 +1641,6 @@ long EditWindow::onUpdNumRows(FXObject* sender,FXSelector,void*)
 }
 
 
-// Set scroll wheel lines (Mathew Robertson <mathew@optushome.com.au>)
-long EditWindow::onCmdWheelAdjust(FXObject* sender,FXSelector,void*)
-{
-    FXuint value;
-    sender->handle(this,FXSEL(SEL_COMMAND,ID_GETINTVALUE),(void*)&value);
-    getApp()->setWheelLines(value);
-    return 1;
-}
-
-
-// Update wheel lines
-long EditWindow::onUpdWheelAdjust(FXObject* sender,FXSelector,void*)
-{
-    FXuint value=getApp()->getWheelLines();
-    sender->handle(this,FXSEL(SEL_COMMAND,ID_SETINTVALUE),(void*)&value);
-    return 1;
-}
-
-
-// Change text color
-long EditWindow::onCmdTextForeColor(FXObject*,FXSelector,void* ptr)
-{
-    editor->setTextColor((FXColor)(FXuval)ptr);
-    return 1;
-}
-
-// Update text color
-long EditWindow::onUpdTextForeColor(FXObject* sender,FXSelector,void*)
-{
-    FXColor color=editor->getTextColor();
-    sender->handle(this,FXSEL(SEL_COMMAND,ID_SETINTVALUE),(void*)&color);
-    return 1;
-}
-
-
-// Change text background color
-long EditWindow::onCmdTextBackColor(FXObject*,FXSelector,void* ptr)
-{
-    editor->setBackColor((FXColor)(FXuval)ptr);
-    return 1;
-}
-
-// Update background color
-long EditWindow::onUpdTextBackColor(FXObject* sender,FXSelector,void*)
-{
-    FXColor color=editor->getBackColor();
-    sender->handle(this,FXSEL(SEL_COMMAND,ID_SETINTVALUE),(void*)&color);
-    return 1;
-}
-
-
-// Change selected text foreground color
-long EditWindow::onCmdTextSelForeColor(FXObject*,FXSelector,void* ptr)
-{
-    editor->setSelTextColor((FXColor)(FXuval)ptr);
-    return 1;
-}
-
-
-// Update selected text foregoround color
-long EditWindow::onUpdTextSelForeColor(FXObject* sender,FXSelector,void*)
-{
-    FXColor color=editor->getSelTextColor();
-    sender->handle(this,FXSEL(SEL_COMMAND,ID_SETINTVALUE),(void*)&color);
-    return 1;
-}
-
-
-// Change selected text background color
-long EditWindow::onCmdTextSelBackColor(FXObject*,FXSelector,void* ptr)
-{
-    editor->setSelBackColor((FXColor)(FXuval)ptr);
-    return 1;
-}
-
-// Update selected text background color
-long EditWindow::onUpdTextSelBackColor(FXObject* sender,FXSelector,void*)
-{
-    FXColor color=editor->getSelBackColor();
-    sender->handle(this,FXSEL(SEL_COMMAND,ID_SETINTVALUE),(void*)&color);
-    return 1;
-}
-
-
-// Change hilight text color
-long EditWindow::onCmdTextHiliteForeColor(FXObject*,FXSelector,void* ptr)
-{
-    editor->setHiliteTextColor((FXColor)(FXuval)ptr);
-    return 1;
-}
-
-// Update hilight text color
-long EditWindow::onUpdTextHiliteForeColor(FXObject* sender,FXSelector,void*)
-{
-    FXColor color=editor->getHiliteTextColor();
-    sender->handle(this,FXSEL(SEL_COMMAND,ID_SETINTVALUE),(void*)&color);
-    return 1;
-}
-
-
-// Change hilight text background color
-long EditWindow::onCmdTextHiliteBackColor(FXObject*,FXSelector,void* ptr)
-{
-    editor->setHiliteBackColor((FXColor)(FXuval)ptr);
-    return 1;
-}
-
-// Update hilight text background color
-long EditWindow::onUpdTextHiliteBackColor(FXObject* sender,FXSelector,void*)
-{
-    FXColor color=editor->getHiliteBackColor();
-    sender->handle(this,FXSEL(SEL_COMMAND,ID_SETINTVALUE),(void*)&color);
-    return 1;
-}
-
-
-// Change cursor color
-long EditWindow::onCmdTextCursorColor(FXObject*,FXSelector,void* ptr)
-{
-    editor->setCursorColor((FXColor)(FXuval)ptr);
-    return 1;
-}
-
-// Update cursor color
-long EditWindow::onUpdTextCursorColor(FXObject* sender,FXSelector,void*)
-{
-    FXColor color=editor->getCursorColor();
-    sender->handle(sender,FXSEL(SEL_COMMAND,FXWindow::ID_SETINTVALUE),(void*)&color);
-    return 1;
-}
-
-
-// Change line numbers background color
-long EditWindow::onCmdTextBarColor(FXObject*,FXSelector,void* ptr)
-{
-    editor->setBarColor((FXColor)(FXuval)ptr);
-    return 1;
-}
-
-
-// Update line numbers background color
-long EditWindow::onUpdTextBarColor(FXObject* sender,FXSelector,void*)
-{
-    FXColor color=editor->getBarColor();
-    sender->handle(this,FXSEL(SEL_COMMAND,ID_SETINTVALUE),(void*)&color);
-    return 1;
-}
-
-
-// Change line numbers color
-long EditWindow::onCmdTextNumberColor(FXObject*,FXSelector,void* ptr)
-{
-    editor->setNumberColor((FXColor)(FXuval)ptr);
-    return 1;
-}
-
-
-// Update line numbers color
-long EditWindow::onUpdTextNumberColor(FXObject* sender,FXSelector,void*)
-{
-    FXColor color=editor->getNumberColor();
-    sender->handle(this,FXSEL(SEL_COMMAND,ID_SETINTVALUE),(void*)&color);
-    return 1;
-}
 
 
 // Text inserted; callback has [pos nins]
