@@ -92,12 +92,46 @@ class Preferences : public DialogBox
 protected:
     FXIcon          *pal;
     FXIcon          *ind;
+	FXTextField*    wrapmargin;
+	FXString        wrapmargin_prev; 
+	FXTextField*    tabsize;
+	FXString        tabsize_prev; 
+	FXCheckButton*	stripcr;
+	FXbool	     	stripcr_prev;
+	FXText*         editor;
+	EditWindow*     editwin;
+	FXint           value_prev;
+	FXColor         textcolor_prev;
+	FXColor         backcolor_prev;
+	FXColor         seltextcolor_prev;
+	FXColor         selbackcolor_prev;
+	FXColor         hilitetextcolor_prev;
+	FXColor         hilitebackcolor_prev;
+	FXColor         cursorcolor_prev;
+	FXColor         barcolor_prev;
+	FXColor         numbercolor_prev;
 private:
     Preferences()
     {}
     Preferences(const Preferences&);
     Preferences& operator=(const Preferences&);
 public:
+    enum{
+        ID_ACCEPT=DialogBox::ID_LAST,
+		ID_CANCEL,
+		ID_WHEELADJUST,
+        ID_TEXT_BACK,
+        ID_TEXT_FORE,
+        ID_TEXT_SELBACK,
+        ID_TEXT_SELFORE,
+        ID_TEXT_HILITEBACK,
+        ID_TEXT_HILITEFORE,
+        ID_TEXT_CURSOR,
+        ID_TEXT_NUMBACK,
+        ID_TEXT_NUMFORE,
+        ID_LAST
+    };
+public:
 
     // Create preferences dialog
     Preferences(EditWindow *owner);
@@ -107,6 +141,29 @@ public:
     {
         return (XFileWrite*)DialogBox::getApp();
     }
+	FXuint execute(FXuint);
+	long onCmdCancel(FXObject*,FXSelector,void*);
+	long onCmdAccept(FXObject*,FXSelector,void*);
+	long onCmdWheelAdjust(FXObject*,FXSelector,void*);
+	long onUpdWheelAdjust(FXObject*,FXSelector,void*);
+    long onCmdTextBackColor(FXObject*,FXSelector,void*);
+    long onUpdTextBackColor(FXObject*,FXSelector,void*);
+    long onCmdTextForeColor(FXObject*,FXSelector,void*);
+    long onUpdTextForeColor(FXObject*,FXSelector,void*);
+    long onCmdTextSelBackColor(FXObject*,FXSelector,void*);
+    long onUpdTextSelBackColor(FXObject*,FXSelector,void*);
+    long onCmdTextSelForeColor(FXObject*,FXSelector,void*);
+    long onUpdTextSelForeColor(FXObject*,FXSelector,void*);
+    long onCmdTextHiliteBackColor(FXObject*,FXSelector,void*);
+    long onUpdTextHiliteBackColor(FXObject*,FXSelector,void*);
+    long onCmdTextHiliteForeColor(FXObject*,FXSelector,void*);
+    long onUpdTextHiliteForeColor(FXObject*,FXSelector,void*);
+    long onCmdTextCursorColor(FXObject*,FXSelector,void*);
+    long onUpdTextCursorColor(FXObject*,FXSelector,void*);
+    long onCmdTextBarColor(FXObject*,FXSelector,void*);
+    long onUpdTextBarColor(FXObject*,FXSelector,void*);
+    long onCmdTextNumberColor(FXObject*,FXSelector,void*);
+    long onUpdTextNumberColor(FXObject*,FXSelector,void*);
 };
 
 // Editor main window
@@ -176,33 +233,10 @@ public:
     long onCmdSaveAs(FXObject*,FXSelector,void*);
     long onCmdFont(FXObject*,FXSelector,void*);
     long onCmdPrint(FXObject*,FXSelector,void*);
-    long onCmdSaveSettings(FXObject*,FXSelector,void*);
 
     // Text display
-    long onCmdTextBackColor(FXObject*,FXSelector,void*);
-    long onUpdTextBackColor(FXObject*,FXSelector,void*);
-    long onCmdTextForeColor(FXObject*,FXSelector,void*);
-    long onUpdTextForeColor(FXObject*,FXSelector,void*);
-    long onCmdTextSelBackColor(FXObject*,FXSelector,void*);
-    long onUpdTextSelBackColor(FXObject*,FXSelector,void*);
-    long onCmdTextSelForeColor(FXObject*,FXSelector,void*);
-    long onUpdTextSelForeColor(FXObject*,FXSelector,void*);
-    long onCmdTextHiliteBackColor(FXObject*,FXSelector,void*);
-    long onUpdTextHiliteBackColor(FXObject*,FXSelector,void*);
-    long onCmdTextHiliteForeColor(FXObject*,FXSelector,void*);
-    long onUpdTextHiliteForeColor(FXObject*,FXSelector,void*);
-    long onCmdTextCursorColor(FXObject*,FXSelector,void*);
-    long onUpdTextCursorColor(FXObject*,FXSelector,void*);
-    long onCmdTextBarColor(FXObject*,FXSelector,void*);
-    long onUpdTextBarColor(FXObject*,FXSelector,void*);
-    long onCmdTextNumberColor(FXObject*,FXSelector,void*);
-    long onUpdTextNumberColor(FXObject*,FXSelector,void*);
     long onCmdLineNumbers(FXObject*,FXSelector,void*);
     long onUpdLineNumbers(FXObject*,FXSelector,void*);
-    long onCmdTabColumns(FXObject*,FXSelector,void*);
-    long onUpdTabColumns(FXObject*,FXSelector,void*);
-    long onCmdWrapColumns(FXObject*,FXSelector,void*);
-    long onUpdWrapColumns(FXObject*,FXSelector,void*);
     long onCmdWrap(FXObject*,FXSelector,void*);
     long onUpdWrap(FXObject*,FXSelector,void*);
 	long onCmdLinesNum(FXObject*,FXSelector,void*);
@@ -218,13 +252,9 @@ public:
     long onEditDNDDrop(FXObject*,FXSelector,void*);
 
     // Miscellaneous
-    long onCmdStripReturns(FXObject*,FXSelector,void*);
-    long onUpdStripReturns(FXObject*,FXSelector,void*);
     long onUpdOverstrike(FXObject*,FXSelector,void*);
     long onUpdNumRows(FXObject*,FXSelector,void*);
     long onCmdMorePrefs(FXObject*,FXSelector,void*);
-    long onCmdWheelAdjust(FXObject*,FXSelector,void*);
-    long onUpdWheelAdjust(FXObject*,FXSelector,void*);
     long onCmdWindow(FXObject*,FXSelector,void*);
     long onUpdWindow(FXObject*,FXSelector,void*);
 	long onCmdSearch(FXObject*,FXSelector,void*);
@@ -245,15 +275,6 @@ public:
         ID_FONT,
         ID_WINDOW,
         ID_PRINT,
-        ID_TEXT_BACK,
-        ID_TEXT_FORE,
-        ID_TEXT_SELBACK,
-        ID_TEXT_SELFORE,
-        ID_TEXT_HILITEBACK,
-        ID_TEXT_HILITEFORE,
-        ID_TEXT_CURSOR,
-        ID_TEXT_NUMBACK,
-        ID_TEXT_NUMFORE,
         ID_TEXT_LINENUMS,
 		ID_SEARCH,
 		ID_REPLACE,
@@ -262,16 +283,11 @@ public:
 		ID_GOTO_LINE,
 		ID_TOGGLE_WRAP,
         ID_TOGGLE_LINES_NUM,
-        ID_SAVE_SETTINGS,
         ID_TEXT,
-        ID_STRIP_CR,
         ID_INCLUDE_PATH,
         ID_OVERSTRIKE,
         ID_PREFERENCES,
-        ID_TABCOLUMNS,
-        ID_WRAPCOLUMNS,
         ID_NUM_ROWS,
-        ID_WHEELADJUST,
         ID_WINDOW_1,
         ID_WINDOW_2,
         ID_WINDOW_3,
@@ -361,6 +377,24 @@ public:
     {
         return filenameset;
     }
+	
+	// Obtain a pointer on the text widget
+	FXText* getEditor() const
+	{
+		return editor;
+	}
+	
+	// Get the value of the stripcr flag
+	FXbool getStripcr() const
+	{
+		return stripcr;
+	}
+	
+	// Set the value of the stripcr flag
+	void setStripcr(FXbool val)
+	{
+		stripcr=val;
+	}
 
     // Is it modified
     FXbool isModified() const;
