@@ -50,10 +50,11 @@ extern FXStringDict* updevices;
 #define STARTUP_TIME 3
 
 // Delay before the progress bar should be shown (ms)
-#define SHOW_PBAR_DELAY 1000
+#define SHOW_PROGRESSBAR_DELAY 1000
 
 // Progress dialog width
-#define PDIALOG_WIDTH 150
+#define PROGRESSDIALOG_WIDTH 150
+
 
 
 // Test if a string (typically a file name) is encoded in UTF-8
@@ -544,213 +545,6 @@ FXbool isGroupMember(gid_t gid)
 }
 
 
-
-/*
-// Check if the file or the link refered file is writable
-// Doesn't use the standard FOX function because of the stat timeout 
-FXbool isWritable(const FXString& file)
-{
-  	struct stat status;
-	FXuint uid=getuid();
-	
-	// File exists and can be stated
-	if (!file.empty() && (statrep(file.text(),&status)==0))
-	{
-		// We are root
-		if (uid==0)
-		{
-			return TRUE;
-		}
-		// We are owner of the file
-		else if (uid==status.st_uid)
-		{
-			// The file is writable
-			if (status.st_mode & S_IWUSR)
-				return TRUE;
-			else
-				return FALSE;
-		}
-		// We are in the group of the file
-		else if (isGroupMember(status.st_gid))
-		{
-			// The file is writable
-			if (status.st_mode & S_IWGRP)
-				return TRUE;
-			else
-				return FALSE;
-		}
-		// We are in others
-		else
-		{
-			// The file is writable
-			if (status.st_mode & S_IWOTH)
-				return TRUE;
-			else
-				return FALSE;
-		}
-	}	
-	
-	// File doesn't exist or cannot be stated
-	else
-		return FALSE;
-}
-
-
-
-// Check if the file or the link itself is writable
-// Doesn't use the standard FOX function because of the stat timeout 
-FXbool isLinkWritable(const FXString& file)
-{
-  	struct stat status;
-	FXuint uid=getuid();
-	
-	// File or link exists and can be stated
-	if (!file.empty() && (lstatrep(file.text(),&status)==0))
-	{
-		// We are root
-		if (uid==0)
-		{	
-			return TRUE;
-		}
-		// We are owner of the file or link
-		else if (uid==status.st_uid)
-		{
-			// The file or link is writable
-			if (status.st_mode & S_IWUSR)
-				return TRUE;
-			else
-				return FALSE;
-		}
-		// We are in the group of the file or link
-		else if (isGroupMember(status.st_gid))
-		{
-			// The file or link is writable
-			if (status.st_mode & S_IWGRP)
-				return TRUE;
-			else
-				return FALSE;
-		}
-		// We are other
-		else
-		{
-			// The file or link is writable
-			if (status.st_mode & S_IWOTH)
-				return TRUE;
-			else
-				return FALSE;
-		}
-	}	
-	
-	// File or link doesn't exist or cannot be stated
-	else
-		return FALSE;
-}
-
-
-
-// Check if the file or link is readable
-// Doesn't use the standard FOX function because of the stat timeout 
-FXbool isReadable(const FXString& file)
-{
-  	struct stat status;
-	FXuint uid=getuid();
-	
-	// File exists and can be stated
-	if (!file.empty() && (lstatrep(file.text(),&status)==0))
-	{
-		// We are root
-		if (uid==0)
-		{
-			return TRUE;
-		}
-		// We are owner of the file
-		else if (uid==status.st_uid)
-		{
-			// The file is readable
-			if (status.st_mode & S_IRUSR)
-				return TRUE;
-			else
-				return FALSE;
-		}
-		// We are in the group of the file
-		else if (isGroupMember(status.st_gid))
-		{
-			// The file is readable
-			if (status.st_mode & S_IRGRP)
-				return TRUE;
-			else
-				return FALSE;
-		}
-		// We are in others
-		else
-		{
-			// The file is readable
-			if (status.st_mode & S_IROTH)
-				return TRUE;
-			else
-				return FALSE;
-		}
-	}	
-	
-	// File doesn't exist or cannot be stated
-	else
-		return FALSE;
-}
-
-
-// Check if the file or the link refered file is readable AND executable
-// Function used to test if we can enter a directory
-// Doesn't use the standard FOX function because of the stat timeout 
-FXbool isReadExecutable(const FXString& file)
-{
-  	struct stat status;
-	FXuint uid=getuid();
-	
-	// File exists and can be stated
-	if (!file.empty() && (statrep(file.text(),&status)==0))
-	{
-		// We are root
-		if (uid==0)
-		{
-			return TRUE;
-		}
-		// We are owner of the file
-		else if (uid==status.st_uid)
-		{
-			// The file is readable and executable
-			if ((status.st_mode & S_IRUSR) && (status.st_mode & S_IXUSR))
-				return TRUE;
-			else
-				return FALSE;
-		}
-		// We are in the group of the file
-		else if (isGroupMember(status.st_gid))
-		{
-			// The file is readable and executable
-			if ((status.st_mode & S_IRGRP) && (status.st_mode & S_IXGRP))
-				return TRUE;
-			else
-				return FALSE;
-		}
-		// We are in others
-		else
-		{
-			// The file is readable and executable
-			if ((status.st_mode & S_IROTH) && (status.st_mode & S_IXOTH))
-				return TRUE;
-			else
-				return FALSE;
-		}
-	}	
-	
-	// File doesn't exist or cannot be stated
-	else
-		return FALSE;
-}
-*/
-
-
-
 // Check if the file or the link refered file is readable AND executable
 // Function used to test if we can enter a directory
 // Uses the access() system function 
@@ -884,10 +678,10 @@ FXIMPLEMENT(File,DialogBox,FileMap,ARRAYNUMBER(FileMap))
 File::File(FXWindow *owner, FXString title, const unsigned int operation):DialogBox(owner,title,DECOR_TITLE|DECOR_BORDER)
 {
     // Progress window
-	FXPacker *buttons=new FXPacker(this,LAYOUT_SIDE_BOTTOM|LAYOUT_FILL_X,0,0,10,10,PDIALOG_WIDTH,PDIALOG_WIDTH,5,5);
+	FXPacker *buttons=new FXPacker(this,LAYOUT_SIDE_BOTTOM|LAYOUT_FILL_X,0,0,10,10,PROGRESSDIALOG_WIDTH,PROGRESSDIALOG_WIDTH,5,5);
     new FXHorizontalSeparator(this,LAYOUT_SIDE_BOTTOM|LAYOUT_FILL_X|SEPARATOR_GROOVE);
     FXVerticalFrame *contents=new FXVerticalFrame(this,LAYOUT_SIDE_TOP|FRAME_NONE|LAYOUT_FILL_X|LAYOUT_FILL_Y);
-	allowPdialog=TRUE;
+	allowProgressDialog=TRUE;
 
     // Cancel Button
     cancelButton=new FXButton(buttons,_("&Cancel"),NULL,this,File::ID_CANCEL_BUTTON,FRAME_RAISED|FRAME_THICK|LAYOUT_CENTER_X,0,0,0,0,20,20);
@@ -896,7 +690,7 @@ File::File(FXWindow *owner, FXString title, const unsigned int operation):Dialog
 	isCancelled=FALSE;
 
 	// Progress bar
-	pbar=NULL;
+	progressbar=NULL;
 
 	// Progress dialog depends on the file operation
 	switch(operation)	
@@ -905,20 +699,20 @@ File::File(FXWindow *owner, FXString title, const unsigned int operation):Dialog
 	    	// Labels and progress bar
 			uplabel=new FXLabel(contents,_("Source :"),NULL,JUSTIFY_LEFT|LAYOUT_FILL_X);
     		downlabel=new FXLabel(contents,_("Target :"),NULL,JUSTIFY_LEFT|LAYOUT_FILL_X);
-			pbar=new FXProgressBar(contents,NULL,0,LAYOUT_FILL_X|FRAME_SUNKEN|FRAME_THICK|PROGRESSBAR_PERCENTAGE,0,0,0,0,PDIALOG_WIDTH);
+			progressbar=new FXProgressBar(contents,NULL,0,LAYOUT_FILL_X|FRAME_SUNKEN|FRAME_THICK|PROGRESSBAR_PERCENTAGE,0,0,0,0,PROGRESSDIALOG_WIDTH);
 		
 			// Timer on
-			getApp()->addTimeout(this,File::ID_TIMEOUT,SHOW_PBAR_DELAY);
+			getApp()->addTimeout(this,File::ID_TIMEOUT,SHOW_PROGRESSBAR_DELAY);
 			break;
 
     	case MOVE:
 	    	// Labels and progress bar
 			uplabel=new FXLabel(contents,_("Source :"),NULL,JUSTIFY_LEFT|LAYOUT_FILL_X);
     		downlabel=new FXLabel(contents,_("Target :"),NULL,JUSTIFY_LEFT|LAYOUT_FILL_X);
-			pbar=new FXProgressBar(contents,NULL,0,LAYOUT_FILL_X|FRAME_SUNKEN|FRAME_THICK|PROGRESSBAR_PERCENTAGE,0,0,0,0,PDIALOG_WIDTH);
+			progressbar=new FXProgressBar(contents,NULL,0,LAYOUT_FILL_X|FRAME_SUNKEN|FRAME_THICK|PROGRESSBAR_PERCENTAGE,0,0,0,0,PROGRESSDIALOG_WIDTH);
 
 			// Timer on
-			getApp()->addTimeout(this,File::ID_TIMEOUT,SHOW_PBAR_DELAY);
+			getApp()->addTimeout(this,File::ID_TIMEOUT,SHOW_PROGRESSBAR_DELAY);
 			break;
 
     	case DELETE:
@@ -927,7 +721,7 @@ File::File(FXWindow *owner, FXString title, const unsigned int operation):Dialog
     		downlabel=new FXLabel(contents,_("From :"),NULL,JUSTIFY_LEFT|LAYOUT_FILL_X);
 
 			// Timer on
-			getApp()->addTimeout(this,File::ID_TIMEOUT,SHOW_PBAR_DELAY);
+			getApp()->addTimeout(this,File::ID_TIMEOUT,SHOW_PROGRESSBAR_DELAY);
 			break;
 
     	case CHMOD:
@@ -936,7 +730,7 @@ File::File(FXWindow *owner, FXString title, const unsigned int operation):Dialog
     		downlabel=new FXLabel(contents,_("File :"),NULL,JUSTIFY_LEFT|LAYOUT_FILL_X);
 
 			// Timer on
-			getApp()->addTimeout(this,File::ID_TIMEOUT,SHOW_PBAR_DELAY);
+			getApp()->addTimeout(this,File::ID_TIMEOUT,SHOW_PROGRESSBAR_DELAY);
 			break;
 
     	case CHOWN:
@@ -945,7 +739,7 @@ File::File(FXWindow *owner, FXString title, const unsigned int operation):Dialog
     		downlabel=new FXLabel(contents,_("File :"),NULL,JUSTIFY_LEFT|LAYOUT_FILL_X);
 
 			// Timer on
-			getApp()->addTimeout(this,File::ID_TIMEOUT,SHOW_PBAR_DELAY);
+			getApp()->addTimeout(this,File::ID_TIMEOUT,SHOW_PROGRESSBAR_DELAY);
 			break;
 
 #if defined(linux)
@@ -989,7 +783,7 @@ File::File(FXWindow *owner, FXString title, const unsigned int operation):Dialog
 File::~File()
 {
 	getApp()->removeTimeout(this,File::ID_TIMEOUT);
-    delete pbar;
+    delete progressbar;
 }
 
 
@@ -1000,6 +794,7 @@ void File::create()
 	DialogBox::create();
 }
 
+
 // Force check of timeout for progress dialog (to avoid latency problems)
 int File::checkTimeout(void)
 {
@@ -1008,7 +803,7 @@ int File::checkTimeout(void)
 		if (getApp()->remainingTimeout(this,File::ID_TIMEOUT)==0)
 		{
 			getApp()->removeTimeout(this,File::ID_TIMEOUT);
-			if (allowPdialog)
+			if (allowProgressDialog)
 				show(PLACEMENT_OWNER);
 			getApp()->forceRefresh();
 			getApp()->flush();
@@ -1018,6 +813,7 @@ int File::checkTimeout(void)
 	return 0;
 }
 
+
 // Read bytes
 long File::fullread(int fd,unsigned char *ptr,long len)
 {
@@ -1060,7 +856,7 @@ long File::fullwrite(int fd,const unsigned char *ptr,long len)
 FXbool File::copyfile(const FXString& source, const FXString& target, const FXbool preserve_date)
 {
 	FXString destfile;
-	unsigned char buffer[4096];
+	unsigned char buffer[16384];
     struct stat status;
 	struct utimbuf timbuf;
     long long nread,nwritten;
@@ -1100,8 +896,8 @@ FXbool File::copyfile(const FXString& source, const FXString& target, const FXbo
 					// Set percentage value for progress dialog
 					nread_all+=nread;
 					pct=100*(double)nread_all/(double)size;	
-					if (pbar)
-						pbar->setProgress((int)pct);
+					if (progressbar)
+						progressbar->setProgress((int)pct);
 
 					// Give cancel button an opportunity to be clicked
 					if(cancelButton)
@@ -1409,7 +1205,7 @@ FXbool File::remove(const FXString& file)
 				
 				// Used to display only one progress dialog when deleting a directory
 				ISDIR=TRUE;
-				
+							
 				// Force timeout checking for progress dialog
 				checkTimeout();
 
@@ -1634,8 +1430,8 @@ FXbool File::move(const FXString& source,const FXString& target)
 	}
 
 	// Set the progress to 100% for move file operation
-	if (pbar)
-		pbar->setProgress(100);
+	if (progressbar)
+		progressbar->setProgress(100);
 
 	// Rename file using the standard C function
 	// This should only work for files that are on the same file system
@@ -2023,6 +1819,7 @@ int File::extract(const FXString name, const FXString dir, const FXString cmd)
     // Make and show command window
 	CommandWindow *cmdwin=new CommandWindow(getApp(),_("Extract archive"),cmd,30,80);			
 	cmdwin->create();
+	cmdwin->setIcon(archexticon);
 
 	// The command window object deletes itself after closing the window!
 
@@ -2066,6 +1863,7 @@ int File::archive(const FXString name, const FXString cmd)
     // Make and show command window
 	CommandWindow *cmdwin=new CommandWindow(getApp(),_("Add to archive"),cmd,30,80);			
 	cmdwin->create();
+	cmdwin->setIcon(archaddicon);
 
 	// The command window object deletes itself after closing the window!
 
@@ -2175,7 +1973,7 @@ long File::onCmdCancel(FXObject*, FXSelector,void*)
 // Handle timeout for progress bar
 long File::onTimeout(FXObject*, FXSelector,void*)
 {
-	if (allowPdialog)
+	if (allowProgressDialog)
 		show(PLACEMENT_OWNER);
     getApp()->forceRefresh();
     getApp()->flush();
