@@ -89,7 +89,7 @@ protected:
     int rchown(char *path, char *file, uid_t uid, gid_t gid, const FXbool dironly, const FXbool fileonly);
     FXLabel *uplabel;
     FXLabel *downlabel;
-    FXProgressBar *pbar;
+    FXProgressBar *progressbar;
 	FXButton *cancelButton;
 	FXbool overwrite;
 	FXbool overwrite_all;
@@ -109,7 +109,7 @@ public:
 		ID_LAST
 	};
 
-	FXbool allowPdialog;
+	FXbool allowProgressDialog;
 	FXbool isCancelled;
     FXbool copy(const FXString& source, const FXString& target, const FXbool confirm_dialog=TRUE, const FXbool preserve_date=TRUE);
     FXbool rename(const FXString& source, const FXString& target);
