@@ -27,29 +27,30 @@ extern FXbool allowPopupScroll;
 
 
 // Map
-FXDEFMAP(FileSelector) FileSelectorMap[]={
-            FXMAPFUNC(SEL_COMMAND,FileSelector::ID_ACCEPT,FileSelector::onCmdAccept),
-            FXMAPFUNC(SEL_COMMAND,FileSelector::ID_FILEFILTER,FileSelector::onCmdFilter),
-            FXMAPFUNC(SEL_DOUBLECLICKED,FileSelector::ID_FILELIST,FileSelector::onCmdItemDoubleClicked),
-            FXMAPFUNC(SEL_CLICKED,FileSelector::ID_FILELIST,FileSelector::onCmdItemClicked),
-            FXMAPFUNC(SEL_SELECTED,FileSelector::ID_FILELIST,FileSelector::onCmdItemSelected),
-            FXMAPFUNC(SEL_DESELECTED,FileSelector::ID_FILELIST,FileSelector::onCmdItemDeselected),
-            FXMAPFUNC(SEL_COMMAND,FileSelector::ID_DIR_UP,FileSelector::onCmdDirUp),
-            FXMAPFUNC(SEL_UPDATE,FileSelector::ID_DIR_UP,FileSelector::onUpdDirUp),
-            FXMAPFUNC(SEL_COMMAND,FileSelector::ID_DIR_BACK,FileSelector::onCmdDirBack),
-			FXMAPFUNC(SEL_UPDATE,FileSelector::ID_DIR_BACK,FileSelector::onUpdDirBack),
-            FXMAPFUNC(SEL_COMMAND,FileSelector::ID_DIR_FORWARD,FileSelector::onCmdDirForward),
-			FXMAPFUNC(SEL_UPDATE,FileSelector::ID_DIR_FORWARD,FileSelector::onUpdDirForward),
-            FXMAPFUNC(SEL_COMMAND,FileSelector::ID_DIR_BACK_HIST,FileSelector::onCmdDirBackHist),
-			FXMAPFUNC(SEL_UPDATE,FileSelector::ID_DIR_BACK_HIST,FileSelector::onUpdDirBackHist),
-            FXMAPFUNC(SEL_COMMAND,FileSelector::ID_DIR_FORWARD_HIST,FileSelector::onCmdDirForwardHist),
-			FXMAPFUNC(SEL_UPDATE,FileSelector::ID_DIR_FORWARD_HIST,FileSelector::onUpdDirForwardHist),
-            FXMAPFUNC(SEL_COMMAND,FileSelector::ID_DIR_TREE,FileSelector::onCmdDirTree),
-            FXMAPFUNC(SEL_COMMAND,FileSelector::ID_HOME,FileSelector::onCmdHome),
-            FXMAPFUNC(SEL_COMMAND,FileSelector::ID_NEWDIR,FileSelector::onCmdNewDir),
-            FXMAPFUNC(SEL_COMMAND,FileSelector::ID_WORK,FileSelector::onCmdWork),
-            FXMAPFUNC(SEL_RIGHTBUTTONRELEASE,FileSelector::ID_FILELIST,FileSelector::onCmdPopupMenu),
-        };
+FXDEFMAP(FileSelector) FileSelectorMap[]=
+{
+	FXMAPFUNC(SEL_COMMAND,FileSelector::ID_ACCEPT,FileSelector::onCmdAccept),
+	FXMAPFUNC(SEL_COMMAND,FileSelector::ID_FILEFILTER,FileSelector::onCmdFilter),
+	FXMAPFUNC(SEL_DOUBLECLICKED,FileSelector::ID_FILELIST,FileSelector::onCmdItemDoubleClicked),
+	FXMAPFUNC(SEL_CLICKED,FileSelector::ID_FILELIST,FileSelector::onCmdItemClicked),
+	FXMAPFUNC(SEL_SELECTED,FileSelector::ID_FILELIST,FileSelector::onCmdItemSelected),
+	FXMAPFUNC(SEL_DESELECTED,FileSelector::ID_FILELIST,FileSelector::onCmdItemDeselected),
+	FXMAPFUNC(SEL_COMMAND,FileSelector::ID_DIR_UP,FileSelector::onCmdDirUp),
+	FXMAPFUNC(SEL_UPDATE,FileSelector::ID_DIR_UP,FileSelector::onUpdDirUp),
+	FXMAPFUNC(SEL_COMMAND,FileSelector::ID_DIR_BACK,FileSelector::onCmdDirBack),
+	FXMAPFUNC(SEL_UPDATE,FileSelector::ID_DIR_BACK,FileSelector::onUpdDirBack),
+	FXMAPFUNC(SEL_COMMAND,FileSelector::ID_DIR_FORWARD,FileSelector::onCmdDirForward),
+	FXMAPFUNC(SEL_UPDATE,FileSelector::ID_DIR_FORWARD,FileSelector::onUpdDirForward),
+	FXMAPFUNC(SEL_COMMAND,FileSelector::ID_DIR_BACK_HIST,FileSelector::onCmdDirBackHist),
+	FXMAPFUNC(SEL_UPDATE,FileSelector::ID_DIR_BACK_HIST,FileSelector::onUpdDirBackHist),
+	FXMAPFUNC(SEL_COMMAND,FileSelector::ID_DIR_FORWARD_HIST,FileSelector::onCmdDirForwardHist),
+	FXMAPFUNC(SEL_UPDATE,FileSelector::ID_DIR_FORWARD_HIST,FileSelector::onUpdDirForwardHist),
+	FXMAPFUNC(SEL_COMMAND,FileSelector::ID_DIR_TREE,FileSelector::onCmdDirTree),
+	FXMAPFUNC(SEL_COMMAND,FileSelector::ID_HOME,FileSelector::onCmdHome),
+	FXMAPFUNC(SEL_COMMAND,FileSelector::ID_NEWDIR,FileSelector::onCmdNewDir),
+	FXMAPFUNC(SEL_COMMAND,FileSelector::ID_WORK,FileSelector::onCmdWork),
+	FXMAPFUNC(SEL_RIGHTBUTTONRELEASE,FileSelector::ID_FILELIST,FileSelector::onCmdPopupMenu),
+};
 
 
 // Implementation
@@ -191,8 +192,7 @@ long FileSelector::onCmdItemClicked(FXObject*,FXSelector,void* ptr)
 				{
 					MessageBox::error(this,BOX_OK,_("Error"),_(" Permission to: %s denied."), filepath.text());
 					return 0;
-				}
-				
+				}				
 				setDirectory(filepath);
 				return 1;
 			}
@@ -213,6 +213,7 @@ long FileSelector::onCmdItemSelected(FXObject*,FXSelector,void* ptr)
 {
     FXint index=(FXint)(long)ptr;
     FXString text,file;
+
     if(selectmode==SELECT_FILE_MULTIPLE)
     {
         for(FXint i=0; i<list->getNumItems(); i++)
@@ -243,8 +244,11 @@ long FileSelector::onCmdItemSelected(FXObject*,FXSelector,void* ptr)
     {
         if(list->isItemDirectory(index))
         {
-            text=list->getItemFilename(index);
-            filename->setText(text);
+			if (list->getItemFilename(index)!="..")
+			{
+				text=list->getItemFilename(index);
+				filename->setText(text);
+			}
         }
     }
     // Mode added to select both directories and files
@@ -307,20 +311,25 @@ long FileSelector::onCmdAccept(FXObject*,FXSelector,void*)
 
     // Get (first) filename
     FXString path=getFilename();
+	
+	// If filename is empty, we get the current directory
+	if(path.empty())
+	{
+		path=list->getDirectory();
+        filename->setText(path);
+	}
 
     // Only do something if a selection was made
     if(!path.empty())
     {
-
         // Is directory?
         if(::isDirectory(path))
         {
-
             // In directory mode:- we got our answer!
             if(selectmode==SELECT_FILE_DIRECTORY || selectmode==SELECT_FILE_MULTIPLE_ALL || selectmode==SELECT_FILE_MIXED)
             {
                 if(tgt)
-                    tgt->handle(accept,FXSEL(SEL_COMMAND,sel),(void*)1);
+                   tgt->handle(accept,FXSEL(SEL_COMMAND,sel),(void*)1);
                 return 1;
             }
 
@@ -1157,9 +1166,9 @@ long FileSelector::onCmdPopupMenu(FXObject* o,FXSelector s,void* p)
 	new FXMenuCheck(&menu,_("&Hidden files"),list,FileList::ID_TOGGLE_HIDDEN);
 	new FXMenuCheck(&menu,_("Thum&bnails"),list,FileList::ID_TOGGLE_THUMBNAILS);
 	new FXMenuSeparator(&menu);
-	new FXMenuRadio(&menu,_("B&ig icons"),list,FXIconList::ID_SHOW_BIG_ICONS);
-	new FXMenuRadio(&menu,_("&Small icons"),list,FXIconList::ID_SHOW_MINI_ICONS);
-	new FXMenuRadio(&menu,_("F&ull file list"),list,FXIconList::ID_SHOW_DETAILS);
+	new FXMenuRadio(&menu,_("B&ig icons"),list,IconList::ID_SHOW_BIG_ICONS);
+	new FXMenuRadio(&menu,_("&Small icons"),list,IconList::ID_SHOW_MINI_ICONS);
+	new FXMenuRadio(&menu,_("F&ull file list"),list,IconList::ID_SHOW_DETAILS);
 	new FXMenuSeparator(&menu);
 	new FXMenuRadio(&menu,_("&Rows"),list,FileList::ID_ARRANGE_BY_ROWS);
 	new FXMenuRadio(&menu,_("&Columns"),list,FileList::ID_ARRANGE_BY_COLUMNS);
