@@ -1,6 +1,7 @@
 #ifndef FILEDIALOG_H
 #define FILEDIALOG_H
 
+#include "DialogBox.h"
 #include "FileList.h"
 #include "DirBox.h"
 
@@ -8,12 +9,24 @@ class FileSelector;
 class FileList;
 class DirBox;
 
+
+// Additional mode for file selection : same as SELECTFILE_DIRECTORY but with the ability to also select files
+enum {
+		SELECT_FILE_ANY,             // A single file, existing or not (to save to)
+		SELECT_FILE_EXISTING,        // An existing file (to load)
+		SELECT_FILE_MULTIPLE,        // Multiple existing files
+		SELECT_FILE_MULTIPLE_ALL,    // Multiple existing files or directories, but not '.' and '..'
+		SELECT_FILE_DIRECTORY,       // Existing directory, including '.' or '..'
+		SELECT_FILE_MIXED,
+	};
+
+
 // File selection widget
 class FXAPI FileSelector : public FXPacker
 {
     FXDECLARE(FileSelector)
 protected:
-    FileList      *filebox;         // File list widget
+    FileList      *list;            // File list widget
     DirBox        *dirbox;          // Directory hierarchy list
     FXTextField   *filename;        // File name entry field
     FXComboBox    *filefilter;      // Combobox for pattern list
@@ -21,8 +34,8 @@ protected:
     FXButton      *accept;          // Accept button
     FXButton      *cancel;          // Cancel button
     FXuint         selectmode;      // Select mode
-	FXArrowButton   *btnbackhist;
-	FXArrowButton   *btnforwardhist;
+	FXArrowButton   *btnbackhist;     // Back history
+	FXArrowButton   *btnforwardhist;  // Forward history
 protected:
     FileSelector()
     {}
@@ -51,6 +64,8 @@ public:
     long onCmdDirTree(FXObject*,FXSelector,void*);
     long onCmdHome(FXObject*,FXSelector,void*);
     long onCmdWork(FXObject*,FXSelector,void*);
+	long onCmdNewDir(FXObject*,FXSelector,void*);
+	long onCmdPopupMenu(FXObject*,FXSelector,void*);
 public:
     enum {
         ID_FILEFILTER=FXPacker::ID_LAST,
@@ -64,6 +79,7 @@ public:
         ID_DIR_TREE,
         ID_HOME,
         ID_WORK,
+		ID_NEWDIR,
         ID_LAST
     };
 public:
@@ -180,11 +196,11 @@ public:
 
 
 // File Dialog object
-class FXAPI FileDialog : public FXDialogBox
+class FXAPI FileDialog : public DialogBox
 {
     FXDECLARE(FileDialog)
 protected:
-    FileSelector *filebox;
+    FileSelector *list;
 protected:
     FileDialog()
     {}
