@@ -2,6 +2,7 @@
 #define FILELIST_H
 
 #include "StringList.h"
+#include "IconList.h"
 
 
 struct FileAssoc;
@@ -9,7 +10,7 @@ class  FileDict;
 class  FileList;
 
 // File item
-class FXAPI FileItem : public FXIconItem
+class FXAPI FileItem : public IconItem
 {
     FXDECLARE(FileItem)
     friend class FileList;
@@ -34,7 +35,7 @@ protected:
     };
 public:
     // Constructor
-    FileItem(const FXString& text,FXIcon* bi=NULL,FXIcon* mi=NULL,void* ptr=NULL):FXIconItem(text,bi,mi,ptr),assoc(NULL),link(NULL),size(0),date(0)
+    FileItem(const FXString& text,FXIcon* bi=NULL,FXIcon* mi=NULL,void* ptr=NULL):IconItem(text,bi,mi,ptr),assoc(NULL),link(NULL),size(0),date(0)
     {}
 
     // Return true if this is a file item
@@ -106,7 +107,7 @@ public:
 
 
 // File List object
-class FXAPI FileList : public FXIconList
+class FXAPI FileList : public IconList
 {
     FXDECLARE(FileList)
 protected:
@@ -129,6 +130,7 @@ protected:
 	FXString	trashlocation;          // Location of the trash directory
 	FXbool      single;                 // Allow single click navigation for directories
 	FXbool		dirsfirst;				// Sort directories first
+	FXint		deldatesize;
 
 public:
 	StringList		*backhist;          // Back history
@@ -137,7 +139,7 @@ public:
 protected:
     FileList()
 	{}
-    virtual FXIconItem *createItem(const FXString& text,FXIcon *big,FXIcon* mini,void* ptr);
+    virtual IconItem *createItem(const FXString& text,FXIcon *big,FXIcon* mini,void* ptr);
     void listItems();
 private:
     FileList(const FileList&);
@@ -198,51 +200,51 @@ public:
 	long onCmdDragReject(FXObject* sender,FXSelector,void*);
 	
 public:
-	static FXint ascending(const FXIconItem* pa,const FXIconItem* pb);
-	static FXint descending(const FXIconItem* pa,const FXIconItem* pb);
-	static FXint ascendingCase(const FXIconItem* pa,const FXIconItem* pb);
-	static FXint descendingCase(const FXIconItem* pa,const FXIconItem* pb);
-	static FXint ascendingType(const FXIconItem* pa,const FXIconItem* pb);
-	static FXint descendingType(const FXIconItem* pa,const FXIconItem* pb);
-	static FXint ascendingSize(const FXIconItem* pa,const FXIconItem* pb);
-	static FXint descendingSize(const FXIconItem* pa,const FXIconItem* pb);
-	static FXint ascendingExt(const FXIconItem* pa,const FXIconItem* pb);
-	static FXint descendingExt(const FXIconItem* pa,const FXIconItem* pb);
-	static FXint ascendingTime(const FXIconItem* pa,const FXIconItem* pb);
-	static FXint descendingTime(const FXIconItem* pa,const FXIconItem* pb);
-	static FXint ascendingUser(const FXIconItem* pa,const FXIconItem* pb);
-	static FXint descendingUser(const FXIconItem* pa,const FXIconItem* pb);
-	static FXint ascendingGroup(const FXIconItem* pa,const FXIconItem* pb);
-	static FXint descendingGroup(const FXIconItem* pa,const FXIconItem* pb);
-	static FXint ascendingPerm(const FXIconItem* pa,const FXIconItem* pb);
-	static FXint descendingPerm(const FXIconItem* pa,const FXIconItem* pb);
-	static FXint ascendingDeltime(const FXIconItem* pa,const FXIconItem* pb);
-	static FXint descendingDeltime(const FXIconItem* pa,const FXIconItem* pb);
+	static FXint ascending(const IconItem* pa,const IconItem* pb);
+	static FXint descending(const IconItem* pa,const IconItem* pb);
+	static FXint ascendingCase(const IconItem* pa,const IconItem* pb);
+	static FXint descendingCase(const IconItem* pa,const IconItem* pb);
+	static FXint ascendingType(const IconItem* pa,const IconItem* pb);
+	static FXint descendingType(const IconItem* pa,const IconItem* pb);
+	static FXint ascendingSize(const IconItem* pa,const IconItem* pb);
+	static FXint descendingSize(const IconItem* pa,const IconItem* pb);
+	static FXint ascendingExt(const IconItem* pa,const IconItem* pb);
+	static FXint descendingExt(const IconItem* pa,const IconItem* pb);
+	static FXint ascendingTime(const IconItem* pa,const IconItem* pb);
+	static FXint descendingTime(const IconItem* pa,const IconItem* pb);
+	static FXint ascendingUser(const IconItem* pa,const IconItem* pb);
+	static FXint descendingUser(const IconItem* pa,const IconItem* pb);
+	static FXint ascendingGroup(const IconItem* pa,const IconItem* pb);
+	static FXint descendingGroup(const IconItem* pa,const IconItem* pb);
+	static FXint ascendingPerm(const IconItem* pa,const IconItem* pb);
+	static FXint descendingPerm(const IconItem* pa,const IconItem* pb);
+	static FXint ascendingDeltime(const IconItem* pa,const IconItem* pb);
+	static FXint descendingDeltime(const IconItem* pa,const IconItem* pb);
 
-	static FXint ascendingMix(const FXIconItem* pa,const FXIconItem* pb);
-	static FXint descendingMix(const FXIconItem* pa,const FXIconItem* pb);
-	static FXint ascendingCaseMix(const FXIconItem* pa,const FXIconItem* pb);
-	static FXint descendingCaseMix(const FXIconItem* pa,const FXIconItem* pb);
-	static FXint ascendingTypeMix(const FXIconItem* pa,const FXIconItem* pb);
-	static FXint descendingTypeMix(const FXIconItem* pa,const FXIconItem* pb);
-	static FXint ascendingSizeMix(const FXIconItem* pa,const FXIconItem* pb);
-	static FXint descendingSizeMix(const FXIconItem* pa,const FXIconItem* pb);
-	static FXint ascendingExtMix(const FXIconItem* pa,const FXIconItem* pb);
-	static FXint descendingExtMix(const FXIconItem* pa,const FXIconItem* pb);
-	static FXint ascendingTimeMix(const FXIconItem* pa,const FXIconItem* pb);
-	static FXint descendingTimeMix(const FXIconItem* pa,const FXIconItem* pb);
-	static FXint ascendingUserMix(const FXIconItem* pa,const FXIconItem* pb);
-	static FXint descendingUserMix(const FXIconItem* pa,const FXIconItem* pb);
-	static FXint ascendingGroupMix(const FXIconItem* pa,const FXIconItem* pb);
-	static FXint descendingGroupMix(const FXIconItem* pa,const FXIconItem* pb);
-	static FXint ascendingPermMix(const FXIconItem* pa,const FXIconItem* pb);
-	static FXint descendingPermMix(const FXIconItem* pa,const FXIconItem* pb);
-	static FXint ascendingDeltimeMix(const FXIconItem* pa,const FXIconItem* pb);
-	static FXint descendingDeltimeMix(const FXIconItem* pa,const FXIconItem* pb);
+	static FXint ascendingMix(const IconItem* pa,const IconItem* pb);
+	static FXint descendingMix(const IconItem* pa,const IconItem* pb);
+	static FXint ascendingCaseMix(const IconItem* pa,const IconItem* pb);
+	static FXint descendingCaseMix(const IconItem* pa,const IconItem* pb);
+	static FXint ascendingTypeMix(const IconItem* pa,const IconItem* pb);
+	static FXint descendingTypeMix(const IconItem* pa,const IconItem* pb);
+	static FXint ascendingSizeMix(const IconItem* pa,const IconItem* pb);
+	static FXint descendingSizeMix(const IconItem* pa,const IconItem* pb);
+	static FXint ascendingExtMix(const IconItem* pa,const IconItem* pb);
+	static FXint descendingExtMix(const IconItem* pa,const IconItem* pb);
+	static FXint ascendingTimeMix(const IconItem* pa,const IconItem* pb);
+	static FXint descendingTimeMix(const IconItem* pa,const IconItem* pb);
+	static FXint ascendingUserMix(const IconItem* pa,const IconItem* pb);
+	static FXint descendingUserMix(const IconItem* pa,const IconItem* pb);
+	static FXint ascendingGroupMix(const IconItem* pa,const IconItem* pb);
+	static FXint descendingGroupMix(const IconItem* pa,const IconItem* pb);
+	static FXint ascendingPermMix(const IconItem* pa,const IconItem* pb);
+	static FXint descendingPermMix(const IconItem* pa,const IconItem* pb);
+	static FXint ascendingDeltimeMix(const IconItem* pa,const IconItem* pb);
+	static FXint descendingDeltimeMix(const IconItem* pa,const IconItem* pb);
 public:
 	enum {
 		// Note : the order of the 9 following sort IDs must be kept
-        ID_SORT_BY_NAME=FXIconList::ID_LAST,
+        ID_SORT_BY_NAME=IconList::ID_LAST,
         ID_SORT_BY_SIZE,
         ID_SORT_BY_TYPE,
         ID_SORT_BY_EXT,
@@ -362,6 +364,10 @@ public:
 		dirsfirst=dfirst;
 	}
 
+	FXint getHeaderSize(FXint index) const;
+	
+	void setHeaderSize(FXint index,FXint size);
+
 	// Allow or disallow periodic refresh
 	void setAllowRefresh(const FXbool allow);
 
