@@ -54,7 +54,7 @@ public:
 
 
 FilePanel(FXchar*,FXComposite*, FXuint name_size=200, FXuint size_size=60, FXuint type_size=100, FXuint ext_size=100, 
-	      FXuint modd_size=150, FXuint user_size=50, FXuint grou_size=50, FXuint attr_size=100, FXColor listbackcolor=FXRGB(255,255,255), FXColor listforecolor=FXRGB(0,0,0),
+	      FXuint modd_size=150, FXuint user_size=50, FXuint grou_size=50, FXuint attr_size=100, FXuint deldate_size=150, FXColor listbackcolor=FXRGB(255,255,255), FXColor listforecolor=FXRGB(0,0,0),
  		  FXuint opts=0,FXint x=0,FXint y=0,FXint w=0,FXint h=0);
     FilePanel()
     {}
