@@ -8,24 +8,25 @@
 #include "FontDialog.h"
 
 // Map
-FXDEFMAP(FontSelector) FontSelectorMap[]={
-            FXMAPFUNC(SEL_COMMAND,FontSelector::ID_FAMILY,FontSelector::onCmdFamily),
-            FXMAPFUNC(SEL_COMMAND,FontSelector::ID_WEIGHT,FontSelector::onCmdWeight),
-            FXMAPFUNC(SEL_COMMAND,FontSelector::ID_SIZE,FontSelector::onCmdSize),
-            FXMAPFUNC(SEL_COMMAND,FontSelector::ID_SIZE_TEXT,FontSelector::onCmdSizeText),
-            FXMAPFUNC(SEL_COMMAND,FontSelector::ID_STYLE,FontSelector::onCmdStyle),
-            FXMAPFUNC(SEL_COMMAND,FontSelector::ID_STYLE_TEXT,FontSelector::onCmdStyleText),
-            FXMAPFUNC(SEL_COMMAND,FontSelector::ID_CHARSET,FontSelector::onCmdCharset),
-            FXMAPFUNC(SEL_UPDATE,FontSelector::ID_CHARSET,FontSelector::onUpdCharset),
-            FXMAPFUNC(SEL_COMMAND,FontSelector::ID_SETWIDTH,FontSelector::onCmdSetWidth),
-            FXMAPFUNC(SEL_UPDATE,FontSelector::ID_SETWIDTH,FontSelector::onUpdSetWidth),
-            FXMAPFUNC(SEL_COMMAND,FontSelector::ID_PITCH,FontSelector::onCmdPitch),
-            FXMAPFUNC(SEL_UPDATE,FontSelector::ID_PITCH,FontSelector::onUpdPitch),
-            FXMAPFUNC(SEL_UPDATE,FontSelector::ID_SCALABLE,FontSelector::onUpdScalable),
-            FXMAPFUNC(SEL_COMMAND,FontSelector::ID_SCALABLE,FontSelector::onCmdScalable),
-            FXMAPFUNC(SEL_UPDATE,FontSelector::ID_ALLFONTS,FontSelector::onUpdAllFonts),
-            FXMAPFUNC(SEL_COMMAND,FontSelector::ID_ALLFONTS,FontSelector::onCmdAllFonts),
-        };
+FXDEFMAP(FontSelector) FontSelectorMap[]=
+{
+	FXMAPFUNC(SEL_COMMAND,FontSelector::ID_FAMILY,FontSelector::onCmdFamily),
+	FXMAPFUNC(SEL_COMMAND,FontSelector::ID_WEIGHT,FontSelector::onCmdWeight),
+	FXMAPFUNC(SEL_COMMAND,FontSelector::ID_SIZE,FontSelector::onCmdSize),
+	FXMAPFUNC(SEL_COMMAND,FontSelector::ID_SIZE_TEXT,FontSelector::onCmdSizeText),
+	FXMAPFUNC(SEL_COMMAND,FontSelector::ID_STYLE,FontSelector::onCmdStyle),
+	FXMAPFUNC(SEL_COMMAND,FontSelector::ID_STYLE_TEXT,FontSelector::onCmdStyleText),
+	FXMAPFUNC(SEL_COMMAND,FontSelector::ID_CHARSET,FontSelector::onCmdCharset),
+	FXMAPFUNC(SEL_UPDATE,FontSelector::ID_CHARSET,FontSelector::onUpdCharset),
+	FXMAPFUNC(SEL_COMMAND,FontSelector::ID_SETWIDTH,FontSelector::onCmdSetWidth),
+	FXMAPFUNC(SEL_UPDATE,FontSelector::ID_SETWIDTH,FontSelector::onUpdSetWidth),
+	FXMAPFUNC(SEL_COMMAND,FontSelector::ID_PITCH,FontSelector::onCmdPitch),
+	FXMAPFUNC(SEL_UPDATE,FontSelector::ID_PITCH,FontSelector::onUpdPitch),
+	FXMAPFUNC(SEL_UPDATE,FontSelector::ID_SCALABLE,FontSelector::onUpdScalable),
+	FXMAPFUNC(SEL_COMMAND,FontSelector::ID_SCALABLE,FontSelector::onCmdScalable),
+	FXMAPFUNC(SEL_UPDATE,FontSelector::ID_ALLFONTS,FontSelector::onUpdAllFonts),
+	FXMAPFUNC(SEL_COMMAND,FontSelector::ID_ALLFONTS,FontSelector::onCmdAllFonts),
+};
 
 
 // Implementation
