@@ -5,10 +5,10 @@
 
 class XComApp;
 
-class MyComboBox : public FXComboBox
+class ComboBox : public FXComboBox
 {
-    FXDECLARE(MyComboBox)
-    MyComboBox()
+    FXDECLARE(ComboBox)
+    ComboBox()
     {
         ;
     }
@@ -22,7 +22,7 @@ public:
 		field->onCmdCursorEnd(0,0,0);
         field->setFocus();
     }
-    MyComboBox(FXComposite *p,FXint cols,FXObject* tgt=NULL,FXSelector sel=0,FXuint opts=0);
+    ComboBox(FXComposite *p,FXint cols,FXObject* tgt=NULL,FXSelector sel=0,FXuint opts=0);
 };
 
 class HistInputDialog : public DialogBox
@@ -32,7 +32,7 @@ protected:
     FXVerticalFrame* contents;
     FXHorizontalFrame* buttons;
     FXHorizontalFrame* checkbutton;
-    MyComboBox *input;
+    ComboBox *input;
     FXLabel*           label;
     FXDataTarget*      string_target;
 private:
@@ -41,19 +41,32 @@ private:
         ;
     }
 public:
-    HistInputDialog(FXWindow*,FXString& ,FXString,FXString,FXString label="",FXIcon *ic=NULL, int option=0, FXString=FXString::null);
+    enum{
+        ID_BROWSE_PATH=DialogBox::ID_LAST,
+        ID_LAST
+    };
+    HistInputDialog(FXWindow*,FXString,FXString,FXString,FXString label="",FXIcon *ic=NULL, int option=0, FXString=FXString::null);
     virtual void create();
     long onCmdKeyPress(FXObject*,FXSelector,void*);
+	long onCmdBrowsePath(FXObject*,FXSelector,void*);
     FXString getText()
     {
         return input->getText();
     }
+	void setText(const FXString& text)
+	{
+		input->setText(text);
+	}
     void CursorEnd();
     void SelectAll();
     void appendItem(char *str)
     {
         input->appendItem(str);
     };
+    void clearItems()
+    {
+        input->clearItems();
+    };
     FXString getHistoryItem(int pos)
     {
         return input->getItemText(pos);
