@@ -11,9 +11,11 @@
 
 
 
-FXDEFMAP(InputDialog) InputDialogMap[]={
-                                           FXMAPFUNC(SEL_KEYPRESS,0,InputDialog::onCmdKeyPress),
-                                       };
+FXDEFMAP(InputDialog) InputDialogMap[]=
+{
+	FXMAPFUNC(SEL_KEYPRESS,0,InputDialog::onCmdKeyPress),
+};
+
 // Object implementation
 FXIMPLEMENT(InputDialog,DialogBox,InputDialogMap,ARRAYNUMBER(InputDialogMap))
 
