@@ -12,13 +12,14 @@
 
 extern FXMainWindow* mainWindow;
 
-FXDEFMAP(PathLinker) PathLinkerMap[] = {
-                                           FXMAPFUNC(SEL_FOCUSIN, PathLinker::ID_FOCUS_BUTTON, PathLinker::onCmdFocusButton),
-                                           FXMAPFUNCS(SEL_ENTER, PathLinker::ID_START_LINK, PathLinker::ID_END_LINK, PathLinker::pathButtonEnter),
-                                           FXMAPFUNCS(SEL_LEAVE, PathLinker::ID_START_LINK, PathLinker::ID_END_LINK, PathLinker::pathButtonEnter),
-                                           FXMAPFUNCS(SEL_LEFTBUTTONPRESS, PathLinker::ID_START_LINK, PathLinker::ID_END_LINK, PathLinker::pathButtonPressed),
-                                           FXMAPFUNCS(SEL_LEFTBUTTONRELEASE, PathLinker::ID_START_LINK, PathLinker::ID_END_LINK, PathLinker::pathButtonReleased),
-                                       };
+FXDEFMAP(PathLinker) PathLinkerMap[]=
+{
+	FXMAPFUNC(SEL_FOCUSIN, PathLinker::ID_FOCUS_BUTTON, PathLinker::onCmdFocusButton),
+	FXMAPFUNCS(SEL_ENTER, PathLinker::ID_START_LINK, PathLinker::ID_END_LINK, PathLinker::pathButtonEnter),
+	FXMAPFUNCS(SEL_LEAVE, PathLinker::ID_START_LINK, PathLinker::ID_END_LINK, PathLinker::pathButtonEnter),
+	FXMAPFUNCS(SEL_LEFTBUTTONPRESS, PathLinker::ID_START_LINK, PathLinker::ID_END_LINK, PathLinker::pathButtonPressed),
+	FXMAPFUNCS(SEL_LEFTBUTTONRELEASE, PathLinker::ID_START_LINK, PathLinker::ID_END_LINK, PathLinker::pathButtonReleased),
+};
 
 FXIMPLEMENT(PathLinker, FXHorizontalFrame, PathLinkerMap, ARRAYNUMBER(PathLinkerMap))
 
@@ -54,8 +55,7 @@ void PathLinker::setText(FXString text)
     int previousPos = 0;
     int frameWidth = getParent()->getParent()->getWidth();
 
-
-    // Hide all of the link buttons
+	// Hide all of the link buttons
     for(int i = 0; i < MAX_LINKS; i++)
     {
         mPath[i]->hide();
