@@ -15,6 +15,7 @@ public:
         ID_START_LINK = FXHorizontalFrame::ID_LAST,
         // Note: Place any additional id's AFTER ID_END_LINK
         ID_END_LINK = ID_START_LINK + MAX_LINKS - 1,
+		ID_FOCUS_BUTTON,
         ID_SPLITTER,
         ID_LAST
     };
@@ -26,6 +27,7 @@ public:
 	long pathButtonEnter(FXObject* obj, FXSelector sel, void* ptr);
     long pathButtonPressed(FXObject* obj, FXSelector sel, void* ptr);
     long pathButtonReleased(FXObject* obj, FXSelector sel, void* ptr);
+	long onCmdFocusButton(FXObject * obj ,FXSelector sel ,void* ptr);
     void setText(FXString text);
 	void focus();
 	void unfocus();
@@ -35,6 +37,7 @@ protected:
     vector_FXButton mPath;
     int activeButtons;
     FXString mFullPath;
+	FXButton* focusButton;
 
 private:
     void setText(unsigned int index, FXString text);
