@@ -8,6 +8,7 @@
 
 #include "icons.h"
 #include "xfedefs.h"
+#include "File.h"
 #include "FileDialog.h"
 #include "FontDialog.h"
 #include "Preferences.h"
@@ -32,27 +33,32 @@ extern FXbool single_click_fileopen;
 
 
 // Map
-FXDEFMAP(PreferencesBox) PreferencesMap[]={
-                                         FXMAPFUNC(SEL_COMMAND,PreferencesBox::ID_ACCEPT,PreferencesBox::onCmdAccept),
-                                         FXMAPFUNC(SEL_COMMAND,PreferencesBox::ID_BROWSE_TXTEDIT,PreferencesBox::onCmdBrowse),
-                                         FXMAPFUNC(SEL_COMMAND,PreferencesBox::ID_BROWSE_TXTVIEW,PreferencesBox::onCmdBrowse),
-                                         FXMAPFUNC(SEL_COMMAND,PreferencesBox::ID_BROWSE_IMGVIEW,PreferencesBox::onCmdBrowse),
-                                         FXMAPFUNC(SEL_COMMAND,PreferencesBox::ID_BROWSE_XTERM,PreferencesBox::onCmdBrowse),
-                                         FXMAPFUNC(SEL_COMMAND,PreferencesBox::ID_COLOR,PreferencesBox::onCmdColor),
-                                         FXMAPFUNC(SEL_COMMAND,PreferencesBox::ID_NORMALFONT,PreferencesBox::onCmdNormalFont),
-                                         FXMAPFUNC(SEL_COMMAND,PreferencesBox::ID_TEXTFONT,PreferencesBox::onCmdTextFont),
-                                         FXMAPFUNC(SEL_COMMAND,PreferencesBox::ID_THEME,PreferencesBox::onCmdTheme),
-                                         FXMAPFUNC(SEL_COMMAND,PreferencesBox::ID_BROWSE_ICON_PATH,PreferencesBox::onCmdBrowsePath),
-                                         FXMAPFUNC(SEL_UPDATE,PreferencesBox::ID_COLOR,PreferencesBox::onUpdColor),
-									     FXMAPFUNC(SEL_UPDATE,PreferencesBox::ID_TRASH_BYPASS,PreferencesBox::onUpdTrashBypass),
-                                         FXMAPFUNC(SEL_COMMAND,PreferencesBox::ID_SU_CMD,PreferencesBox::onCmdSuMode),
-                                         FXMAPFUNC(SEL_COMMAND,PreferencesBox::ID_SUDO_CMD,PreferencesBox::onCmdSuMode),
-                                         FXMAPFUNC(SEL_UPDATE,PreferencesBox::ID_SU_CMD,PreferencesBox::onUpdSuMode),
-                                         FXMAPFUNC(SEL_UPDATE,PreferencesBox::ID_SUDO_CMD,PreferencesBox::onUpdSuMode),
-                                         FXMAPFUNC(SEL_UPDATE,PreferencesBox::ID_COLOR,PreferencesBox::onUpdColor),
-                                         FXMAPFUNC(SEL_COMMAND,PreferencesBox::ID_WHEELADJUST,PreferencesBox::onCmdWheelAdjust),
-                                         FXMAPFUNC(SEL_UPDATE,PreferencesBox::ID_WHEELADJUST,PreferencesBox::onUpdWheelAdjust),
-                                     };
+FXDEFMAP(PreferencesBox) PreferencesMap[]=
+{
+	FXMAPFUNC(SEL_COMMAND,PreferencesBox::ID_ACCEPT,PreferencesBox::onCmdAccept),
+	FXMAPFUNC(SEL_COMMAND,PreferencesBox::ID_CANCEL,PreferencesBox::onCmdCancel),
+	FXMAPFUNC(SEL_COMMAND,PreferencesBox::ID_BROWSE_TXTEDIT,PreferencesBox::onCmdBrowse),
+	FXMAPFUNC(SEL_COMMAND,PreferencesBox::ID_BROWSE_TXTVIEW,PreferencesBox::onCmdBrowse),
+	FXMAPFUNC(SEL_COMMAND,PreferencesBox::ID_BROWSE_IMGVIEW,PreferencesBox::onCmdBrowse),
+	FXMAPFUNC(SEL_COMMAND,PreferencesBox::ID_BROWSE_XTERM,PreferencesBox::onCmdBrowse),
+	FXMAPFUNC(SEL_COMMAND,PreferencesBox::ID_COLOR,PreferencesBox::onCmdColor),
+	FXMAPFUNC(SEL_COMMAND,PreferencesBox::ID_NORMALFONT,PreferencesBox::onCmdNormalFont),
+	FXMAPFUNC(SEL_COMMAND,PreferencesBox::ID_TEXTFONT,PreferencesBox::onCmdTextFont),
+	FXMAPFUNC(SEL_COMMAND,PreferencesBox::ID_THEME,PreferencesBox::onCmdTheme),
+	FXMAPFUNC(SEL_COMMAND,PreferencesBox::ID_BROWSE_ICON_PATH,PreferencesBox::onCmdBrowsePath),
+	FXMAPFUNC(SEL_UPDATE,PreferencesBox::ID_COLOR,PreferencesBox::onUpdColor),
+	FXMAPFUNC(SEL_UPDATE,PreferencesBox::ID_TRASH_BYPASS,PreferencesBox::onUpdTrashBypass),
+	FXMAPFUNC(SEL_UPDATE,PreferencesBox::ID_CONFIRM_DEL_EMPTYDIR,PreferencesBox::onUpdConfirmDelEmptyDir),
+	FXMAPFUNC(SEL_COMMAND,PreferencesBox::ID_SU_CMD,PreferencesBox::onCmdSuMode),
+	FXMAPFUNC(SEL_COMMAND,PreferencesBox::ID_SUDO_CMD,PreferencesBox::onCmdSuMode),
+	FXMAPFUNC(SEL_UPDATE,PreferencesBox::ID_SU_CMD,PreferencesBox::onUpdSuMode),
+	FXMAPFUNC(SEL_UPDATE,PreferencesBox::ID_SUDO_CMD,PreferencesBox::onUpdSuMode),
+	FXMAPFUNC(SEL_UPDATE,PreferencesBox::ID_COLOR,PreferencesBox::onUpdColor),
+	FXMAPFUNC(SEL_COMMAND,PreferencesBox::ID_WHEELADJUST,PreferencesBox::onCmdWheelAdjust),
+	FXMAPFUNC(SEL_UPDATE,PreferencesBox::ID_WHEELADJUST,PreferencesBox::onUpdWheelAdjust),
+	FXMAPFUNC(SEL_UPDATE,PreferencesBox::ID_SINGLE_CLICK_FILEOPEN,PreferencesBox::onUpdSingleClickFileopen),
+};
+
 // Object implementation
 FXIMPLEMENT(PreferencesBox,DialogBox,PreferencesMap,ARRAYNUMBER(PreferencesMap))
 
@@ -95,7 +101,7 @@ PreferencesBox::PreferencesBox(FXWindow *win, FXColor listbackcolor, FXColor lis
     ok->addHotKey(KEY_Return);
     
     // Cancel
-    new FXButton(buttons,_("&Cancel"),NULL,this,ID_CANCEL,FRAME_RAISED|FRAME_THICK|LAYOUT_RIGHT|LAYOUT_CENTER_Y,0,0,0,0,20,20);
+    new FXButton(buttons,_("&Cancel"),NULL,this,PreferencesBox::ID_CANCEL,FRAME_RAISED|FRAME_THICK|LAYOUT_RIGHT|LAYOUT_CENTER_Y,0,0,0,0,20,20);
     
 	// Switcher
     FXTabBook *tabbook = new FXTabBook(contents,NULL,0,LAYOUT_FILL_X|LAYOUT_FILL_Y|LAYOUT_RIGHT);
@@ -110,7 +116,7 @@ PreferencesBox::PreferencesBox(FXWindow *win, FXColor listbackcolor, FXColor lis
 	trashbypass=new FXCheckButton(group,_("Include a command to bypass the trash can (permanent delete)"),this,ID_TRASH_BYPASS);
     autosave=new FXCheckButton(group,_("Auto save layout"));
     diropen=new FXCheckButton(group,_("Single click directory open"));
-    fileopen=new FXCheckButton(group,_("Single click file open"));
+    fileopen=new FXCheckButton(group,_("Single click file open"),this,ID_SINGLE_CLICK_FILEOPEN);
 
 	group=new FXGroupBox(options,_("Mouse"),GROUPBOX_TITLE_LEFT|FRAME_GROOVE|LAYOUT_FILL_X|LAYOUT_FILL_Y);
     FXMatrix *matrix = new FXMatrix(group,2,MATRIX_BY_COLUMNS|LAYOUT_SIDE_TOP|LAYOUT_FILL_X|LAYOUT_FILL_Y);
@@ -150,8 +156,10 @@ PreferencesBox::PreferencesBox(FXWindow *win, FXColor listbackcolor, FXColor lis
     new FXTabItem(tabbook,_("&Dialogs"),NULL);
     FXVerticalFrame *dialogs=new FXVerticalFrame(tabbook,FRAME_THICK|FRAME_RAISED);
 	group=new FXGroupBox(dialogs,_("Confirmations"),GROUPBOX_TITLE_LEFT|FRAME_GROOVE|LAYOUT_FILL_X|LAYOUT_FILL_Y);
-    ask=new FXCheckButton(group,_("Always ask before file operation"));
+    ask=new FXCheckButton(group,_("Confirm copy/move/rename/symlink"));
+    dnd=new FXCheckButton(group,_("Confirm drag and drop"));
 	del=new FXCheckButton(group,_("Confirm delete"));
+	del_emptydir=new FXCheckButton(group,_("Confirm delete non empty directories"),this,ID_CONFIRM_DEL_EMPTYDIR);
     overwrite=new FXCheckButton(group,_("Confirm overwrite"));
 	quit=new FXCheckButton(group,_("Confirm quit"));
 
@@ -166,10 +174,14 @@ PreferencesBox::PreferencesBox(FXWindow *win, FXColor listbackcolor, FXColor lis
 	quit->setCheck(confirm_quit);
     FXbool confirm_del=getApp()->reg().readUnsignedEntry("OPTIONS","confirm_delete",TRUE);
 	del->setCheck(confirm_del);
+    FXbool confirm_del_emptydir=getApp()->reg().readUnsignedEntry("OPTIONS","confirm_delete_emptydir",TRUE);
+	del_emptydir->setCheck(confirm_del_emptydir);
     FXbool confirm_overwrite=getApp()->reg().readUnsignedEntry("OPTIONS","confirm_overwrite",TRUE);
 	overwrite->setCheck(confirm_overwrite);
     FXbool ask_before_copy=getApp()->reg().readUnsignedEntry("OPTIONS","ask_before_copy",TRUE);
 	ask->setCheck(ask_before_copy);
+    FXbool confirm_dnd=getApp()->reg().readUnsignedEntry("OPTIONS","confirm_drag_and_drop",TRUE);
+	dnd->setCheck(confirm_dnd);
 
 #if defined(linux)
 	FXbool mount_warn=getApp()->reg().readUnsignedEntry("OPTIONS","mount_warn",TRUE);
@@ -232,7 +244,7 @@ PreferencesBox::PreferencesBox(FXWindow *win, FXColor listbackcolor, FXColor lis
 
     FXGroupBox *themes=new FXGroupBox(visual,_("Color theme"),GROUPBOX_TITLE_LEFT|FRAME_GROOVE|LAYOUT_FILL_X|LAYOUT_FILL_Y);
     FXPacker *pack = new FXPacker(themes,FRAME_THICK|FRAME_SUNKEN|LAYOUT_FILL_Y|LAYOUT_FILL_X,0,0,0,0, 0,0,0,0);
-    themesList = new FXList(pack,this,ID_THEME,LIST_SINGLESELECT|FRAME_SUNKEN|FRAME_THICK|LAYOUT_FILL_X|LAYOUT_FILL_Y);
+    themesList = new FXList(pack,this,ID_THEME,LIST_BROWSESELECT|FRAME_SUNKEN|FRAME_THICK|LAYOUT_FILL_X|LAYOUT_FILL_Y);
     themesList->setNumVisible(7);
 	for(int i=0;i<THEMES_NUM;i++)
         themesList->appendItem(Themes[i].name);
@@ -240,7 +252,7 @@ PreferencesBox::PreferencesBox(FXWindow *win, FXColor listbackcolor, FXColor lis
 
     FXGroupBox *colors=new FXGroupBox(visual,_("Custom colors"),GROUPBOX_TITLE_LEFT|FRAME_GROOVE|LAYOUT_FILL_X);
     FXHorizontalFrame *col=new FXHorizontalFrame(colors,LAYOUT_FILL_X);
-    colorsBox = new FXComboBox(col,COLORS_NUM,NULL,0,COMBOBOX_NO_REPLACE|FRAME_SUNKEN|FRAME_THICK|LAYOUT_FILL_X|LAYOUT_SIDE_RIGHT);
+    colorsBox = new FXComboBox(col,COLORS_NUM,NULL,0,COMBOBOX_STATIC|FRAME_SUNKEN|FRAME_THICK|LAYOUT_FILL_X|LAYOUT_SIDE_RIGHT);
   	colorsBox->setNumVisible(COLORS_NUM);
     pack = new FXPacker(col,LAYOUT_SIDE_LEFT|FRAME_SUNKEN|LAYOUT_FILL_Y);
     cwell = new FXButton(pack,"",NULL,this,ID_COLOR,LAYOUT_FIX_WIDTH|LAYOUT_FILL_Y,0,0, 30);
@@ -316,15 +328,18 @@ long PreferencesBox::onCmdTheme(FXObject* o,FXSelector s,void* p)
 
 long PreferencesBox::onCmdBrowsePath(FXObject* o,FXSelector s,void* p)
 {
-	FileDialog browse(this,_("Select an icon theme directory"),0,0,0,650,480);
+	FileDialog browse(this,_("Select an icon theme directory or an icon file"),0,0,0,650,480);
 
-	browse.setSelectMode(SELECT_FILE_DIRECTORY);
+	browse.setSelectMode(SELECT_FILE_MIXED);
 	browse.setFilename(iconpath->getText());
 
 	if(browse.execute())
 	{
 		FXString path=browse.getFilename();
-		iconpath->setText(path);
+		if (::isFile(path))
+			iconpath->setText(FXPath::directory(path).text());
+		else
+			iconpath->setText(path);
 	}
 	return 1;
 }
@@ -332,13 +347,14 @@ long PreferencesBox::onCmdBrowsePath(FXObject* o,FXSelector s,void* p)
 
 long PreferencesBox::onCmdBrowse(FXObject* o,FXSelector s,void* p)
 {
-    FileDialog browse(this,_("Select Program"),0,0,0,650,480);
+    FileDialog browse(this,_("Select an executable file"),0,0,0,650,480);
     const FXchar *patterns[]=
         {
             _("All files"),     "*",NULL
         };
 	browse.setFilename(ROOTDIR);
 	browse.setPatternList(patterns);
+	browse.setSelectMode(SELECT_FILE_ANY);
     if(browse.execute())
     {
         char *path=strdup(browse.getFilename().text());
@@ -651,8 +667,10 @@ long PreferencesBox::onCmdAccept(FXObject* o,FXSelector s,void* p)
     getApp()->reg().writeUnsignedEntry("OPTIONS","single_click_diropen",diropen->getCheck());
     getApp()->reg().writeUnsignedEntry("OPTIONS","single_click_fileopen",fileopen->getCheck());
     getApp()->reg().writeUnsignedEntry("OPTIONS","confirm_delete",del->getCheck());
+    getApp()->reg().writeUnsignedEntry("OPTIONS","confirm_delete_emptydir",del_emptydir->getCheck());
     getApp()->reg().writeUnsignedEntry("OPTIONS","confirm_overwrite",overwrite->getCheck());
 	getApp()->reg().writeUnsignedEntry("OPTIONS","confirm_quit",quit->getCheck());
+    getApp()->reg().writeUnsignedEntry("OPTIONS","confirm_drag_and_drop",dnd->getCheck());
     getApp()->reg().writeUnsignedEntry("OPTIONS","root_warn",root_warning->getCheck());
 #if defined(linux)
     getApp()->reg().writeUnsignedEntry("OPTIONS","mount_warn",mount->getCheck());
@@ -708,6 +726,109 @@ long PreferencesBox::onCmdAccept(FXObject* o,FXSelector s,void* p)
 }
 
 
+long PreferencesBox::onCmdCancel(FXObject* o,FXSelector s,void* p)
+{
+	// Reset preferences to their previous values
+	
+	// First tab - Options
+	trashcan->setCheck(trashcan_prev);
+	trashbypass->setCheck(trashbypass_prev);
+	autosave->setCheck(autosave_prev);
+	diropen->setCheck(diropen_prev);
+	fileopen->setCheck(fileopen_prev);
+	getApp()->setWheelLines(value_prev);	
+	use_sudo=use_sudo_prev;
+	getApp()->reg().writeUnsignedEntry("OPTIONS","use_sudo",use_sudo);
+	
+	// Second tab - Dialogs
+	ask->setCheck(ask_prev);
+	dnd->setCheck(dnd_prev);
+	del->setCheck(del_prev);
+	del_emptydir->setCheck(del_emptydir_prev);
+	overwrite->setCheck(overwrite_prev);
+	quit->setCheck(quit_prev);
+#if defined(linux)
+	mount->setCheck(mount_prev);
+	show_mount->setCheck(show_mount_prev);
+#endif
+	root_warning->setCheck(root_warning_prev);
+	
+	// Third tab - Programs
+	txteditor->setText(oldtxteditor);	
+	txtviewer->setText(oldtxtviewer);	
+	imgeditor->setText(oldimgeditor);	
+	imgviewer->setText(oldimgviewer);	
+	archiver->setText(oldarchiver);	
+	xterm->setText(oldxterm);
+
+	// Fourth tab - Visual
+    themesList->setCurrentItem(themelist_prev);
+	currTheme=currTheme_prev;
+    iconpath->setText(oldiconpath);
+
+	// Fifth tab - Fonts
+	normalfont->setText(oldnormalfont);
+	textfont->setText(oldtextfont);
+
+	// Finally, update the registry (really necessary?)
+	getApp()->reg().write();
+	
+    DialogBox::onCmdCancel(o,s,p);
+    return 1;
+}
+
+
+// Execute dialog box modally
+FXuint PreferencesBox::execute(FXuint placement)
+{
+	// Save current preferences to restore them if cancel is pressed
+	
+	// First tab - Options
+	trashcan_prev=trashcan->getCheck();
+	trashbypass_prev=trashbypass->getCheck();
+	autosave_prev=autosave->getCheck();
+	diropen_prev=diropen->getCheck();
+	fileopen_prev=fileopen->getCheck();
+	value_prev=getApp()->getWheelLines();
+	use_sudo_prev=use_sudo;
+	
+	// Second tab - Dialogs
+	ask_prev=ask->getCheck();
+	dnd_prev=dnd->getCheck();
+	del_prev=del->getCheck();
+	del_emptydir_prev=del_emptydir->getCheck();
+	overwrite_prev=overwrite->getCheck();
+	quit_prev=quit->getCheck();
+#if defined(linux)
+	mount_prev=mount->getCheck();
+	show_mount_prev=show_mount_prev;
+#endif
+	root_warning_prev=root_warning->getCheck();
+
+    // Third tab - Programs
+	oldtxteditor=txteditor->getText();
+	oldtxtviewer=txtviewer->getText();
+	oldimgeditor=imgeditor->getText();
+	oldimgviewer=imgviewer->getText();
+	oldarchiver=archiver->getText();
+	oldxterm=xterm->getText();
+	
+	// Fourth tab - Visual
+	themelist_prev=themesList->getCurrentItem();
+    currTheme_prev = currTheme;
+    oldiconpath=iconpath->getText();
+	
+	// Fifth tab - Fonts
+	oldnormalfont=normalfont->getText();
+	oldtextfont=textfont->getText();
+
+	create();
+    show(placement);
+	getApp()->refresh();
+    return getApp()->runModalFor(this);
+}
+
+
 // Update the bypass trash can option item
 long PreferencesBox::onUpdTrashBypass(FXObject* o,FXSelector,void*)
 {
@@ -719,6 +840,17 @@ long PreferencesBox::onUpdTrashBypass(FXObject* o,FXSelector,void*)
 }
 
 
+// Update the confirm delete empty directories option item
+long PreferencesBox::onUpdConfirmDelEmptyDir(FXObject* o,FXSelector,void*)
+{
+	if (del->getCheck())	
+		o->handle(this,FXSEL(SEL_COMMAND,FXWindow::ID_ENABLE),NULL);
+	else
+		o->handle(this,FXSEL(SEL_COMMAND,FXWindow::ID_DISABLE),NULL);
+    return 1;
+}
+
+
 // Set root mode
 long PreferencesBox::onCmdSuMode(FXObject*,FXSelector sel,void*)
 {
@@ -770,10 +902,23 @@ long PreferencesBox::onCmdWheelAdjust(FXObject* sender,FXSelector,void*)
 }
 
 
-// Update wheel lines
+// Update the wheel lines button
 long PreferencesBox::onUpdWheelAdjust(FXObject* sender,FXSelector,void*)
 {
     FXuint value=getApp()->getWheelLines();
 	sender->handle(this,FXSEL(SEL_COMMAND,ID_SETINTVALUE),(void*)&value);
     return 1;
 }
+
+
+// Update single click file open button
+long PreferencesBox::onUpdSingleClickFileopen(FXObject* o,FXSelector,void*)
+{
+	if (diropen->getCheck())	
+		o->handle(this,FXSEL(SEL_COMMAND,FXWindow::ID_ENABLE),NULL);
+	else
+		o->handle(this,FXSEL(SEL_COMMAND,FXWindow::ID_DISABLE),NULL);
+    return 1;
+}
+
+
