@@ -73,7 +73,9 @@ private:
     FXCheckButton  *quit;
     FXCheckButton  *trashcan;
     FXCheckButton  *trashbypass;
+    FXCheckButton  *dnd;
     FXCheckButton  *del;
+    FXCheckButton  *del_emptydir;
     FXCheckButton  *overwrite;
     FXCheckButton  *ask;
     FXCheckButton  *bg;
@@ -82,10 +84,31 @@ private:
 	FXCheckButton  *show_mount;
     Theme          Themes[THEMES_NUM];
     Theme          currTheme;
+    Theme          currTheme_prev;
 	FXbool		   use_sudo;
+	FXbool		   use_sudo_prev;
+	FXbool		   trashcan_prev;
+	FXbool		   trashbypass_prev;
+	FXbool		   autosave_prev;
+	FXbool         diropen_prev;
+	FXbool         fileopen_prev;
+	FXuint	       value_prev;
+	FXbool		   ask_prev;
+	FXbool		   dnd_prev;
+	FXbool		   del_prev;
+	FXbool		   del_emptydir_prev;
+	FXbool		   overwrite_prev;
+	FXbool		   quit_prev;
+#if defined(linux)
+	FXbool		   mount_prev;
+	FXbool		   show_mount_prev;
+#endif
+	FXbool		   root_warning_prev;
+	FXuint		   themelist_prev;
 public:
     enum{
         ID_ACCEPT=DialogBox::ID_LAST,
+		ID_CANCEL,
         ID_BROWSE_TXTEDIT,
         ID_BROWSE_TXTVIEW,
 		ID_BROWSE_IMGVIEW,
@@ -96,9 +119,11 @@ public:
         ID_THEME,
         ID_BROWSE_ICON_PATH,
 		ID_TRASH_BYPASS,
+		ID_CONFIRM_DEL_EMPTYDIR,
 		ID_SU_CMD,
 		ID_SUDO_CMD,
 		ID_WHEELADJUST,
+		ID_SINGLE_CLICK_FILEOPEN,
         ID_LAST
     };
 
@@ -113,10 +138,14 @@ public:
 	long onCmdNormalFont(FXObject*,FXSelector,void*);
 	long onCmdTextFont(FXObject*,FXSelector,void*);
 	long onUpdTrashBypass(FXObject*,FXSelector,void*);
+	long onUpdConfirmDelEmptyDir(FXObject*,FXSelector,void*);
 	long onCmdSuMode(FXObject*,FXSelector,void*);
 	long onUpdSuMode(FXObject*,FXSelector,void*);
 	long onCmdWheelAdjust(FXObject*,FXSelector,void*);
-	long onUpdWheelAdjust(FXObject* sender,FXSelector,void*);
+	long onUpdWheelAdjust(FXObject*,FXSelector,void*);
+	long onUpdSingleClickFileopen(FXObject*,FXSelector,void*);
+	FXuint execute(FXuint);
+	long onCmdCancel(FXObject*,FXSelector,void*);
 
 };
 #endif
