@@ -106,33 +106,34 @@ PermFrame::PermFrame(FXComposite* parent,FXObject *target):
 }
 
 // Map
-FXDEFMAP(PropertiesBox) PropertiesBoxMap[]={
-            FXMAPFUNC(SEL_COMMAND,PropertiesBox::ID_ACCEPT_SINGLE,PropertiesBox::onCmdAcceptSingle),
-            FXMAPFUNC(SEL_COMMAND,PropertiesBox::ID_ACCEPT_MULT,PropertiesBox::onCmdAcceptMult),
-            FXMAPFUNC(SEL_COMMAND,PropertiesBox::ID_CANCEL,PropertiesBox::onCmdCancel),
-            FXMAPFUNC(SEL_COMMAND,PropertiesBox::ID_RUSR,PropertiesBox::onCmdCheck),
-            FXMAPFUNC(SEL_COMMAND,PropertiesBox::ID_WUSR,PropertiesBox::onCmdCheck),
-            FXMAPFUNC(SEL_COMMAND,PropertiesBox::ID_XUSR,PropertiesBox::onCmdCheck),
-            FXMAPFUNC(SEL_COMMAND,PropertiesBox::ID_RGRP,PropertiesBox::onCmdCheck),
-            FXMAPFUNC(SEL_COMMAND,PropertiesBox::ID_WGRP,PropertiesBox::onCmdCheck),
-            FXMAPFUNC(SEL_COMMAND,PropertiesBox::ID_XGRP,PropertiesBox::onCmdCheck),
-            FXMAPFUNC(SEL_COMMAND,PropertiesBox::ID_ROTH,PropertiesBox::onCmdCheck),
-            FXMAPFUNC(SEL_COMMAND,PropertiesBox::ID_WOTH,PropertiesBox::onCmdCheck),
-            FXMAPFUNC(SEL_COMMAND,PropertiesBox::ID_XOTH,PropertiesBox::onCmdCheck),
-  			FXMAPFUNC(SEL_UPDATE,0,PropertiesBox::onUpdPerm),
-            FXMAPFUNC(SEL_COMMAND,PropertiesBox::ID_SET,PropertiesBox::onCmdCommand),
-            FXMAPFUNC(SEL_COMMAND,PropertiesBox::ID_CLEAR,PropertiesBox::onCmdCommand),
-            FXMAPFUNC(SEL_COMMAND,PropertiesBox::ID_ADD,PropertiesBox::onCmdCommand),
-            FXMAPFUNC(SEL_COMMAND,PropertiesBox::ID_DIRONLY,PropertiesBox::onCmdFilter),
-            FXMAPFUNC(SEL_COMMAND,PropertiesBox::ID_FILEONLY,PropertiesBox::onCmdFilter),
-            FXMAPFUNC(SEL_COMMAND,PropertiesBox::ID_ALL,PropertiesBox::onCmdFilter),
-            FXMAPFUNC(SEL_COMMAND,PropertiesBox::ID_BIG_ICON,PropertiesBox::onCmdBrowseIcon),
-            FXMAPFUNC(SEL_COMMAND,PropertiesBox::ID_MINI_ICON,PropertiesBox::onCmdBrowseIcon),
-            FXMAPFUNC(SEL_COMMAND,PropertiesBox::ID_BROWSE_OPEN,PropertiesBox::onCmdBrowse),
-            FXMAPFUNC(SEL_COMMAND,PropertiesBox::ID_BROWSE_VIEW,PropertiesBox::onCmdBrowse),
-            FXMAPFUNC(SEL_COMMAND,PropertiesBox::ID_BROWSE_EDIT,PropertiesBox::onCmdBrowse),
-			FXMAPFUNC(SEL_KEYPRESS,0,PropertiesBox::onCmdKeyPress),
-        };
+FXDEFMAP(PropertiesBox) PropertiesBoxMap[]=
+{
+	FXMAPFUNC(SEL_COMMAND,PropertiesBox::ID_ACCEPT_SINGLE,PropertiesBox::onCmdAcceptSingle),
+	FXMAPFUNC(SEL_COMMAND,PropertiesBox::ID_ACCEPT_MULT,PropertiesBox::onCmdAcceptMult),
+	FXMAPFUNC(SEL_COMMAND,PropertiesBox::ID_CANCEL,PropertiesBox::onCmdCancel),
+	FXMAPFUNC(SEL_COMMAND,PropertiesBox::ID_RUSR,PropertiesBox::onCmdCheck),
+	FXMAPFUNC(SEL_COMMAND,PropertiesBox::ID_WUSR,PropertiesBox::onCmdCheck),
+	FXMAPFUNC(SEL_COMMAND,PropertiesBox::ID_XUSR,PropertiesBox::onCmdCheck),
+	FXMAPFUNC(SEL_COMMAND,PropertiesBox::ID_RGRP,PropertiesBox::onCmdCheck),
+	FXMAPFUNC(SEL_COMMAND,PropertiesBox::ID_WGRP,PropertiesBox::onCmdCheck),
+	FXMAPFUNC(SEL_COMMAND,PropertiesBox::ID_XGRP,PropertiesBox::onCmdCheck),
+	FXMAPFUNC(SEL_COMMAND,PropertiesBox::ID_ROTH,PropertiesBox::onCmdCheck),
+	FXMAPFUNC(SEL_COMMAND,PropertiesBox::ID_WOTH,PropertiesBox::onCmdCheck),
+	FXMAPFUNC(SEL_COMMAND,PropertiesBox::ID_XOTH,PropertiesBox::onCmdCheck),
+	FXMAPFUNC(SEL_UPDATE,0,PropertiesBox::onUpdPerm),
+	FXMAPFUNC(SEL_COMMAND,PropertiesBox::ID_SET,PropertiesBox::onCmdCommand),
+	FXMAPFUNC(SEL_COMMAND,PropertiesBox::ID_CLEAR,PropertiesBox::onCmdCommand),
+	FXMAPFUNC(SEL_COMMAND,PropertiesBox::ID_ADD,PropertiesBox::onCmdCommand),
+	FXMAPFUNC(SEL_COMMAND,PropertiesBox::ID_DIRONLY,PropertiesBox::onCmdFilter),
+	FXMAPFUNC(SEL_COMMAND,PropertiesBox::ID_FILEONLY,PropertiesBox::onCmdFilter),
+	FXMAPFUNC(SEL_COMMAND,PropertiesBox::ID_ALL,PropertiesBox::onCmdFilter),
+	FXMAPFUNC(SEL_COMMAND,PropertiesBox::ID_BIG_ICON,PropertiesBox::onCmdBrowseIcon),
+	FXMAPFUNC(SEL_COMMAND,PropertiesBox::ID_MINI_ICON,PropertiesBox::onCmdBrowseIcon),
+	FXMAPFUNC(SEL_COMMAND,PropertiesBox::ID_BROWSE_OPEN,PropertiesBox::onCmdBrowse),
+	FXMAPFUNC(SEL_COMMAND,PropertiesBox::ID_BROWSE_VIEW,PropertiesBox::onCmdBrowse),
+	FXMAPFUNC(SEL_COMMAND,PropertiesBox::ID_BROWSE_EDIT,PropertiesBox::onCmdBrowse),
+	FXMAPFUNC(SEL_KEYPRESS,0,PropertiesBox::onCmdKeyPress),
+};
 
 // Object implementation
 FXIMPLEMENT(PropertiesBox,DialogBox,PropertiesBoxMap,ARRAYNUMBER(PropertiesBoxMap))
@@ -1135,14 +1136,15 @@ long PropertiesBox::onCmdCheck(FXObject* o,FXSelector s,void* p)
 
 long PropertiesBox::onCmdBrowse(FXObject* o,FXSelector s,void* p)
 {
-    FileDialog browseProgram(this,_("Select Program"),0,0,0,650,480);
+    FileDialog browseProgram(this,_("Select an executable file"),0,0,0,650,480);
     const FXchar *patterns[]=
         {
             _("All files"),     "*",NULL
         };
 	browseProgram.setFilename(ROOTDIR);
 	browseProgram.setPatternList(patterns);
-    if(browseProgram.execute())
+	browseProgram.setSelectMode(SELECT_FILE_ANY);
+	if(browseProgram.execute())
     {
         char *path=strdup(browseProgram.getFilename().text());
         switch(FXSELID(s))
@@ -1178,7 +1180,7 @@ long PropertiesBox::onCmdBrowseIcon(FXObject* o,FXSelector s,void* p)
 			_("GIF Images"),     "*.gif",
             _("BMP Images"),     "*.bmp",NULL
         };
-    FileDialog browseIcon(this,_("Select Icon"),0,0,0,650,480);
+    FileDialog browseIcon(this,_("Select an icon file"),0,0,0,650,480);
     browseIcon.setFilename(iconpath+PATHSEPSTRING+icon);
     browseIcon.setPatternList(patterns);
     if(browseIcon.execute())
