@@ -1,6 +1,4 @@
 #include "config.h"
-#include "config.h"
-#include "config.h"
 #include "i18n.h"
 
 #include <stdio.h>
@@ -47,7 +45,6 @@ FXString clipboard="";
 
 char OpenHistory[OPEN_WITH_HIST_SIZE][100];
 int OpenNum;
-FXColor highlightcolor;
 FXbool allowPopupScroll=FALSE;
 FXbool single_click_diropen=FALSE;
 FXbool single_click_fileopen=FALSE;
@@ -81,66 +78,68 @@ void toolbarSeparator(FXToolBar* tb)
 
 
 // Map
-FXDEFMAP(XFileExplorer) XFileExplorerMap[]={
-                                     FXMAPFUNC(SEL_COMMAND,XFileExplorer::ID_TOGGLE_STATUS,XFileExplorer::onCmdToggleStatus),
-                                     FXMAPFUNC(SEL_COMMAND,XFileExplorer::ID_RUN,XFileExplorer::onCmdRun),
-                                     FXMAPFUNC(SEL_COMMAND,XFileExplorer::ID_SU,XFileExplorer::onCmdSu),
-                                     FXMAPFUNC(SEL_COMMAND,XFileExplorer::ID_FILE_COPY,XFileExplorer::onCmdFileCopyClp),
-                                     FXMAPFUNC(SEL_COMMAND,XFileExplorer::ID_FILE_CUT,XFileExplorer::onCmdFileCutClp),
-                                     FXMAPFUNC(SEL_COMMAND,XFileExplorer::ID_FILE_PASTE,XFileExplorer::onCmdFilePasteClp),
-                                     FXMAPFUNC(SEL_COMMAND,XFileExplorer::ID_FILE_RENAME,XFileExplorer::onCmdFileRename),
-                                     FXMAPFUNC(SEL_COMMAND,XFileExplorer::ID_FILE_COPYTO,XFileExplorer::onCmdFileCopyto),
-                                     FXMAPFUNC(SEL_COMMAND,XFileExplorer::ID_FILE_MOVE,XFileExplorer::onCmdFileMove),
-                                     FXMAPFUNC(SEL_COMMAND,XFileExplorer::ID_FILE_SYMLINK,XFileExplorer::onCmdFileSymlink),
-                                     FXMAPFUNC(SEL_COMMAND,XFileExplorer::ID_FILE_PROPERTIES,XFileExplorer::onCmdFileProperties),
-                                     FXMAPFUNC(SEL_COMMAND,XFileExplorer::ID_FILE_DELETE,XFileExplorer::onCmdFileDelete),
-                                     FXMAPFUNC(SEL_COMMAND,XFileExplorer::ID_FILE_TRASH,XFileExplorer::onCmdFileTrash),
-                                     FXMAPFUNC(SEL_COMMAND,XFileExplorer::ID_QUIT,XFileExplorer::onQuit),
-                                     FXMAPFUNC(SEL_COMMAND,XFileExplorer::ID_HELP,XFileExplorer::onCmdHelp),
-                                     FXMAPFUNC(SEL_COMMAND,XFileExplorer::ID_ABOUT,XFileExplorer::onCmdAbout),
-                                     FXMAPFUNC(SEL_COMMAND,XFileExplorer::ID_FILE_ASSOC,XFileExplorer::onCmdFileAssoc),
-                                     FXMAPFUNC(SEL_COMMAND,XFileExplorer::ID_REFRESH,XFileExplorer::onCmdRefresh),
-                                     FXMAPFUNC(SEL_COMMAND,XFileExplorer::ID_EMPTY_TRASHCAN,XFileExplorer::onCmdEmptyTrashcan),
-                                     FXMAPFUNC(SEL_COMMAND,XFileExplorer::ID_XTERM,XFileExplorer::onCmdXTerm),
-									 FXMAPFUNC(SEL_COMMAND,XFileExplorer::ID_CLEAR_LOCATION,XFileExplorer::onCmdClearLocation),
-									 FXMAPFUNC(SEL_COMMAND,XFileExplorer::ID_GOTO_LOCATION,XFileExplorer::onCmdGotoLocation),
-                                     FXMAPFUNC(SEL_COMMAND,XFileExplorer::ID_PREFS,XFileExplorer::onCmdPrefs),
-                                     FXMAPFUNC(SEL_COMMAND,XFileExplorer::ID_SHOW_ONE_PANEL,XFileExplorer::onCmdShowPanels),
-                                     FXMAPFUNC(SEL_COMMAND,XFileExplorer::ID_SHOW_TWO_PANELS,XFileExplorer::onCmdShowPanels),
-                                     FXMAPFUNC(SEL_COMMAND,XFileExplorer::ID_SHOW_TREE_PANEL,XFileExplorer::onCmdShowPanels),
-                                     FXMAPFUNC(SEL_COMMAND,XFileExplorer::ID_SHOW_TREE_TWO_PANELS,XFileExplorer::onCmdShowPanels),
-			                         FXMAPFUNC(SEL_COMMAND,XFileExplorer::ID_RESTART,XFileExplorer::onCmdRestart),
-                                     FXMAPFUNC(SEL_COMMAND,XFileExplorer::ID_NEW_WIN,XFileExplorer::onCmdNewWindow),
-                                     FXMAPFUNC(SEL_COMMAND,XFileExplorer::ID_BOOKMARK,XFileExplorer::onCmdBookmark),
-                                     FXMAPFUNC(SEL_COMMAND,XFileExplorer::ID_ADD_BOOKMARK,XFileExplorer::onCmdBookmark),
-                                     FXMAPFUNC(SEL_COMMAND,XFileExplorer::ID_DIR_BACK,XFileExplorer::onCmdDirBack),
-									 FXMAPFUNC(SEL_UPDATE,XFileExplorer::ID_DIR_BACK,XFileExplorer::onUpdDirBack),
-                                     FXMAPFUNC(SEL_COMMAND,XFileExplorer::ID_DIR_FORWARD,XFileExplorer::onCmdDirForward),
-									 FXMAPFUNC(SEL_UPDATE,XFileExplorer::ID_DIR_FORWARD,XFileExplorer::onUpdDirForward),
-                                     FXMAPFUNC(SEL_COMMAND,XFileExplorer::ID_DIR_BACK_HIST,XFileExplorer::onCmdDirBackHist),
-									 FXMAPFUNC(SEL_UPDATE,XFileExplorer::ID_DIR_BACK_HIST,XFileExplorer::onUpdDirBackHist),
-                                     FXMAPFUNC(SEL_COMMAND,XFileExplorer::ID_DIR_FORWARD_HIST,XFileExplorer::onCmdDirForwardHist),
-									 FXMAPFUNC(SEL_UPDATE,XFileExplorer::ID_DIR_FORWARD_HIST,XFileExplorer::onUpdDirForwardHist),
-           						     FXMAPFUNC(SEL_KEYPRESS,0,XFileExplorer::onKeyPress),
-                                     FXMAPFUNC(SEL_CLOSE,0,XFileExplorer::onQuit),
-                                     FXMAPFUNC(SEL_UPDATE,XFileExplorer::ID_TOGGLE_STATUS,XFileExplorer::onUpdToggleStatus),
-                                     FXMAPFUNC(SEL_UPDATE,XFileExplorer::ID_SHOW_ONE_PANEL,XFileExplorer::onUpdShowPanels),
-                                     FXMAPFUNC(SEL_UPDATE,XFileExplorer::ID_SHOW_TWO_PANELS,XFileExplorer::onUpdShowPanels),
-                                     FXMAPFUNC(SEL_UPDATE,XFileExplorer::ID_SHOW_TREE_PANEL,XFileExplorer::onUpdShowPanels),
-                                     FXMAPFUNC(SEL_UPDATE,XFileExplorer::ID_SHOW_TREE_TWO_PANELS,XFileExplorer::onUpdShowPanels),
-									 FXMAPFUNC(SEL_UPDATE,XFileExplorer::ID_GOTO_LOCATION,XFileExplorer::onUpdFileLocation),
-									 FXMAPFUNC(SEL_UPDATE,XFileExplorer::ID_EMPTY_TRASHCAN,XFileExplorer::onUpdEmptyTrashcan),
-									 FXMAPFUNC(SEL_UPDATE,XFileExplorer::ID_FILE_DELETE,XFileExplorer::onUpdFileDelete),
-									 FXMAPFUNC(SEL_UPDATE,XFileExplorer::ID_FILE_TRASH,XFileExplorer::onUpdFileTrash),
-                                     FXMAPFUNC(SEL_UPDATE,XFileExplorer::ID_FILE_RENAME,XFileExplorer::onUpdFileRename),
-                                     FXMAPFUNC(SEL_UPDATE,XFileExplorer::ID_FILE_PROPERTIES,XFileExplorer::onUpdFileMan),
-                                     FXMAPFUNC(SEL_UPDATE,XFileExplorer::ID_FILE_COPYTO,XFileExplorer::onUpdFileMan),
-                                     FXMAPFUNC(SEL_UPDATE,XFileExplorer::ID_FILE_MOVE,XFileExplorer::onUpdFileMan),
-                                     FXMAPFUNC(SEL_UPDATE,XFileExplorer::ID_FILE_SYMLINK,XFileExplorer::onUpdFileMan),
-                                     FXMAPFUNC(SEL_UPDATE,XFileExplorer::ID_FILE_COPY,XFileExplorer::onUpdFileMan),
-                                     FXMAPFUNC(SEL_UPDATE,XFileExplorer::ID_FILE_CUT,XFileExplorer::onUpdFileMan),
-                                     FXMAPFUNC(SEL_UPDATE,XFileExplorer::ID_FILE_PASTE,XFileExplorer::onUpdFilePaste),
-                                 };
+FXDEFMAP(XFileExplorer) XFileExplorerMap[]=
+{
+	FXMAPFUNC(SEL_COMMAND,XFileExplorer::ID_TOGGLE_STATUS,XFileExplorer::onCmdToggleStatus),
+	FXMAPFUNC(SEL_COMMAND,XFileExplorer::ID_RUN,XFileExplorer::onCmdRun),
+	FXMAPFUNC(SEL_COMMAND,XFileExplorer::ID_SU,XFileExplorer::onCmdSu),
+	FXMAPFUNC(SEL_COMMAND,XFileExplorer::ID_FILE_COPY,XFileExplorer::onCmdFileCopyClp),
+	FXMAPFUNC(SEL_COMMAND,XFileExplorer::ID_FILE_CUT,XFileExplorer::onCmdFileCutClp),
+	FXMAPFUNC(SEL_COMMAND,XFileExplorer::ID_FILE_PASTE,XFileExplorer::onCmdFilePasteClp),
+	FXMAPFUNC(SEL_COMMAND,XFileExplorer::ID_FILE_RENAME,XFileExplorer::onCmdFileRename),
+	FXMAPFUNC(SEL_COMMAND,XFileExplorer::ID_FILE_COPYTO,XFileExplorer::onCmdFileCopyto),
+	FXMAPFUNC(SEL_COMMAND,XFileExplorer::ID_FILE_MOVE,XFileExplorer::onCmdFileMove),
+	FXMAPFUNC(SEL_COMMAND,XFileExplorer::ID_FILE_SYMLINK,XFileExplorer::onCmdFileSymlink),
+	FXMAPFUNC(SEL_COMMAND,XFileExplorer::ID_FILE_PROPERTIES,XFileExplorer::onCmdFileProperties),
+	FXMAPFUNC(SEL_COMMAND,XFileExplorer::ID_FILE_DELETE,XFileExplorer::onCmdFileDelete),
+	FXMAPFUNC(SEL_COMMAND,XFileExplorer::ID_FILE_TRASH,XFileExplorer::onCmdFileTrash),
+	FXMAPFUNC(SEL_COMMAND,XFileExplorer::ID_QUIT,XFileExplorer::onQuit),
+	FXMAPFUNC(SEL_COMMAND,XFileExplorer::ID_HELP,XFileExplorer::onCmdHelp),
+	FXMAPFUNC(SEL_COMMAND,XFileExplorer::ID_ABOUT,XFileExplorer::onCmdAbout),
+	FXMAPFUNC(SEL_COMMAND,XFileExplorer::ID_FILE_ASSOC,XFileExplorer::onCmdFileAssoc),
+	FXMAPFUNC(SEL_COMMAND,XFileExplorer::ID_REFRESH,XFileExplorer::onCmdRefresh),
+	FXMAPFUNC(SEL_COMMAND,XFileExplorer::ID_EMPTY_TRASHCAN,XFileExplorer::onCmdEmptyTrashcan),
+	FXMAPFUNC(SEL_COMMAND,XFileExplorer::ID_XTERM,XFileExplorer::onCmdXTerm),
+	FXMAPFUNC(SEL_COMMAND,XFileExplorer::ID_CLEAR_LOCATION,XFileExplorer::onCmdClearLocation),
+	FXMAPFUNC(SEL_COMMAND,XFileExplorer::ID_GOTO_LOCATION,XFileExplorer::onCmdGotoLocation),
+	FXMAPFUNC(SEL_COMMAND,XFileExplorer::ID_PREFS,XFileExplorer::onCmdPrefs),
+	FXMAPFUNC(SEL_COMMAND,XFileExplorer::ID_SHOW_ONE_PANEL,XFileExplorer::onCmdShowPanels),
+	FXMAPFUNC(SEL_COMMAND,XFileExplorer::ID_SHOW_TWO_PANELS,XFileExplorer::onCmdShowPanels),
+	FXMAPFUNC(SEL_COMMAND,XFileExplorer::ID_SHOW_TREE_PANEL,XFileExplorer::onCmdShowPanels),
+	FXMAPFUNC(SEL_COMMAND,XFileExplorer::ID_SHOW_TREE_TWO_PANELS,XFileExplorer::onCmdShowPanels),
+	FXMAPFUNC(SEL_COMMAND,XFileExplorer::ID_RESTART,XFileExplorer::onCmdRestart),
+	FXMAPFUNC(SEL_COMMAND,XFileExplorer::ID_NEW_WIN,XFileExplorer::onCmdNewWindow),
+	FXMAPFUNC(SEL_COMMAND,XFileExplorer::ID_BOOKMARK,XFileExplorer::onCmdBookmark),
+	FXMAPFUNC(SEL_COMMAND,XFileExplorer::ID_DIR_UP,XFileExplorer::onCmdDirUp),
+	FXMAPFUNC(SEL_COMMAND,XFileExplorer::ID_ADD_BOOKMARK,XFileExplorer::onCmdBookmark),
+	FXMAPFUNC(SEL_COMMAND,XFileExplorer::ID_DIR_BACK,XFileExplorer::onCmdDirBack),
+	FXMAPFUNC(SEL_UPDATE,XFileExplorer::ID_DIR_BACK,XFileExplorer::onUpdDirBack),
+	FXMAPFUNC(SEL_COMMAND,XFileExplorer::ID_DIR_FORWARD,XFileExplorer::onCmdDirForward),
+	FXMAPFUNC(SEL_UPDATE,XFileExplorer::ID_DIR_FORWARD,XFileExplorer::onUpdDirForward),
+	FXMAPFUNC(SEL_COMMAND,XFileExplorer::ID_DIR_BACK_HIST,XFileExplorer::onCmdDirBackHist),
+	FXMAPFUNC(SEL_UPDATE,XFileExplorer::ID_DIR_BACK_HIST,XFileExplorer::onUpdDirBackHist),
+	FXMAPFUNC(SEL_COMMAND,XFileExplorer::ID_DIR_FORWARD_HIST,XFileExplorer::onCmdDirForwardHist),
+	FXMAPFUNC(SEL_UPDATE,XFileExplorer::ID_DIR_FORWARD_HIST,XFileExplorer::onUpdDirForwardHist),
+	FXMAPFUNC(SEL_KEYPRESS,0,XFileExplorer::onKeyPress),
+	FXMAPFUNC(SEL_CLOSE,0,XFileExplorer::onQuit),
+	FXMAPFUNC(SEL_UPDATE,XFileExplorer::ID_TOGGLE_STATUS,XFileExplorer::onUpdToggleStatus),
+	FXMAPFUNC(SEL_UPDATE,XFileExplorer::ID_SHOW_ONE_PANEL,XFileExplorer::onUpdShowPanels),
+	FXMAPFUNC(SEL_UPDATE,XFileExplorer::ID_SHOW_TWO_PANELS,XFileExplorer::onUpdShowPanels),
+	FXMAPFUNC(SEL_UPDATE,XFileExplorer::ID_SHOW_TREE_PANEL,XFileExplorer::onUpdShowPanels),
+	FXMAPFUNC(SEL_UPDATE,XFileExplorer::ID_SHOW_TREE_TWO_PANELS,XFileExplorer::onUpdShowPanels),
+	FXMAPFUNC(SEL_UPDATE,XFileExplorer::ID_GOTO_LOCATION,XFileExplorer::onUpdFileLocation),
+	FXMAPFUNC(SEL_UPDATE,XFileExplorer::ID_EMPTY_TRASHCAN,XFileExplorer::onUpdEmptyTrashcan),
+	FXMAPFUNC(SEL_UPDATE,XFileExplorer::ID_FILE_DELETE,XFileExplorer::onUpdFileDelete),
+	FXMAPFUNC(SEL_UPDATE,XFileExplorer::ID_FILE_TRASH,XFileExplorer::onUpdFileTrash),
+	FXMAPFUNC(SEL_UPDATE,XFileExplorer::ID_FILE_RENAME,XFileExplorer::onUpdFileRename),
+	FXMAPFUNC(SEL_UPDATE,XFileExplorer::ID_FILE_PROPERTIES,XFileExplorer::onUpdFileMan),
+	FXMAPFUNC(SEL_UPDATE,XFileExplorer::ID_FILE_COPYTO,XFileExplorer::onUpdFileMan),
+	FXMAPFUNC(SEL_UPDATE,XFileExplorer::ID_FILE_MOVE,XFileExplorer::onUpdFileMan),
+	FXMAPFUNC(SEL_UPDATE,XFileExplorer::ID_FILE_SYMLINK,XFileExplorer::onUpdFileMan),
+	FXMAPFUNC(SEL_UPDATE,XFileExplorer::ID_FILE_COPY,XFileExplorer::onUpdFileMan),
+	FXMAPFUNC(SEL_UPDATE,XFileExplorer::ID_FILE_CUT,XFileExplorer::onUpdFileMan),
+	FXMAPFUNC(SEL_UPDATE,XFileExplorer::ID_FILE_PASTE,XFileExplorer::onUpdFilePaste),
+};
 
 
 // Object implementation
@@ -206,6 +205,7 @@ XFileExplorer::XFileExplorer(FXApp *app,char *title,FXIcon *bigicon,FXIcon *mini
                      getApp()->reg().readUnsignedEntry("LEFT PANEL","user_size",50),
                      getApp()->reg().readUnsignedEntry("LEFT PANEL","grou_size",50),
                      getApp()->reg().readUnsignedEntry("LEFT PANEL","attr_size",100),
+                     getApp()->reg().readUnsignedEntry("LEFT PANEL","deldate_size",150),
 					 listbackcolor,listforecolor,
 					 LAYOUT_SIDE_TOP|LAYOUT_FILL_X|LAYOUT_FILL_Y|LAYOUT_FIX_WIDTH,0,0,MIN_PANEL_WIDTH,0);
     rpanel=new FilePanel("RIGHT PANEL",subsplit,
@@ -217,6 +217,7 @@ XFileExplorer::XFileExplorer(FXApp *app,char *title,FXIcon *bigicon,FXIcon *mini
                      getApp()->reg().readUnsignedEntry("RIGHT PANEL","user_size",50),
                      getApp()->reg().readUnsignedEntry("RIGHT PANEL","grou_size",50),
                      getApp()->reg().readUnsignedEntry("RIGHT PANEL","attr_size",100),
+                     getApp()->reg().readUnsignedEntry("RIGHT PANEL","deldate_size",150),
 					 listbackcolor,listforecolor,
 					 LAYOUT_SIDE_TOP|LAYOUT_FILL_X|LAYOUT_FILL_Y|LAYOUT_FIX_WIDTH,0,0,MIN_PANEL_WIDTH,0);
     lpanel->Next(rpanel);
@@ -397,7 +398,7 @@ XFileExplorer::XFileExplorer(FXApp *app,char *title,FXIcon *bigicon,FXIcon *mini
 
 	btnforwardhist=new FXArrowButton(generaltoolbar,this,XFileExplorer::ID_DIR_FORWARD_HIST,LAYOUT_FILL_Y|FRAME_RAISED|FRAME_THICK|ARROW_DOWN|ARROW_TOOLBAR);
 
-	btn=new FXButton(generaltoolbar,_("\tGo up (Backspace)"),dirupicon,lpanel->current,FilePanel::ID_DIRECTORY_UP,BUTTON_TOOLBAR|FRAME_RAISED|LAYOUT_TOP|LAYOUT_LEFT);
+	btn=new FXButton(generaltoolbar,_("\tGo up (Backspace)"),dirupicon,this,XFileExplorer::ID_DIR_UP,BUTTON_TOOLBAR|FRAME_RAISED|LAYOUT_TOP|LAYOUT_LEFT);
     btn->addHotKey(KEY_BackSpace);
 
 	toolbarSeparator(generaltoolbar);
@@ -444,14 +445,6 @@ XFileExplorer::XFileExplorer(FXApp *app,char *title,FXIcon *bigicon,FXIcon *mini
     btn->addHotKey(hotkey);
 #endif
 
-	//toolbarSeparator(generaltoolbar);
-
-	// Quit button
-    btn=new FXButton(generaltoolbar,_("\tQuit (Ctrl-Q, Ctrl-W)"),quiticon,this,XFileExplorer::ID_QUIT,BUTTON_TOOLBAR|LAYOUT_TOP|LAYOUT_LEFT|ICON_BEFORE_TEXT|FRAME_RAISED);
-    btn->hide();
-    hotkey=(CONTROLMASK<<16) | KEY_w;
-    btn->addHotKey(hotkey);
-
 	// Panel toolbar
 	
 	// Show one panel
@@ -474,18 +467,6 @@ XFileExplorer::XFileExplorer(FXApp *app,char *title,FXIcon *bigicon,FXIcon *mini
     hotkey = (CONTROLMASK<<16) | KEY_F4;
    	btn->addHotKey(hotkey);
 
-	// Show or hide hidden files (button not shown : just to add the shortcut)   
-    tgbtn=new FXToggleButton(paneltoolbar,_("\tHide hidden files (Ctrl-F6)"),_("\tShow hidden files (Ctrl-F6)"),hidehiddenicon,showhiddenicon,lpanel->current,FilePanel::ID_TOGGLE_HIDDEN,BUTTON_TOOLBAR|FRAME_RAISED|LAYOUT_TOP|LAYOUT_LEFT|ICON_BEFORE_TEXT);
-    tgbtn->hide();
-	hotkey=(CONTROLMASK<<16) | KEY_F6;
-    tgbtn->addHotKey(hotkey);
-
-	// Show or hide thumbnails (button not shown : just to add the shortcut)   
-   	tgbtn=new FXToggleButton(paneltoolbar,_("\tHide thumbnails (Ctrl-F7)"),_("\tShow thumbnails (Ctrl-F7)"),showthumbicon,hidethumbicon,lpanel->current,FilePanel::ID_TOGGLE_THUMBNAILS,BUTTON_TOOLBAR|FRAME_RAISED|LAYOUT_TOP|LAYOUT_LEFT|ICON_BEFORE_TEXT);
-    tgbtn->hide();
-	hotkey=KEY_F7;
-   	tgbtn->addHotKey(hotkey);
-
 	toolbarSeparator(paneltoolbar);
 
     // Switch display modes
@@ -577,8 +558,8 @@ XFileExplorer::XFileExplorer(FXApp *app,char *title,FXIcon *bigicon,FXIcon *mini
     new FXMenuRadio(viewmenu,_("T&ree and panel\tCtrl-F2"),this,XFileExplorer::ID_SHOW_TREE_PANEL);
     new FXMenuRadio(viewmenu,_("Two &panels\tCtrl-F3"),this,XFileExplorer::ID_SHOW_TWO_PANELS);
     new FXMenuRadio(viewmenu,_("Tr&ee and two panels\tCtrl-F4"),this,XFileExplorer::ID_SHOW_TREE_TWO_PANELS);
-    new FXMenuSeparator(viewmenu);
-    new FXMenuCheck(viewmenu,_("&Hidden folders\tCtrl-F5"),dirpanel,DirPanel::ID_TOGGLE_HIDDEN);
+    //new FXMenuSeparator(viewmenu);
+    //new FXMenuCheck(viewmenu,_("&Hidden folders\tCtrl-F5"),dirpanel,DirPanel::ID_TOGGLE_HIDDEN);
     viewmenutitle=new FXMenuTitle(menubar,_("&View"),NULL,viewmenu);
 
     // Left View Menu Pane
@@ -587,9 +568,9 @@ XFileExplorer::XFileExplorer(FXApp *app,char *title,FXIcon *bigicon,FXIcon *mini
     new FXMenuCheck(lpanelmenu,_("&Hidden files"),lpanel->list,FileList::ID_TOGGLE_HIDDEN);
     new FXMenuCheck(lpanelmenu,_("&Thumbnails"),lpanel->list,FileList::ID_TOGGLE_THUMBNAILS);
     new FXMenuSeparator(lpanelmenu);
-    new FXMenuRadio(lpanelmenu,_("&Big icons"),lpanel->list,FXIconList::ID_SHOW_BIG_ICONS);
-    new FXMenuRadio(lpanelmenu,_("&Small icons"),lpanel->list,FXIconList::ID_SHOW_MINI_ICONS);
-    new FXMenuRadio(lpanelmenu,_("F&ull file list"),lpanel->list,FXIconList::ID_SHOW_DETAILS);
+    new FXMenuRadio(lpanelmenu,_("&Big icons"),lpanel->list,IconList::ID_SHOW_BIG_ICONS);
+    new FXMenuRadio(lpanelmenu,_("&Small icons"),lpanel->list,IconList::ID_SHOW_MINI_ICONS);
+    new FXMenuRadio(lpanelmenu,_("F&ull file list"),lpanel->list,IconList::ID_SHOW_DETAILS);
     new FXMenuSeparator(lpanelmenu);
     new FXMenuRadio(lpanelmenu,_("&Rows"),lpanel->list,FileList::ID_ARRANGE_BY_ROWS);
     new FXMenuRadio(lpanelmenu,_("&Columns"),lpanel->list,FileList::ID_ARRANGE_BY_COLUMNS);
@@ -610,9 +591,9 @@ XFileExplorer::XFileExplorer(FXApp *app,char *title,FXIcon *bigicon,FXIcon *mini
     new FXMenuCheck(rpanelmenu,_("&Hidden files"),rpanel->list,FileList::ID_TOGGLE_HIDDEN);
     new FXMenuCheck(rpanelmenu,_("&Thumbnails"),rpanel->list,FileList::ID_TOGGLE_THUMBNAILS);
     new FXMenuSeparator(rpanelmenu);
-    new FXMenuRadio(rpanelmenu,_("&Big icons"),rpanel->list,FXIconList::ID_SHOW_BIG_ICONS);
-    new FXMenuRadio(rpanelmenu,_("&Small icons"),rpanel->list,FXIconList::ID_SHOW_MINI_ICONS);
-    new FXMenuRadio(rpanelmenu,_("F&ull file list"),rpanel->list,FXIconList::ID_SHOW_DETAILS);
+    new FXMenuRadio(rpanelmenu,_("&Big icons"),rpanel->list,IconList::ID_SHOW_BIG_ICONS);
+    new FXMenuRadio(rpanelmenu,_("&Small icons"),rpanel->list,IconList::ID_SHOW_MINI_ICONS);
+    new FXMenuRadio(rpanelmenu,_("F&ull file list"),rpanel->list,IconList::ID_SHOW_DETAILS);
     new FXMenuSeparator(rpanelmenu);
     new FXMenuRadio(rpanelmenu,_("&Rows"),rpanel->list,FileList::ID_ARRANGE_BY_ROWS);
     new FXMenuRadio(rpanelmenu,_("&Columns"),rpanel->list,FileList::ID_ARRANGE_BY_COLUMNS);
@@ -655,11 +636,18 @@ XFileExplorer::XFileExplorer(FXApp *app,char *title,FXIcon *bigicon,FXIcon *mini
     helpmenutitle=new FXMenuTitle(menubar,_("&Help"),NULL,helpmenu);
 
   	// Install some other key accelerators for compatibility with Midnight Commander
-	//getAccelTable()->addAccel(FXSEL(0,KEY_F3),lpanel->current,FXSEL(SEL_COMMAND,FilePanel::ID_VIEW));
-	getAccelTable()->addAccel(FXSEL(0,KEY_F4),lpanel->current,FXSEL(SEL_COMMAND,FilePanel::ID_EDIT));
-	getAccelTable()->addAccel(FXSEL(0,KEY_F5),lpanel->current,FXSEL(SEL_COMMAND,FilePanel::ID_FILE_COPYTO));
-	getAccelTable()->addAccel(FXSEL(0,KEY_F6),lpanel->current,FXSEL(SEL_COMMAND,FilePanel::ID_FILE_MOVE));
-	getAccelTable()->addAccel(FXSEL(0,KEY_Escape),lpanel->current,FXSEL(SEL_COMMAND,FilePanel::FilePanel::ID_DESELECT_ALL));
+	getAccelTable()->addAccel(KEY_F4,lpanel->current,FXSEL(SEL_COMMAND,FilePanel::ID_EDIT));
+	getAccelTable()->addAccel(KEY_F5,lpanel->current,FXSEL(SEL_COMMAND,FilePanel::ID_FILE_COPYTO));
+	getAccelTable()->addAccel(KEY_F6,lpanel->current,FXSEL(SEL_COMMAND,FilePanel::ID_FILE_MOVE));
+	getAccelTable()->addAccel(KEY_Escape,lpanel->current,FXSEL(SEL_COMMAND,FilePanel::ID_DESELECT_ALL));
+
+	// Other accelerators
+	getAccelTable()->addAccel(MKUINT(KEY_F5,CONTROLMASK),dirpanel,FXSEL(SEL_COMMAND,DirPanel::ID_TOGGLE_HIDDEN));
+	getAccelTable()->addAccel(MKUINT(KEY_F6,CONTROLMASK),lpanel->current,FXSEL(SEL_COMMAND,FilePanel::ID_TOGGLE_HIDDEN));
+	getAccelTable()->addAccel(MKUINT(KEY_F7,CONTROLMASK),lpanel->current,FXSEL(SEL_COMMAND,FilePanel::ID_TOGGLE_THUMBNAILS));
+
+	getAccelTable()->addAccel(MKUINT(KEY_q,CONTROLMASK),this,FXSEL(SEL_COMMAND,XFileExplorer::ID_QUIT));
+	getAccelTable()->addAccel(MKUINT(KEY_w,CONTROLMASK),this,FXSEL(SEL_COMMAND,XFileExplorer::ID_QUIT));
 
     // Make a tool tip
     new FXToolTip(app,0);
@@ -668,6 +656,9 @@ XFileExplorer::XFileExplorer(FXApp *app,char *title,FXIcon *bigicon,FXIcon *mini
     rundialog=NULL;
 	prefsdialog=NULL;
 	helpwindow=NULL;
+	
+	// Initial focus is on (left) file panel
+	panelfocus=FILEPANEL_FOCUS;
 }
     
 // Save configuration when quitting
@@ -686,6 +677,7 @@ void XFileExplorer::saveConfig()
         getApp()->reg().writeUnsignedEntry("LEFT PANEL","user_size",lpanel->list->getHeaderSize(5));
         getApp()->reg().writeUnsignedEntry("LEFT PANEL","grou_size",lpanel->list->getHeaderSize(6));
         getApp()->reg().writeUnsignedEntry("LEFT PANEL","attr_size",lpanel->list->getHeaderSize(7));
+        getApp()->reg().writeUnsignedEntry("LEFT PANEL","deldate_size",lpanel->list->getHeaderSize(8));
         getApp()->reg().writeUnsignedEntry("LEFT PANEL","liststyle",lpanel->list->getListStyle());
         getApp()->reg().writeUnsignedEntry("LEFT PANEL","hiddenfiles",lpanel->list->showHiddenFiles());
         getApp()->reg().writeUnsignedEntry("LEFT PANEL","showthumbnails",lpanel->list->showThumbnails());
@@ -778,6 +770,7 @@ void XFileExplorer::saveConfig()
         getApp()->reg().writeUnsignedEntry("RIGHT PANEL","user_size",rpanel->list->getHeaderSize(5));
         getApp()->reg().writeUnsignedEntry("RIGHT PANEL","grou_size",rpanel->list->getHeaderSize(6));
         getApp()->reg().writeUnsignedEntry("RIGHT PANEL","attr_size",rpanel->list->getHeaderSize(7));
+        getApp()->reg().writeUnsignedEntry("RIGHT PANEL","deldate_size",rpanel->list->getHeaderSize(8));
         getApp()->reg().writeUnsignedEntry("RIGHT PANEL","liststyle",rpanel->list->getListStyle());
         getApp()->reg().writeUnsignedEntry("RIGHT PANEL","panel_width",(FXuint)rpanel_width);
         getApp()->reg().writeUnsignedEntry("RIGHT PANEL","panel_tree_width",(FXuint)rpanel_tree_width);
@@ -981,9 +974,9 @@ void XFileExplorer::create()
 	dirpanel->list->setDirectory(startdir,TRUE);
     
 	// Set file panels list style
-	liststyle=getApp()->reg().readUnsignedEntry("LEFT PANEL","liststyle",(FXuint)FXIconList::ID_SHOW_DETAILS);
+	liststyle=getApp()->reg().readUnsignedEntry("LEFT PANEL","liststyle",(FXuint)IconList::ID_SHOW_DETAILS);
 	lpanel->list->setListStyle(liststyle|ICONLIST_AUTOSIZE);
-    liststyle=getApp()->reg().readUnsignedEntry("RIGHT PANEL","liststyle",(FXuint)FXIconList::ID_SHOW_DETAILS);
+    liststyle=getApp()->reg().readUnsignedEntry("RIGHT PANEL","liststyle",(FXuint)IconList::ID_SHOW_DETAILS);
     rpanel->list->setListStyle(liststyle|ICONLIST_AUTOSIZE);
 
 	// Show or hide hidden files listed in panels
@@ -1267,13 +1260,28 @@ long XFileExplorer::onQuit(FXObject*,FXSelector,void*)
 }
 
 
+// Directory up
+long  XFileExplorer::onCmdDirUp(FXObject* sender,FXSelector,void*)
+{
+	lpanel->current->handle(sender,FXSEL(SEL_COMMAND,FilePanel::ID_DIRECTORY_UP),NULL);
+
+	// Set focus on dirpanel or filepanel
+	if (panelfocus==DIRPANEL_FOCUS)
+		dirpanel->list->setFocus();
+	else
+		lpanel->current->list->setFocus();
+
+    return 1;
+}
+
+
 // Directory back
-long  XFileExplorer::onCmdDirBack(FXObject*,FXSelector s,void* p)
+long  XFileExplorer::onCmdDirBack(FXObject*,FXSelector,void*)
 {
 	StringList *backhist, *forwardhist;
 	StringItem *item;
 	FXString pathname;
-
+	
 	// Get the filelist history
 	backhist=lpanel->current->list->backhist;
 	forwardhist=lpanel->current->list->forwardhist;
@@ -1287,17 +1295,23 @@ long  XFileExplorer::onCmdDirBack(FXObject*,FXSelector s,void* p)
 	backhist->removeFirstItem();
 	forwardhist->insertFirstItem(lpanel->current->list->getDirectory());
 	
-	// Go to to the previous directory
+	// Go to the previous directory
 	lpanel->current->list->setDirectory(pathname,FALSE);
 	lpanel->current->updatePathLinker();
 	dirpanel->list->setDirectory(pathname,TRUE);
+	
+	// Set focus on dirpanel or filepanel
+	if (panelfocus==DIRPANEL_FOCUS)
+		dirpanel->list->setFocus();
+	else
+		lpanel->current->list->setFocus();
 
     return 1;
 }
 
 
 // Update directory back
-long  XFileExplorer::onUpdDirBack(FXObject* sender, FXSelector sel, void* ptr)
+long  XFileExplorer::onUpdDirBack(FXObject* sender, FXSelector, void* ptr)
 {
 	StringList *backhist;
 	StringItem *item;
@@ -1318,7 +1332,7 @@ long  XFileExplorer::onUpdDirBack(FXObject* sender, FXSelector sel, void* ptr)
 
 
 // Directory forward
-long  XFileExplorer::onCmdDirForward(FXObject*,FXSelector s,void* p)
+long  XFileExplorer::onCmdDirForward(FXObject*,FXSelector,void*)
 {
 	StringList *backhist, *forwardhist;
 	StringItem *item;
@@ -1337,11 +1351,17 @@ long  XFileExplorer::onCmdDirForward(FXObject*,FXSelector s,void* p)
 	forwardhist->removeFirstItem();
 	backhist->insertFirstItem(lpanel->current->list->getDirectory());
 	
-	// Go to to the next directory
+	// Go to the next directory
 	lpanel->current->list->setDirectory(pathname,FALSE);
 	lpanel->current->updatePathLinker();
 	dirpanel->list->setDirectory(pathname,TRUE);
 
+	// Set focus on dirpanel or filepanel
+	if (panelfocus==DIRPANEL_FOCUS)
+		dirpanel->list->setFocus();
+	else
+		lpanel->current->list->setFocus();
+
     return 1;
 }
 
@@ -1680,6 +1700,7 @@ long XFileExplorer::onCmdHelp(FXObject*,FXSelector,void*)
     // Display help window
 	if (helpwindow==NULL)
 		helpwindow=new TextWindow(getApp(),_("Help"),40,120);			
+	helpwindow->setIcon(helpicon);
 
     // Set text font
 	FXString fontspec;
@@ -1972,7 +1993,8 @@ long XFileExplorer::onCmdRun(FXObject*,FXSelector,void*)
     			// Make and show command window
 				CommandWindow *cmdwin=new CommandWindow(getApp(),_("Command log"),command,30,80);			
 				cmdwin->create();
-				
+				cmdwin->setIcon(runicon);
+
 				// The CommandWindow object will delete itself when closed!
 			}
 			
@@ -2257,6 +2279,13 @@ long XFileExplorer::onUpdFileTrash(FXObject* o,FXSelector,void*)
 // Update the file operation menu items
 long XFileExplorer::onUpdFileMan(FXObject* o,FXSelector,void*)
 {
+	// Update the panelfocus variable
+	if (lpanel->current->list->hasFocus())
+		panelfocus=FILEPANEL_FOCUS;
+	if (dirpanel->list->hasFocus())
+		panelfocus=DIRPANEL_FOCUS;
+
+	// Update the file operation menu items
 	FXint num=lpanel->current->list->getNumSelectedItems();
 	if (num==0)
 		o->handle(this,FXSEL(SEL_COMMAND,FXWindow::ID_DISABLE),NULL);
