@@ -44,7 +44,9 @@ protected:
 		ONE_PANEL,
 		TWO_PANELS,
 		TREE_PANEL,
-		TREE_TWO_PANELS
+		TREE_TWO_PANELS,
+		FILEPANEL_FOCUS,
+		DIRPANEL_FOCUS,
 	};	
 	int panel_view;
     int RunHistSize;
@@ -89,6 +91,7 @@ protected:
 	FXuint			height;
 	FXColor			listbackcolor;
 	FXColor			listforecolor;
+	FXColor			highlightcolor;
     FXButton		*btndel;
     FXButton		*btntrash;
 	FXArrowButton   *btnbackhist;
@@ -96,7 +99,10 @@ protected:
 	HistInputDialog*   rundialog;
 	PreferencesBox*    prefsdialog;
 	TextWindow*		   helpwindow;
-	FXString message;
+	FXString 		message;
+	FXuint 			panelfocus;
+	
+	
 public:
     enum{
         ID_ABOUT=FXMainWindow::ID_LAST,
@@ -104,6 +110,7 @@ public:
 		ID_REFRESH,
 		ID_EMPTY_TRASHCAN,
         ID_XTERM,
+		ID_DIR_UP,
 		ID_DIR_BACK,
 		ID_DIR_FORWARD,
 		ID_DIR_BACK_HIST,
@@ -135,11 +142,7 @@ public:
         ID_BOOKMARK,
         ID_ADD_BOOKMARK,
         ID_QUIT,
-		ID_OPTION1,
- 		ID_OPTION2,
- 		ID_OPTION3,
-		ID_OPTION4,
-      ID_LAST
+		ID_LAST
     };
 public:
     XFileExplorer(FXApp *app=NULL,char *title = "X File Explorer",FXIcon *bigicon=NULL,FXIcon *miniicon=NULL);
@@ -177,6 +180,7 @@ public:
 	long onCmdFileTrash(FXObject*,FXSelector sel,void*);
 	long onUpdFileDelete(FXObject*,FXSelector,void*);
 	long onUpdFileTrash(FXObject*,FXSelector,void*);
+	long onCmdDirUp(FXObject*,FXSelector,void*);
 	long onCmdDirBack(FXObject*,FXSelector,void*);
 	long onUpdDirBack(FXObject*,FXSelector,void*);
 	long onCmdDirForward(FXObject*,FXSelector,void*);
