@@ -110,55 +110,56 @@ void toolbarSeparator(FXToolBar* tb)
 }
 
 // Map
-FXDEFMAP(XFileImage) XFileImageMap[]={
-										FXMAPFUNC(SEL_COMMAND,XFileImage::ID_ABOUT,XFileImage::onCmdAbout),
-                                        FXMAPFUNC(SEL_COMMAND,XFileImage::ID_OPEN,XFileImage::onCmdOpen),
-                                        FXMAPFUNC(SEL_UPDATE,XFileImage::ID_TITLE,XFileImage::onUpdTitle),
-                                        FXMAPFUNC(SEL_COMMAND,XFileImage::ID_QUIT,XFileImage::onCmdQuit),
-                                        FXMAPFUNC(SEL_SIGNAL,XFileImage::ID_QUIT,XFileImage::onCmdQuit),
-                                        FXMAPFUNC(SEL_CLOSE,XFileImage::ID_TITLE,XFileImage::onCmdQuit),
-                                        FXMAPFUNC(SEL_DOUBLECLICKED,XFileImage::ID_FILELIST,XFileImage::onCmdItemDoubleClicked),
-                                        FXMAPFUNC(SEL_CLICKED,XFileImage::ID_FILELIST,XFileImage::onCmdItemClicked),
-                                        FXMAPFUNC(SEL_COMMAND,XFileImage::ID_RECENTFILE,XFileImage::onCmdRecentFile),
-                                        FXMAPFUNC(SEL_COMMAND,XFileImage::ID_TOGGLE_HIDDEN,XFileImage::onCmdToggleHidden),
-                                        FXMAPFUNC(SEL_COMMAND,XFileImage::ID_TOGGLE_THUMBNAILS,XFileImage::onCmdToggleThumbnails),
-                                        FXMAPFUNC(SEL_COMMAND,XFileImage::ID_SHOW_DETAILS,XFileImage::onCmdShowDetails),
-                                        FXMAPFUNC(SEL_COMMAND,XFileImage::ID_SHOW_MINI,XFileImage::onCmdShowMini),
-                                        FXMAPFUNC(SEL_COMMAND,XFileImage::ID_SHOW_BIG,XFileImage::onCmdShowBig),
-                                        FXMAPFUNC(SEL_COMMAND,XFileImage::ID_ROWS,XFileImage::onCmdShowRows),
-										FXMAPFUNC(SEL_COMMAND,XFileImage::ID_COLS,XFileImage::onCmdShowCols),
-                                        FXMAPFUNC(SEL_COMMAND,XFileImage::ID_ROTATE_90,XFileImage::onCmdRotate),
-                                        FXMAPFUNC(SEL_COMMAND,XFileImage::ID_ROTATE_270,XFileImage::onCmdRotate),
-                                        FXMAPFUNC(SEL_COMMAND,XFileImage::ID_MIRROR_HOR,XFileImage::onCmdMirror),
-                                        FXMAPFUNC(SEL_COMMAND,XFileImage::ID_MIRROR_VER,XFileImage::onCmdMirror),
-                                        FXMAPFUNC(SEL_COMMAND,XFileImage::ID_ZOOM_IN,XFileImage::onCmdZoomIn),
-                                        FXMAPFUNC(SEL_COMMAND,XFileImage::ID_ZOOM_OUT,XFileImage::onCmdZoomOut),
-                                        FXMAPFUNC(SEL_COMMAND,XFileImage::ID_ZOOM_100,XFileImage::onCmdZoom100),
-                                        FXMAPFUNC(SEL_COMMAND,XFileImage::ID_ZOOM_WIN,XFileImage::onCmdZoomWin),
-	                                    FXMAPFUNC(SEL_COMMAND,XFileImage::ID_PRINT,XFileImage::onCmdPrint),
-                                        FXMAPFUNC(SEL_UPDATE,XFileImage::ID_PRINT,XFileImage::onUpdImage),
-                                        FXMAPFUNC(SEL_UPDATE,XFileImage::ID_ROTATE_90,XFileImage::onUpdImage),
-                                        FXMAPFUNC(SEL_UPDATE,XFileImage::ID_ROTATE_270,XFileImage::onUpdImage),
-                                        FXMAPFUNC(SEL_UPDATE,XFileImage::ID_MIRROR_HOR,XFileImage::onUpdImage),
-                                        FXMAPFUNC(SEL_UPDATE,XFileImage::ID_MIRROR_VER,XFileImage::onUpdImage),
-                                        FXMAPFUNC(SEL_UPDATE,XFileImage::ID_ZOOM_IN,XFileImage::onUpdImage),                                        
-                                        FXMAPFUNC(SEL_UPDATE,XFileImage::ID_ZOOM_OUT,XFileImage::onUpdImage),                                        
-                                        FXMAPFUNC(SEL_UPDATE,XFileImage::ID_ZOOM_100,XFileImage::onUpdImage),                                        
-                                        FXMAPFUNC(SEL_UPDATE,XFileImage::ID_ZOOM_WIN,XFileImage::onUpdImage),                                        
-                                        FXMAPFUNC(SEL_UPDATE,XFileImage::ID_SHOW_BIG,XFileImage::onUpdFileView),
-										FXMAPFUNC(SEL_UPDATE,XFileImage::ID_SHOW_MINI,XFileImage::onUpdFileView),
-                                        FXMAPFUNC(SEL_UPDATE,XFileImage::ID_SHOW_DETAILS,XFileImage::onUpdFileView),                                        
- 										FXMAPFUNC(SEL_UPDATE,XFileImage::ID_ROWS,XFileImage::onUpdIconView),
-                                        FXMAPFUNC(SEL_UPDATE,XFileImage::ID_COLS,XFileImage::onUpdIconView),
-                                        FXMAPFUNC(SEL_UPDATE,XFileImage::ID_TOGGLE_HIDDEN,XFileImage::onUpdToggleHidden),
-                                        FXMAPFUNC(SEL_UPDATE,XFileImage::ID_TOGGLE_THUMBNAILS,XFileImage::onUpdToggleThumbnails),
-                               			FXMAPFUNC(SEL_UPDATE,XFileImage::ID_LABEL,XFileImage::onUpdLabel),
-                                        FXMAPFUNC(SEL_COMMAND,XFileImage::ID_TOGGLE_FIT_WIN,XFileImage::onCmdToggleFitWin),
-										FXMAPFUNC(SEL_UPDATE,XFileImage::ID_TOGGLE_FIT_WIN,XFileImage::onUpdToggleFitWin),
-										FXMAPFUNC(SEL_COMMAND,XFileImage::ID_HOME,XFileImage::onCmdHome),
-										FXMAPFUNC(SEL_COMMAND,XFileImage::ID_WORK,XFileImage::onCmdWork),
-										FXMAPFUNC(SEL_RIGHTBUTTONRELEASE,XFileImage::ID_FILELIST,XFileImage::onCmdPopupMenu),
-                                    };
+FXDEFMAP(XFileImage) XFileImageMap[]=
+{
+	FXMAPFUNC(SEL_COMMAND,XFileImage::ID_ABOUT,XFileImage::onCmdAbout),
+	FXMAPFUNC(SEL_COMMAND,XFileImage::ID_OPEN,XFileImage::onCmdOpen),
+	FXMAPFUNC(SEL_UPDATE,XFileImage::ID_TITLE,XFileImage::onUpdTitle),
+	FXMAPFUNC(SEL_COMMAND,XFileImage::ID_QUIT,XFileImage::onCmdQuit),
+	FXMAPFUNC(SEL_SIGNAL,XFileImage::ID_QUIT,XFileImage::onCmdQuit),
+	FXMAPFUNC(SEL_CLOSE,XFileImage::ID_TITLE,XFileImage::onCmdQuit),
+	FXMAPFUNC(SEL_DOUBLECLICKED,XFileImage::ID_FILELIST,XFileImage::onCmdItemDoubleClicked),
+	FXMAPFUNC(SEL_CLICKED,XFileImage::ID_FILELIST,XFileImage::onCmdItemClicked),
+	FXMAPFUNC(SEL_COMMAND,XFileImage::ID_RECENTFILE,XFileImage::onCmdRecentFile),
+	FXMAPFUNC(SEL_COMMAND,XFileImage::ID_TOGGLE_HIDDEN,XFileImage::onCmdToggleHidden),
+	FXMAPFUNC(SEL_COMMAND,XFileImage::ID_TOGGLE_THUMBNAILS,XFileImage::onCmdToggleThumbnails),
+	FXMAPFUNC(SEL_COMMAND,XFileImage::ID_SHOW_DETAILS,XFileImage::onCmdShowDetails),
+	FXMAPFUNC(SEL_COMMAND,XFileImage::ID_SHOW_MINI,XFileImage::onCmdShowMini),
+	FXMAPFUNC(SEL_COMMAND,XFileImage::ID_SHOW_BIG,XFileImage::onCmdShowBig),
+	FXMAPFUNC(SEL_COMMAND,XFileImage::ID_ROWS,XFileImage::onCmdShowRows),
+	FXMAPFUNC(SEL_COMMAND,XFileImage::ID_COLS,XFileImage::onCmdShowCols),
+	FXMAPFUNC(SEL_COMMAND,XFileImage::ID_ROTATE_90,XFileImage::onCmdRotate),
+	FXMAPFUNC(SEL_COMMAND,XFileImage::ID_ROTATE_270,XFileImage::onCmdRotate),
+	FXMAPFUNC(SEL_COMMAND,XFileImage::ID_MIRROR_HOR,XFileImage::onCmdMirror),
+	FXMAPFUNC(SEL_COMMAND,XFileImage::ID_MIRROR_VER,XFileImage::onCmdMirror),
+	FXMAPFUNC(SEL_COMMAND,XFileImage::ID_ZOOM_IN,XFileImage::onCmdZoomIn),
+	FXMAPFUNC(SEL_COMMAND,XFileImage::ID_ZOOM_OUT,XFileImage::onCmdZoomOut),
+	FXMAPFUNC(SEL_COMMAND,XFileImage::ID_ZOOM_100,XFileImage::onCmdZoom100),
+	FXMAPFUNC(SEL_COMMAND,XFileImage::ID_ZOOM_WIN,XFileImage::onCmdZoomWin),
+	FXMAPFUNC(SEL_COMMAND,XFileImage::ID_PRINT,XFileImage::onCmdPrint),
+	FXMAPFUNC(SEL_UPDATE,XFileImage::ID_PRINT,XFileImage::onUpdImage),
+	FXMAPFUNC(SEL_UPDATE,XFileImage::ID_ROTATE_90,XFileImage::onUpdImage),
+	FXMAPFUNC(SEL_UPDATE,XFileImage::ID_ROTATE_270,XFileImage::onUpdImage),
+	FXMAPFUNC(SEL_UPDATE,XFileImage::ID_MIRROR_HOR,XFileImage::onUpdImage),
+	FXMAPFUNC(SEL_UPDATE,XFileImage::ID_MIRROR_VER,XFileImage::onUpdImage),
+	FXMAPFUNC(SEL_UPDATE,XFileImage::ID_ZOOM_IN,XFileImage::onUpdImage),                                        
+	FXMAPFUNC(SEL_UPDATE,XFileImage::ID_ZOOM_OUT,XFileImage::onUpdImage),                                        
+	FXMAPFUNC(SEL_UPDATE,XFileImage::ID_ZOOM_100,XFileImage::onUpdImage),                                        
+	FXMAPFUNC(SEL_UPDATE,XFileImage::ID_ZOOM_WIN,XFileImage::onUpdImage),                                        
+	FXMAPFUNC(SEL_UPDATE,XFileImage::ID_SHOW_BIG,XFileImage::onUpdFileView),
+	FXMAPFUNC(SEL_UPDATE,XFileImage::ID_SHOW_MINI,XFileImage::onUpdFileView),
+	FXMAPFUNC(SEL_UPDATE,XFileImage::ID_SHOW_DETAILS,XFileImage::onUpdFileView),                                        
+	FXMAPFUNC(SEL_UPDATE,XFileImage::ID_ROWS,XFileImage::onUpdIconView),
+	FXMAPFUNC(SEL_UPDATE,XFileImage::ID_COLS,XFileImage::onUpdIconView),
+	FXMAPFUNC(SEL_UPDATE,XFileImage::ID_TOGGLE_HIDDEN,XFileImage::onUpdToggleHidden),
+	FXMAPFUNC(SEL_UPDATE,XFileImage::ID_TOGGLE_THUMBNAILS,XFileImage::onUpdToggleThumbnails),
+	FXMAPFUNC(SEL_UPDATE,XFileImage::ID_LABEL,XFileImage::onUpdLabel),
+	FXMAPFUNC(SEL_COMMAND,XFileImage::ID_TOGGLE_FIT_WIN,XFileImage::onCmdToggleFitWin),
+	FXMAPFUNC(SEL_UPDATE,XFileImage::ID_TOGGLE_FIT_WIN,XFileImage::onUpdToggleFitWin),
+	FXMAPFUNC(SEL_COMMAND,XFileImage::ID_HOME,XFileImage::onCmdHome),
+	FXMAPFUNC(SEL_COMMAND,XFileImage::ID_WORK,XFileImage::onCmdWork),
+	FXMAPFUNC(SEL_RIGHTBUTTONRELEASE,XFileImage::ID_FILELIST,XFileImage::onCmdPopupMenu),
+};
 
 
 // Object implementation
@@ -230,6 +231,89 @@ XFileImage::XFileImage(FXApp* a):FXMainWindow(a,"Xfi ",NULL,NULL,DECOR_ALL,0,0,8
     filelist=new FileList(fileframe,this,ID_FILELIST,LAYOUT_FILL_X|LAYOUT_FILL_Y|ICONLIST_MINI_ICONS|ICONLIST_AUTOSIZE);
 	filelist->setTextColor(listforecolor);
 	filelist->setBackColor(listbackcolor);
+	filelist->setHeaderSize(0,getApp()->reg().readUnsignedEntry("SETTINGS","name_size",200));
+    filelist->setHeaderSize(1,getApp()->reg().readUnsignedEntry("SETTINGS","size_size",60));
+    filelist->setHeaderSize(2,getApp()->reg().readUnsignedEntry("SETTINGS","type_size",100));
+    filelist->setHeaderSize(3,getApp()->reg().readUnsignedEntry("SETTINGS","ext_size",100));
+    filelist->setHeaderSize(4,getApp()->reg().readUnsignedEntry("SETTINGS","modd_size",150));
+    filelist->setHeaderSize(5,getApp()->reg().readUnsignedEntry("SETTINGS","user_size",50));
+    filelist->setHeaderSize(6,getApp()->reg().readUnsignedEntry("SETTINGS","grou_size",50));
+    filelist->setHeaderSize(7,getApp()->reg().readUnsignedEntry("SETTINGS","attr_size",100));  	
+
+	// Read and set sort function for file list
+	FXString sort_func=getApp()->reg().readStringEntry("SETTINGS","sort_func","ascendingCase");
+    if (sort_func=="ascendingCase")
+		filelist->setSortFunc(filelist->ascendingCase);        
+    if (sort_func=="ascendingCaseMix")
+		filelist->setSortFunc(filelist->ascendingCaseMix);        
+    else if (sort_func=="descendingCase")
+		filelist->setSortFunc(filelist->descendingCase);        
+    else if (sort_func=="descendingCaseMix")
+		filelist->setSortFunc(filelist->descendingCaseMix);        
+    else if (sort_func=="ascending")
+		filelist->setSortFunc(filelist->ascending);        
+	else if (sort_func=="ascendingMix")
+		filelist->setSortFunc(filelist->ascendingMix);        
+    else if (sort_func=="descending")
+		filelist->setSortFunc(filelist->descending);        
+    else if (sort_func=="descendingMix")
+		filelist->setSortFunc(filelist->descendingMix);        
+	else if (sort_func=="ascendingSize")
+		filelist->setSortFunc(filelist->ascendingSize);        
+	else if (sort_func=="ascendingSizeMix")
+		filelist->setSortFunc(filelist->ascendingSizeMix);        
+	else if (sort_func=="descendingSize")
+		filelist->setSortFunc(filelist->descendingSize);        
+	else if (sort_func=="descendingSizeMix")
+		filelist->setSortFunc(filelist->descendingSizeMix);        
+	else if (sort_func=="ascendingType")
+		filelist->setSortFunc(filelist->ascendingType);        
+	else if (sort_func=="ascendingTypeMix")
+		filelist->setSortFunc(filelist->ascendingTypeMix);        
+	else if (sort_func=="descendingType")
+		filelist->setSortFunc(filelist->descendingType);        
+	else if (sort_func=="descendingTypeMix")
+		filelist->setSortFunc(filelist->descendingTypeMix);        
+	else if (sort_func=="ascendingExt")
+		filelist->setSortFunc(filelist->ascendingExt);        
+	else if (sort_func=="ascendingExtMix")
+		filelist->setSortFunc(filelist->ascendingExtMix);        
+	else if (sort_func=="descendingExt")
+		filelist->setSortFunc(filelist->descendingExt);        
+	else if (sort_func=="descendingExtMix")
+		filelist->setSortFunc(filelist->descendingExtMix);        
+	else if (sort_func=="ascendingTime")
+		filelist->setSortFunc(filelist->ascendingTime);        
+	else if (sort_func=="ascendingTimeMix")
+		filelist->setSortFunc(filelist->ascendingTimeMix);        
+	else if (sort_func=="descendingTime")
+		filelist->setSortFunc(filelist->descendingTime);        
+	else if (sort_func=="descendingTimeMix")
+		filelist->setSortFunc(filelist->descendingTimeMix);        
+	else if (sort_func=="ascendingUser")
+		filelist->setSortFunc(filelist->ascendingUser);        
+	else if (sort_func=="ascendingUserMix")
+		filelist->setSortFunc(filelist->ascendingUserMix);        
+	else if (sort_func=="descendingUser")
+		filelist->setSortFunc(filelist->descendingUser);         
+	else if (sort_func=="descendingUserMix")
+		filelist->setSortFunc(filelist->descendingUserMix);         
+	else if (sort_func=="ascendingGroup")
+		filelist->setSortFunc(filelist->ascendingGroup);        
+	else if (sort_func=="ascendingGroupMix")
+		filelist->setSortFunc(filelist->ascendingGroupMix);        
+	else if (sort_func=="descendingGroup")
+		filelist->setSortFunc(filelist->descendingGroup);        
+	else if (sort_func=="descendingGroupMix")
+		filelist->setSortFunc(filelist->descendingGroupMix);        
+	else if (sort_func=="ascendingPerm")
+		filelist->setSortFunc(filelist->ascendingPerm);        
+	else if (sort_func=="ascendingPermMix")
+		filelist->setSortFunc(filelist->ascendingPermMix);        
+	else if (sort_func=="descendingPerm")
+		filelist->setSortFunc(filelist->descendingPerm);        
+	else if (sort_func=="descendingPermMix")
+		filelist->setSortFunc(filelist->descendingPermMix);        
 
 	// Single click navigation
 	if (single_click_diropen & single_click_fileopen)
@@ -407,9 +491,9 @@ long XFileImage::onCmdPopupMenu(FXObject* o,FXSelector s,void* p)
 	new FXMenuCheck(&menu,_("&Hidden files"),filelist,FileList::ID_TOGGLE_HIDDEN);
 	new FXMenuCheck(&menu,_("Thum&bnails"),filelist,FileList::ID_TOGGLE_THUMBNAILS);
 	new FXMenuSeparator(&menu);
-	new FXMenuRadio(&menu,_("B&ig icons"),filelist,FXIconList::ID_SHOW_BIG_ICONS);
-	new FXMenuRadio(&menu,_("&Small icons"),filelist,FXIconList::ID_SHOW_MINI_ICONS);
-	new FXMenuRadio(&menu,_("F&ull file list"),filelist,FXIconList::ID_SHOW_DETAILS);
+	new FXMenuRadio(&menu,_("B&ig icons"),filelist,IconList::ID_SHOW_BIG_ICONS);
+	new FXMenuRadio(&menu,_("&Small icons"),filelist,IconList::ID_SHOW_MINI_ICONS);
+	new FXMenuRadio(&menu,_("F&ull file list"),filelist,IconList::ID_SHOW_DETAILS);
 	new FXMenuSeparator(&menu);
 	new FXMenuRadio(&menu,_("&Rows"),filelist,FileList::ID_ARRANGE_BY_ROWS);
 	new FXMenuRadio(&menu,_("&Columns"),filelist,FileList::ID_ARRANGE_BY_COLUMNS);
@@ -1232,6 +1316,94 @@ void XFileImage::saveConfig()
 	// Startup zoom
 	getApp()->reg().writeUnsignedEntry("SETTINGS","fitwin",fitwin);
 
+	// Filelist columns sizes
+	getApp()->reg().writeUnsignedEntry("SETTINGS","name_size",filelist->getHeaderSize(0));
+	getApp()->reg().writeUnsignedEntry("SETTINGS","size_size",filelist->getHeaderSize(1));
+	getApp()->reg().writeUnsignedEntry("SETTINGS","type_size",filelist->getHeaderSize(2));
+	getApp()->reg().writeUnsignedEntry("SETTINGS","ext_size",filelist->getHeaderSize(3));
+	getApp()->reg().writeUnsignedEntry("SETTINGS","modd_size",filelist->getHeaderSize(4));
+	getApp()->reg().writeUnsignedEntry("SETTINGS","user_size",filelist->getHeaderSize(5));
+	getApp()->reg().writeUnsignedEntry("SETTINGS","grou_size",filelist->getHeaderSize(6));
+	getApp()->reg().writeUnsignedEntry("SETTINGS","attr_size",filelist->getHeaderSize(7));
+
+	// Get and write sort function for search window
+	FXString sort_func;
+	if (filelist->getSortFunc()==filelist->ascendingCase)
+		sort_func="ascendingCase";
+	if (filelist->getSortFunc()==filelist->ascendingCaseMix)
+		sort_func="ascendingCaseMix";
+	else if (filelist->getSortFunc()==filelist->descendingCase)
+		sort_func="descendingCase";
+	else if (filelist->getSortFunc()==filelist->descendingCaseMix)
+		sort_func="descendingCaseMix";
+	else if (filelist->getSortFunc()==filelist->ascending)
+		sort_func="ascending";
+	else if (filelist->getSortFunc()==filelist->ascendingMix)
+		sort_func="ascendingMix";
+	else if (filelist->getSortFunc()==filelist->descending)
+		sort_func="descending";
+	else if (filelist->getSortFunc()==filelist->descendingMix)
+		sort_func="descendingMix";
+	else if (filelist->getSortFunc()==filelist->ascendingSize)
+		sort_func="ascendingSize";
+	else if (filelist->getSortFunc()==filelist->ascendingSizeMix)
+		sort_func="ascendingSizeMix";
+	else if (filelist->getSortFunc()==filelist->descendingSize)
+		sort_func="descendingSize";
+	else if (filelist->getSortFunc()==filelist->descendingSizeMix)
+		sort_func="descendingSizeMix";
+	else if (filelist->getSortFunc()==filelist->ascendingType)
+		sort_func="ascendingType";
+	else if (filelist->getSortFunc()==filelist->ascendingTypeMix)
+		sort_func="ascendingTypeMix";
+	else if (filelist->getSortFunc()==filelist->descendingType)
+		sort_func="descendingType";
+	else if (filelist->getSortFunc()==filelist->descendingTypeMix)
+		sort_func="descendingTypeMix";
+	else if (filelist->getSortFunc()==filelist->ascendingExt)
+		sort_func="ascendingExt";
+	else if (filelist->getSortFunc()==filelist->ascendingExtMix)
+		sort_func="ascendingExtMix";
+	else if (filelist->getSortFunc()==filelist->descendingExt)
+		sort_func="descendingExt";
+	else if (filelist->getSortFunc()==filelist->descendingExtMix)
+		sort_func="descendingExtMix";
+	else if (filelist->getSortFunc()==filelist->ascendingTime)
+		sort_func="ascendingTime";
+	else if (filelist->getSortFunc()==filelist->ascendingTimeMix)
+		sort_func="ascendingTimeMix";
+	else if (filelist->getSortFunc()==filelist->descendingTime)
+		sort_func="descendingTime";
+	else if (filelist->getSortFunc()==filelist->descendingTimeMix)
+		sort_func="descendingTimeMix";
+	else if (filelist->getSortFunc()==filelist->ascendingUser)
+		sort_func="ascendingUser";
+	else if (filelist->getSortFunc()==filelist->ascendingUserMix)
+		sort_func="ascendingUserMix";
+	else if (filelist->getSortFunc()==filelist->descendingUser)
+		sort_func="descendingUser";
+	else if (filelist->getSortFunc()==filelist->descendingUserMix)
+		sort_func="descendingUserMix";
+	else if (filelist->getSortFunc()==filelist->ascendingGroup)
+		sort_func="ascendingGroup";
+	else if (filelist->getSortFunc()==filelist->ascendingGroupMix)
+		sort_func="ascendingGroupMix";
+	else if (filelist->getSortFunc()==filelist->descendingGroup)
+		sort_func="descendingGroup";
+	else if (filelist->getSortFunc()==filelist->descendingGroupMix)
+		sort_func="descendingGroupMix";
+	else if (filelist->getSortFunc()==filelist->ascendingPerm)
+		sort_func="ascendingPerm";
+	else if (filelist->getSortFunc()==filelist->ascendingPermMix)
+		sort_func="ascendingPermMix";
+	else if (filelist->getSortFunc()==filelist->descendingPerm)
+		sort_func="descendingPerm";
+	else if (filelist->getSortFunc()==filelist->descendingPermMix)
+		sort_func="descendingPermMix";
+	else
+		sort_func="ascendingCase";
+	getApp()->reg().writeStringEntry("SETTINGS","sort_func",sort_func.text());
+
 	// Write registry settings
 	getApp()->reg().write();
 }
@@ -1325,7 +1497,7 @@ int main(int argc,char *argv[])
 
 	// Set Xfi colors according to the Xfe registry
 	FXColor basecolor,forecolor,backcolor,selforecolor,selbackcolor,bordercolor;
-    basecolor=reg->readColorEntry("SETTINGS","basecolor",FXRGB(214,207,198));
+    basecolor=reg->readColorEntry("SETTINGS","basecolor",FXRGB(237,233,227));
     forecolor=reg->readColorEntry("SETTINGS","forecolor",FXRGB(0,0,0));
     backcolor=reg->readColorEntry("SETTINGS","backcolor",FXRGB(255,255,255));
     selforecolor=reg->readColorEntry("SETTINGS","selforecolor",FXRGB(255,255,255));
