@@ -1,6 +1,9 @@
 #ifndef XFILEIMAGE_H
 #define XFILEIMAGE_H
 
+#include "InputDialog.h"
+#include "FileDialog.h"
+
 class XFileImage : public FXMainWindow
 {
     FXDECLARE(XFileImage)
@@ -15,7 +18,6 @@ protected:
     FXMenuBar         *menubar;               // Menu bar
     FXToolBar         *toolbar;               // Tool bar
     FXToolBarShell    *dragshell1;            // Shell for floating menubar
-    FXToolBarShell    *dragshell2;            // Shell for floating toolbar
     FXHorizontalFrame *statusbar;             // Status bar
     FXSplitter        *splitter;              // Splitter
     FXHorizontalFrame *filebox;               // Box containing directories/files
@@ -33,6 +35,8 @@ protected:
 	FXint			  indZoom;				  // Zoom index
 	FXdouble		  zoomval;				  // Actual zoom factor
 	FXbool			  fitwin;                 // Fit window when opening an image
+	InputDialog*	  printdialog;
+	FileDialog*       opendialog;
 protected:
     XFileImage()
     {}
@@ -67,6 +71,9 @@ public:
 	long onCmdItemClicked(FXObject* sender,FXSelector sel, void* ptr);
 	long onCmdToggleFitWin(FXObject*,FXSelector,void*);
 	long onUpdToggleFitWin(FXObject*,FXSelector,void*);
+	long onCmdPopupMenu(FXObject*,FXSelector,void*);
+    long onCmdHome(FXObject*,FXSelector,void*);
+    long onCmdWork(FXObject*,FXSelector,void*);
 public:
     enum{
         ID_ABOUT=FXMainWindow::ID_LAST,
@@ -94,6 +101,8 @@ public:
         ID_ZOOM_100,
         ID_ZOOM_WIN,
 		ID_TOGGLE_FIT_WIN,
+        ID_HOME,
+        ID_WORK,
         ID_LAST
     };
 public:
