@@ -70,15 +70,16 @@ FXbool single_click_fileopen=FALSE;
    
 
 // Map
-FXDEFMAP(XFilePackage) XFilePackageMap[]={
-                                         FXMAPFUNC(SEL_COMMAND,XFilePackage::ID_QUIT,XFilePackage::onCmdQuit),
-                                         FXMAPFUNC(SEL_COMMAND,XFilePackage::ID_UNINSTALL,XFilePackage::onCmdUninstall),
-                                       	 FXMAPFUNC(SEL_COMMAND,XFilePackage::ID_ABOUT,XFilePackage::onCmdAbout),
-                                       	 FXMAPFUNC(SEL_COMMAND,XFilePackage::ID_OPEN,XFilePackage::onCmdOpen),
-                                         FXMAPFUNC(SEL_COMMAND,XFilePackage::ID_INSTALL,XFilePackage::onCmdInstall),
-                                         FXMAPFUNC(SEL_UPDATE,XFilePackage::ID_DESCRIPTION,XFilePackage::onUpdDescription),
-                                         FXMAPFUNC(SEL_UPDATE,XFilePackage::ID_FILELIST,XFilePackage::onUpdFileList),
-                                     };
+FXDEFMAP(XFilePackage) XFilePackageMap[]=
+{
+	FXMAPFUNC(SEL_COMMAND,XFilePackage::ID_QUIT,XFilePackage::onCmdQuit),
+	FXMAPFUNC(SEL_COMMAND,XFilePackage::ID_UNINSTALL,XFilePackage::onCmdUninstall),
+	FXMAPFUNC(SEL_COMMAND,XFilePackage::ID_ABOUT,XFilePackage::onCmdAbout),
+	FXMAPFUNC(SEL_COMMAND,XFilePackage::ID_OPEN,XFilePackage::onCmdOpen),
+	FXMAPFUNC(SEL_COMMAND,XFilePackage::ID_INSTALL,XFilePackage::onCmdInstall),
+	FXMAPFUNC(SEL_UPDATE,XFilePackage::ID_DESCRIPTION,XFilePackage::onUpdDescription),
+	FXMAPFUNC(SEL_UPDATE,XFilePackage::ID_FILELIST,XFilePackage::onUpdFileList),
+};
 
 
 // Object implementation
@@ -637,7 +638,7 @@ int main(int argc,char* argv[])
 	
 	// Set Xfp colors according to the Xfe registry
 	FXColor basecolor,forecolor,backcolor,selforecolor,selbackcolor,bordercolor;
-    basecolor=reg->readColorEntry("SETTINGS","basecolor",FXRGB(214,207,198));
+    basecolor=reg->readColorEntry("SETTINGS","basecolor",FXRGB(237,233,227));
     forecolor=reg->readColorEntry("SETTINGS","forecolor",FXRGB(0,0,0));
     backcolor=reg->readColorEntry("SETTINGS","backcolor",FXRGB(255,255,255));
     selforecolor=reg->readColorEntry("SETTINGS","selforecolor",FXRGB(255,255,255));
