@@ -3,6 +3,70 @@
 #include <X11/Xft/Xft.h>
 
 
+// Hack to display a tooltip with name, size, date, etc.
+// We were asked about tip text
+long FXTreeList::onQueryTip(FXObject* sender,FXSelector sel,void* ptr)
+{
+	if(FXWindow::onQueryTip(sender,sel,ptr))
+		return 1;
+
+	if((flags&FLAG_TIP) && !(options&TREELIST_AUTOSELECT)) // No tip when autoselect!
+	{
+		FXint x,y;
+		FXuint buttons;
+
+		getCursorPosition(x,y,buttons);
+		FXTreeItem *item=getItemAt(x,y);
+		if(item)
+		{
+			//!!!! Hack to display a tooltip with name, size, date, etc.
+			FXString string;
+			
+			// Root folder
+			if (item->getText()==ROOTDIR)
+				string=_("Root directory");
+			
+			// Other folders
+			else
+			{
+				// Get user data pointer
+				FXString str=(FXchar*)item->getData();
+			
+				// Add name, type, permissions, etc. to the tool tip
+				FXString name=str.section('\t',0);
+				FXString type=str.section('\t',1);
+				FXString date=str.section('\t',2);
+				FXString user=str.section('\t',3);
+				FXString group=str.section('\t',4);
+				FXString perms=str.section('\t',5);
+				FXString deldate=str.section('\t',6);
+				FXString pathname=str.section('\t',7);
+
+				// Compute root file size
+				unsigned long long dnsize;
+				char dsize[64];
+				dnsize=::dirsize(pathname.text());
+				snprintf(dsize,sizeof(dsize)-1,"%llu",dnsize);
+				FXString size=::hSize(dsize);
+				if (deldate.empty())
+					string=_("Name: ")+name+"\n"+_("Size in root: ")+size+"\n"+_("Type: ")+type
+						   +"\n"+_("Modified date: ")+date+"\n"+_("User: ")+user+" - "+_("Group: ")+group
+						   +"\n"+_("Permissions: ")+perms;
+				else
+					string=_("Name: ")+name+"\n"+_("Size in root: ")+size+"\n"+_("Type: ")+type
+						   +"\n"+_("Modified date: ")+date+"\n"+_("Deletion date: ")+deldate+"\n"+_("User: ")+user+" - "+_("Group: ")+group
+						   +"\n"+_("Permissions: ")+perms;
+			}
+			//!!!! End of hack !!!
+			
+			sender->handle(this,FXSEL(SEL_COMMAND,ID_SETSTRINGVALUE),(void*)&string);
+			return 1;
+		}
+	}
+	return 0;
+}
+
+
 //
 // Hack of FXDCWindow
 //
@@ -67,7 +131,6 @@ FXint FXFont::getTextWidth(const FXchar *string,FXuint length) const
 
 
 
-
 //
 // Hack of FXTextField
 //
@@ -109,6 +172,7 @@ long FXTextField::onPaint(FXObject*,FXSelector,void* ptr)
 }
 
 
+
 //
 // Hack of FXSplitter
 //
@@ -301,357 +365,6 @@ bool FXRegistry::write()
 }
 
 
-//
-// Hack of FXIconList
-//
-
-// Hack to display more informations in the tool tip
-long FXIconList::onQueryTip(FXObject* sender,FXSelector sel,void* ptr)
-{
-    if (FXWindow::onQueryTip(sender,sel,ptr))
-        return 1;
-    if ((flags&FLAG_TIP) && (0<=cursor))
-    {
-        FXString str=items[cursor]->getText();
-
-        // !!!! Hack to add nsize, type, permissions, etc. to the tool tip
-        FXString name=str.section('\t',0);
-        FXString size=str.section('\t',1);
-        FXString type=str.section('\t',2);
-        FXString date=str.section('\t',4);
-        FXString user=str.section('\t',5);
-        FXString group=str.section('\t',6);
-        FXString perms=str.section('\t',7);
-        FXString string;
-        if (size.length()==0)
-            string=_("Name: ")+name+"\n"+_("Type: ")+type+"\n"+_("Modified date: ")+date+"\n"+_("User: ")+user+" - "+_("Group: ")+group+"\n"+_("Permissions: ")+perms;
-        else
-            string=_("Name: ")+name+"\n"+_("Size: ")+size+"\n"+_("Type: ")+type+"\n"+_("Modified date: ")+date+"\n"+_("User: ")+user+" - "+_("Group: ")+group+"\n"+_("Permissions: ")+perms;
-        // !!!! End of hack
-
-        sender->handle(this,FXSEL(SEL_COMMAND,ID_SETSTRINGVALUE),(void*)&string);
-        return 1;
-    }
-    return 0;
-}
-
-
-// The function below is taken from the FXIconList class
-// and hacked to right justify the second column of the file list (file size)
-// Also hacked to display a gray bar one line over two
-// It replaces the normal function...
-
-#define SIDE_SPACING            4    // Left or right spacing between items
-#define DETAIL_TEXT_SPACING     2    // Spacing between text and icon in detail icon mode
-
-extern FXColor highlightcolor;
-
-void FXIconItem::drawDetails(const FXIconList* list,FXDC& dc,FXint x,FXint y,FXint,FXint h) const
-{
-    register FXHeader *header=list->getHeader();
-    register FXFont *font=list->getFont();
-    register FXint iw=0,ih=0,tw=0,th=0,yt,beg,end,hi,drw,space,used,dw,xx;
-
-    if (header->getNumItems()==0)
-        return;
-
-    // !!!! Hack to display a grey bar in the Filelist, one line over two
-    static FXbool highlight=FALSE;
-
-    // Reset highlight variable at the beginning of the list
-    if (list->getItemAt(x,y)==0)
-        highlight=FALSE;
-
-    // Draw gray bar
-    if (highlight)
-    {
-        dc.setForeground(highlightcolor);
-        dc.fillRectangle(x,y,header->getTotalSize(),h);
-    }
-    highlight = !highlight;
-    // !!!! End of hack
-
-    if (isSelected())
-    {
-        dc.setForeground(list->getSelBackColor());
-        dc.fillRectangle(x,y,header->getTotalSize(),h);
-    }
-    if (hasFocus())
-        dc.drawFocusRectangle(x+1,y+1,header->getTotalSize()-2,h-2);
-    xx=x+SIDE_SPACING/2;
-    if (miniIcon)
-    {
-        iw=miniIcon->getWidth();
-        ih=miniIcon->getHeight();
-        dc.setClipRectangle(x,y,header->getItemSize(0),h);
-        dc.drawIcon(miniIcon,xx,y+(h-ih)/2);
-        dc.clearClipRectangle();
-        xx+=iw+DETAIL_TEXT_SPACING;
-    }
-    if (!label.empty())
-    {
-        th=font->getFontHeight();
-        dw=font->getTextWidth("...",3);
-        yt=y+(h-th-4)/2;
-        if (!isEnabled())
-            dc.setForeground(makeShadowColor(list->getBackColor()));
-        else if (isSelected())
-            dc.setForeground(list->getSelTextColor());
-        else
-            dc.setForeground(list->getTextColor());
-        used=iw+DETAIL_TEXT_SPACING+SIDE_SPACING/2;
-
-        for (hi=beg=0; beg<label.length() && hi<header->getNumItems(); hi++,beg=end+1)
-        {
-            space=header->getItemSize(hi)-used;
-            for (end=beg; end<label.length() && label[end]!='\t'; end++)
-                ;
-            if (end>beg)
-            {
-                drw=end-beg;
-                tw=font->getTextWidth(&label[beg],drw);
-                if (tw>space-4)
-                {
-                    while ((tw=font->getTextWidth(&label[beg],drw))+dw>space-4 && drw>1)
-                        drw--;
-                    dc.setClipRectangle(xx,y,space,h);
-                    dc.drawText(xx+2,yt+font->getFontAscent()+2,&label[beg],drw);
-                    dc.drawText(xx+tw+2,yt+font->getFontAscent()+2,"...",3);
-                    dc.clearClipRectangle();
-                }
-                else
-                {
-                    // !!!! Hack to right justify the second column (file size)
-                    if (hi==1)
-                        dc.drawText(xx+space-tw-20,yt+font->getFontAscent()+2,&label[beg],drw);
-                    else
-                        dc.drawText(xx+2,yt+font->getFontAscent()+2,&label[beg],drw);
-                    // !!!! End of hack
-                }
-            }
-            xx+=space;
-            used=0;
-        }
-    }
-}
-
-
-// The function below is taken from the FXIconList class
-// and hacked to allow single click navigation in the FileList
-// It replaces the normal function...
-
-#define SELECT_MASK   (ICONLIST_EXTENDEDSELECT|ICONLIST_SINGLESELECT|ICONLIST_BROWSESELECT|ICONLIST_MULTIPLESELECT)
-
-long FXIconList::onKeyPress(FXObject*,FXSelector,void* ptr)
-{
-    FXEvent* event=(FXEvent*)ptr;
-    FXint index=current;
-    flags&=~FLAG_TIP;
-    if (!isEnabled())
-        return 0;
-    if (target && target->tryHandle(this,FXSEL(SEL_KEYPRESS,message),ptr))
-        return 1;
-    switch (event->code)
-    {
-    case KEY_Control_L:
-    case KEY_Control_R:
-    case KEY_Shift_L:
-    case KEY_Shift_R:
-    case KEY_Alt_L:
-    case KEY_Alt_R:
-        if (flags&FLAG_DODRAG)
-            handle(this,FXSEL(SEL_DRAGGED,0),ptr);
-        return 1;
-    case KEY_Page_Up:
-    case KEY_KP_Page_Up:
-        lookup=FXString::null;
-        setPosition(pos_x,pos_y+verticalScrollBar()->getPage());
-        return 1;
-    case KEY_Page_Down:
-    case KEY_KP_Page_Down:
-        lookup=FXString::null;
-        setPosition(pos_x,pos_y-verticalScrollBar()->getPage());
-        return 1;
-    case KEY_Right:
-    case KEY_KP_Right:
-        if (!(options&(ICONLIST_BIG_ICONS|ICONLIST_MINI_ICONS)))
-        {
-            setPosition(pos_x-10,pos_y);
-            return 1;
-        }
-        if (options&ICONLIST_COLUMNS)
-            index+=1;
-        else
-            index+=nrows;
-        goto hop;
-    case KEY_Left:
-    case KEY_KP_Left:
-        if (!(options&(ICONLIST_BIG_ICONS|ICONLIST_MINI_ICONS)))
-        {
-            setPosition(pos_x+10,pos_y);
-            return 1;
-        }
-        if (options&ICONLIST_COLUMNS)
-            index-=1;
-        else
-            index-=nrows;
-        goto hop;
-    case KEY_Up:
-    case KEY_KP_Up:
-        if (options&ICONLIST_COLUMNS)
-            index-=ncols;
-        else
-            index-=1;
-        goto hop;
-    case KEY_Down:
-    case KEY_KP_Down:
-        if (options&ICONLIST_COLUMNS)
-            index+=ncols;
-        else
-            index+=1;
-        goto hop;
-    case KEY_Home:
-    case KEY_KP_Home:
-        index=0;
-        goto hop;
-    case KEY_End:
-    case KEY_KP_End:
-        index=items.no()-1;
-hop:
-        lookup=FXString::null;
-        if (0<=index && index<items.no())
-        {
-            setCurrentItem(index,TRUE);
-            makeItemVisible(index);
-            if (items[index]->isEnabled())
-            {
-                if ((options&SELECT_MASK)==ICONLIST_EXTENDEDSELECT)
-                {
-                    if (event->state&SHIFTMASK)
-                    {
-                        if (0<=anchor)
-                        {
-                            selectItem(anchor,TRUE);
-                            extendSelection(index,TRUE);
-                        }
-                        else
-                            selectItem(index,TRUE);
-                    }
-                    else if (!(event->state&CONTROLMASK))
-                    {
-                        killSelection(TRUE);
-                        selectItem(index,TRUE);
-                        setAnchorItem(index);
-                    }
-                }
-            }
-        }
-
-        // !!!! Hack to allow single click navigation in the FileList
-        //handle(this,FXSEL(SEL_CLICKED,0),(void*)(FXival)current);
-        // !!!! End of hack
-
-        if (0<=current && items[current]->isEnabled())
-            handle(this,FXSEL(SEL_COMMAND,0),(void*)(FXival)current);
-        return 1;
-    case KEY_space:
-    case KEY_KP_Space:
-        lookup=FXString::null;
-        if (0<=current && items[current]->isEnabled())
-        {
-            switch (options&SELECT_MASK)
-            {
-            case ICONLIST_EXTENDEDSELECT:
-                if (event->state&SHIFTMASK)
-                {
-                    if (0<=anchor)
-                    {
-                        selectItem(anchor,TRUE);
-                        extendSelection(current,TRUE);
-                    }
-                    else
-                        selectItem(current,TRUE);
-                }
-                else if (event->state&CONTROLMASK)
-                    toggleItem(current,TRUE);
-                else
-                {
-                    killSelection(TRUE);
-                    selectItem(current,TRUE);
-                }
-                break;
-            case ICONLIST_MULTIPLESELECT:
-            case ICONLIST_SINGLESELECT:
-                toggleItem(current,TRUE);
-                break;
-            }
-            setAnchorItem(current);
-        }
-        handle(this,FXSEL(SEL_CLICKED,0),(void*)(FXival)current);
-        if (0<=current && items[current]->isEnabled())
-            handle(this,FXSEL(SEL_COMMAND,0),(void*)(FXival)current);
-        return 1;
-    case KEY_Return:
-    case KEY_KP_Enter:
-        lookup=FXString::null;
-        handle(this,FXSEL(SEL_DOUBLECLICKED,0),(void*)(FXival)current);
-        if (0<=current && items[current]->isEnabled())
-            handle(this,FXSEL(SEL_COMMAND,0),(void*)(FXival)current);
-        return 1;
-    default:
-        if ((FXuchar)event->text[0]<' ')
-            return 0;
-        if (event->state&(CONTROLMASK|ALTMASK))
-            return 0;
-        if (!Ascii::isPrint(event->text[0]))
-            return 0;
-        lookup.append(event->text);
-        getApp()->addTimeout(this,ID_LOOKUPTIMER,getApp()->getTypingSpeed());
-        index=findItem(lookup,current,SEARCH_FORWARD|SEARCH_WRAP|SEARCH_PREFIX);
-        if (0<=index)
-        {
-            setCurrentItem(index,TRUE);
-            makeItemVisible(index);
-            if (items[index]->isEnabled())
-            {
-                if ((options&SELECT_MASK)==ICONLIST_EXTENDEDSELECT)
-                {
-                    killSelection(TRUE);
-                    selectItem(index,TRUE);
-                }
-                setAnchorItem(index);
-            }
-        }
-        handle(this,FXSEL(SEL_CLICKED,0),(void*)(FXival)current);
-        if (0<=current && items[current]->isEnabled())
-            handle(this,FXSEL(SEL_COMMAND,0),(void*)(FXival)current);
-        return 1;
-    }
-    return 0;
-}
-
-
-// Move content
-void FXIconList::moveContents(FXint x,FXint y)
-{
-    FXint dx=x-pos_x;
-    FXint dy=y-pos_y;
-    FXint top=0;
-    pos_x=x;
-    pos_y=y;
-    if (!(options&(ICONLIST_MINI_ICONS|ICONLIST_BIG_ICONS)))
-    {
-        top=header->getDefaultHeight();
-        header->setPosition(x);
-    }
-    scroll(0,top,viewport_w,viewport_h,dx,dy);
-
-    // !!!! Hack to add a refresh when scrolling with one grey line over two
-    recalc();
-    // !!!! End of hack
-}
-
-
 
 //
 // Hack of FXPopup
