@@ -27,7 +27,7 @@ This program is distributed in the hope that it will be useful, but WITHOUT ANY
 \n \
 X File Explorer (xfe) is a lightweight file manager for X11, written using the FOX toolkit.\n \
 It is desktop independent and can easily be customized.\n \
-It has Windows Commander or MS-Explorer style and it is very fast and small.\n \
+It has Commander or Explorer styles and it is very fast and small.\n \
 Xfe is based on the popular, but discontinued X Win Commander, written by Maxim Baranov.\n \
 \n \
 \n \
@@ -119,7 +119,7 @@ Xfe is based on the popular, but discontinued X Win Commander, written by Maxim
   Drag and Drop operations :\n \
   =-=-=-=-=-=-=-=-=-=-=-=-=-=\n \
 \n \
-Dragging a file or group or files (by moving the mouse while maintaining the left button pressed) to a directory or a file panel, opens a dialog that allows to select the file operation : copy, move, link or cancel.\n \
+Dragging a file or group or files (by moving the mouse while maintaining the left button pressed) to a directory or a file panel optionally opens a dialog that allows to select the file operation : copy, move, link or cancel.\n \
 \n \
 \n \
   Configuration\n \
