@@ -34,8 +34,8 @@ FXIcon *searchnexticon, *searchicon, *searchprevicon, *selallicon, *setbookicon,
 FXIcon *showhiddenicon, *shownumbersicon, *showthumbicon, *smalliconsicon;
 FXIcon *trash_full_bigicon, *trash_fullicon, *treeonepanelicon, *treetwopanelsicon, *twopanelsicon;
 FXIcon *undoicon, *unmaphosticon, *uppercaseicon, *warningbigicon, *workicon, *wrapofficon, *wraponicon, *xfeicon, *xfiicon;
-FXIcon *xfqicon, *xfvicon, *xfwicon, *zipicon, *zoom100icon, *zoominicon, *zoomouticon, *zoomwinicon;
-FXIcon *totrashicon, *dirbackicon, *dirforwardicon, *minixfeicon, *minixferooticon;
+FXIcon *xfpicon, *xfvicon, *xfwicon, *zipicon, *zoom100icon, *zoominicon, *zoomouticon, *zoomwinicon;
+FXIcon *totrashicon, *dirbackicon, *dirforwardicon, *minixfeicon, *minixferooticon, *filedialogicon, *bigarchaddicon;
 
 
 // Load a PNG icon from a file in the icon path
@@ -213,7 +213,7 @@ FXbool loadAppIcons(FXApp *app)
 	success=( (wraponicon=loadiconfile(app,iconpath,"wrapon.png")) != NULL ) & success;
 	success=( (xfeicon=loadiconfile(app,iconpath,"xfe.png")) != NULL ) & success;
 	success=( (xfiicon=loadiconfile(app,iconpath,"xfi.png")) != NULL ) & success;
-	success=( (xfqicon=loadiconfile(app,iconpath,"xfq.png")) != NULL ) & success;
+	success=( (xfpicon=loadiconfile(app,iconpath,"xfp.png")) != NULL ) & success;
 	success=( (xfvicon=loadiconfile(app,iconpath,"xfv.png")) != NULL ) & success;
 	success=( (xfwicon=loadiconfile(app,iconpath,"xfw.png")) != NULL ) & success;
 	success=( (zipicon=loadiconfile(app,iconpath,"zip.png")) != NULL ) & success;
@@ -226,6 +226,8 @@ FXbool loadAppIcons(FXApp *app)
 	success=( (dirforwardicon=loadiconfile(app,iconpath,"dirforward.png")) != NULL ) & success;
 	success=( (minixferooticon=loadiconfile(app,iconpath,"minixferoot.png")) != NULL ) & success;
 	success=( (minixfeicon=loadiconfile(app,iconpath,"minixfe.png")) != NULL ) & success;
+	success=( (filedialogicon=loadiconfile(app,iconpath,"filedialog.png")) != NULL ) & success;
+	success=( (bigarchaddicon=loadiconfile(app,iconpath,"bigarchadd.png")) != NULL ) & success;
 		
 	return success;
 }
