@@ -191,6 +191,10 @@ int main(int argc,char *argv[])
 	// Read registry thru foxhacks
 	application->reg().read();
 
+	// Set base color (to change the default base color at first run)
+	FXColor basecolor=application->reg().readColorEntry("SETTINGS","basecolor",FXRGB(237,233,227));
+	application->setBaseColor(basecolor);
+	
 	// Load all application icons
 	loadicons=loadAppIcons(application);
 	
