@@ -60,5 +60,15 @@
 #endif
 
 // Tooltips setup time and duration
-#define TOOLTIP_PAUSE 200
+#ifndef TOOLTIP_PAUSE 
+#define TOOLTIP_PAUSE 500
+#endif
+
+#ifndef TOOLTIP_TIME
 #define TOOLTIP_TIME 10000
+#endif
+
+// Coefficient used to darken the sorted column in detailed mode
+#ifndef DARKEN_SORT
+#define DARKEN_SORT 0.96
+#endif
